


# Libraries
library(lme4)       # for lmer
library(lmerTest)   # to get p-value from lmer
library(robustlmm)  # for robust estimation of lmer handling outliers
library(sjPlot)     # for tab_model
library(parameters) # for demean
library(ggpubr)     # for ggline
library(haven)      # to read sas7bdat
library(data.table) # faster than data.frame
library(performance)# for "vif" for lmer fit
library(glmmTMB)    # for negative binomial
library(spaMM)      # for spatial modeling
library(scales)     # for rescale
library(DHARMa)     # for simulateResiduals

memory.limit(300000000000) # Increase memory limit

# Loading Data
z<-read_sas("Z:/CDCK01/Data_Zip/cdck01zip_census2.sas7bdat")       # N=11064,  829 variables
z<-data.table(z)

# as.integer -- for negative binomial DV and offset
z$CPopT <-as.integer(z$CPopT )
z$CPopW <-as.integer(z$CPopW )
z$CPopB <-as.integer(z$CPopB )
z$CPopH <-as.integer(z$CPopH )
z$CPopTM<-as.integer(z$CPopTM)
z$CPopTF<-as.integer(z$CPopTF)
z$CPop1 <-as.integer(z$CPop1 )
z$CPop2 <-as.integer(z$CPop2 )
z$CPop3 <-as.integer(z$CPop3 )
z$RptT  <-as.integer(z$RptT  )
z$RptW  <-as.integer(z$RptW  )
z$RptB  <-as.integer(z$RptB  )
z$RptH  <-as.integer(z$RptH  )
z$RptM  <-as.integer(z$RptM  )
z$RptF  <-as.integer(z$RptF  )
z$Rpt1  <-as.integer(z$Rpt1  )
z$Rpt2  <-as.integer(z$Rpt2  )
z$Rpt3  <-as.integer(z$Rpt3  )
z$NegT  <-as.integer(z$NegT  )
z$PhyT  <-as.integer(z$PhyT  )
z$SexT  <-as.integer(z$SexT  )
z$EmoT  <-as.integer(z$EmoT  )

# making categorical variables as.factor & scaling (roughly 0-100) continuous variables
z$Yearf      <-as.factor(z$Year)
z$NCHS_RUC   <-as.factor(z$NCHS_RUC)
z$USDA_RUC   <-as.factor(z$USDA_RUC)
z$USDA_RUC2  <-factor(z$USDA_RUC,levels=c(2,1,3))
z$USDA_RUC3  <-factor(z$USDA_RUC,levels=c(3,1,2))
z$USDA_RUC0  <-as.factor(z$USDA_RUC0)
z$IncomeT1k  <-z$IncomeT /1000
z$IncomeW1k  <-z$IncomeW /1000
z$IncomeB1k  <-z$IncomeB /1000
z$IncomeH1k  <-z$IncomeH /1000
z$HValueT10k <-z$HValueT /10000
z$MCostT100  <-z$MCostT  /100
z$OCostDT100 <-z$OCostDT /100
z$MRentDT100 <-z$MRentDT /100
z$CARatioT100<-z$CARatioT*100
z$CARatioW100<-z$CARatioW*100
z$CARatioB100<-z$CARatioB*100
z$CARatioH100<-z$CARatioH*100
z$MFRatioT100<-z$MFRatioT*100
z$MFRatioW100<-z$MFRatioW*100
z$MFRatioB100<-z$MFRatioB*100
z$MFRatioH100<-z$MFRatioH*100
z$OwnerT     <-z$OwnNT/z$OHUnitT*100
z$OwnerW     <-z$OwnNW/z$OHUnitW*100
z$OwnerB     <-z$OwnNB/z$OHUnitB*100
z$OwnerH     <-z$OwnNH/z$OHUnitH*100
z$GiniT100   <-z$GiniT*100
z$FoodIS     <-z$FoodInsP*100

# Spatial data
z$pos<-numFactor(z$Longitude,z$Latitude)

# Creating Outcome-Specific Data
zt<-z # total
zw<-z # White
zb<-z # Black
zh<-z # Hispanic
zm<-z # Male
zf<-z # Female
z1<-z # Age 0-5
z2<-z # Age 6-11
z3<-z # Age 12-17
zn<-z # Neglect
zp<-z # Physical abuse
zs<-z # Sexual abuse

summary(z[,.(RptTr,Rpt1r,Rpt2r,Rpt3r,RptMr,RptFr,NegTr,PhyTr,SexTr,RptWr,RptBr,RptHr,Yearf,FoodIS,USDA_RUC,
             CPovT,CPov1,CPov2,CPov3,CPovW,CPovB,CPovH,SingleT,SingleW,SingleB,SingleH,HValueT,VacantT,
             NoHighT,NoHighW,NoHighB,NoHighH,FBornT,FBornW,FBornB,FBornH,ChildPT,ChildPW,ChildPB,ChildPH,
             MalePT,MalePW,MalePB,MalePH,ElderT,ElderW,ElderB,ElderH,MoveT,MoveW,MoveB,MoveH,Longitude,Latitude)])

# Delete zip codes with no child
# Conceptually having them makes no sense.
# Methodologically, spaMM does not allow an weighting variable has a zero value.
zt<-zt[zt$CPopT >0,] # N=11064 -> 10876 (no child= 188)  1.7%
zw<-zw[zw$CPopW >0,] # N=11064 -> 10807 (no child= 257)  2.3%
zb<-zb[zb$CPopB >0,] # N=11064 ->  4997 (no child=6067) 54.8%
zh<-zh[zh$CPopH >0,] # N=11064 ->  7445 (no child=3619) 32.7%
zm<-zm[zm$CPopTM>0,] # N=11064 -> 10812 (no child= 252)  2.3%
zf<-zf[zf$CPopTF>0,] # N=11064 -> 10778 (no child= 286)  2.6%
z1<-z1[z1$CPop1 >0,] # N=11064 -> 10640 (no child= 424)  3.8%
z2<-z2[z2$CPop2 >0,] # N=11064 -> 10650 (no child= 414)  3.7%
z3<-z3[z3$CPop3 >0,] # N=11064 -> 10695 (no child= 369)  3.3%
zn<-zn[zn$CPopT >0,] # N=11064 -> 10876 (no child= 188)  1.7%
zp<-zp[zp$CPopT >0,] # N=11064 -> 10876 (no child= 188)  1.7%
zs<-zs[zs$CPopT >0,] # N=11064 -> 10876 (no child= 188)  1.7%

# Delete zip codes with missing HValueT
zt<-zt[!is.na(zt$HValueT),] # N=10876 -> 10720 (HValueT missing=156; 1.4%)
zw<-zw[!is.na(zw$HValueT),] # N=10807 -> 10666 (HValueT missing=141; 1.3%)
zb<-zb[!is.na(zb$HValueT),] # N= 4997 ->  4955 (HValueT missing= 42; 0.4%)
zh<-zh[!is.na(zh$HValueT),] # N= 7445 ->  7400 (HValueT missing= 45; 0.4%)
zm<-zm[!is.na(zm$HValueT),] # N=10812 -> 10671 (HValueT missing=141; 1.3%)
zf<-zf[!is.na(zf$HValueT),] # N=10778 -> 10636 (HValueT missing=142; 1.3%)
z1<-z1[!is.na(z1$HValueT),] # N=10640 -> 10545 (HValueT missing= 95; 0.9%)
z2<-z2[!is.na(z2$HValueT),] # N=10650 -> 10547 (HValueT missing=103; 0.9%)
z3<-z3[!is.na(z3$HValueT),] # N=10695 -> 10575 (HValueT missing=120; 1.1%)
zn<-zn[!is.na(zn$HValueT),] # N=10876 -> 10720 (HValueT missing=156; 1.4%)
zp<-zp[!is.na(zp$HValueT),] # N=10876 -> 10720 (HValueT missing=156; 1.4%)
zs<-zs[!is.na(zs$HValueT),] # N=10876 -> 10720 (HValueT missing=156; 1.4%)

10720/11064*100 # 96.9%
10666/11064*100 # 96.4%
 4955/11064*100 # 44.8%
 7400/11064*100 # 66.9%
10671/11064*100 # 96.4%
10636/11064*100 # 96.1%
10545/11064*100 # 95.3%
10547/11064*100 # 95.3%
10575/11064*100 # 95.6%
10720/11064*100 # 96.9%
10720/11064*100 # 96.9%
10720/11064*100 # 96.9%

nrow(zt[RptTr>1000]) #  11
nrow(zw[RptWr>1000]) #  13
nrow(zb[RptBr>1000]) # 116
nrow(zh[RptHr>1000]) #  26
nrow(zm[RptMr>1000]) #  13
nrow(zf[RptFr>1000]) #   5
nrow(z1[Rpt1r>1000]) #  24
nrow(z2[Rpt2r>1000]) #  17
nrow(z3[Rpt3r>1000]) #   3
nrow(zn[NegTr>1000]) #   2
nrow(zp[PhyTr>1000]) #   0
nrow(zs[SexTr>1000]) #   1

summary(zt$CPopT [zt$RptTr>1000]) # CPop 3rd Qu. = 6.5     Max = 20
summary(zw$CPopW [zw$RptWr>1000]) # CPop 3rd Qu. = 9       Max = 153
summary(zb$CPopB [zb$RptBr>1000]) # CPop 3rd Qu. = 6       Max = 27
summary(zh$CPopH [zh$RptHr>1000]) # CPop 3rd Qu. = 3       Max = 9
summary(zm$CPopTM[zm$RptMr>1000]) # CPop 3rd Qu. = 5       Max = 10
summary(zf$CPopTF[zf$RptFr>1000]) # CPop 3rd Qu. = 4       Max = 9
summary(z1$CPop1 [z1$Rpt1r>1000]) # CPop 3rd Qu. = 4.25    Max = 15
summary(z2$CPop2 [z2$Rpt2r>1000]) # CPop 3rd Qu. = 5       Max = 8
summary(z3$CPop3 [z3$Rpt3r>1000]) # CPop 3rd Qu. = 10.5    Max = 18
summary(zn$CPopT [zn$NegTr>1000]) # CPop 3rd Qu. = 5       Max = 6
summary(zp$CPopT [zp$PhyTr>1000]) # CPop 3rd Qu. = none    Max = none
summary(zs$CPopT [zs$SexTr>1000]) # CPop 3rd Qu. = 2       Max = 2

zt$RptTr[zt$RptTr>1000]<-1000
zw$RptWr[zw$RptWr>1000]<-1000
zb$RptBr[zb$RptBr>1000]<-1000
zh$RptHr[zh$RptHr>1000]<-1000
zm$RptMr[zm$RptMr>1000]<-1000
zf$RptFr[zf$RptFr>1000]<-1000
z1$Rpt1r[z1$Rpt1r>1000]<-1000
z2$Rpt2r[z2$Rpt2r>1000]<-1000
z3$Rpt3r[z3$Rpt3r>1000]<-1000
zn$NegTr[zn$NegTr>1000]<-1000
zp$PhyTr[zp$PhyTr>1000]<-1000
zs$SexTr[zs$SexTr>1000]<-1000

sum(zt$CPopT )/sum(z$CPopT ) # 0.9985766
sum(zw$CPopW )/sum(z$CPopW ) # 0.9984312
sum(zb$CPopB )/sum(z$CPopB ) # 0.9982899
sum(zh$CPopH )/sum(z$CPopH ) # 0.9993201
sum(zm$CPopTM)/sum(z$CPopTM) # 0.9985294
sum(zf$CPopTF)/sum(z$CPopTF) # 0.9986259
sum(z1$CPop1 )/sum(z$CPop1 ) # 0.9980162
sum(z2$CPop2 )/sum(z$CPop2 ) # 0.9984791
sum(z3$CPop3 )/sum(z$CPop3 ) # 0.999249
sum(zn$CPopT )/sum(z$CPopT ) # 0.9985766
sum(zp$CPopT )/sum(z$CPopT ) # 0.9985766
sum(zs$CPopT )/sum(z$CPopT ) # 0.9985766





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Total
# Food Insecurity - Total
# Food Insecurity - Total
# Food Insecurity - Total
# Food Insecurity - Total
# Food Insecurity - Total
# Food Insecurity - Total
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Checking Sample Size
# length(ct1$CountyFIPS)
# length(ct4$CountyFIPS)
# length(unique(ct1$CountyFIPS))
# length(unique(ct4$CountyFIPS))
# sum(ct1$CPopT)
# sum(ct4$CPopT)

# Check DV Distribution
# boxplot(ct4$RptTr)
# skewness(ct4$RptTr)
# plot(density(ct4$RptTr))

# Check IV Distribution
# boxplot(ct4$CPovT)
# boxplot(ct4$IncomeT)
# boxplot(ct4$FoodInsecure)
# plot(density(ct4$CPovT))
# plot(density(ct4$IncomeT))
# plot(density(ct4$FoodInsecure))

# Longitudinal Trend
# ct4[,list(mean=mean(RptTr)),by=Year]
# ct4[,list(mean=mean(CPovT)),by=Year]
# ct4[,list(mean=mean(IncomeT1k)),by=Year]
# ct4[,list(mean=mean(FoodInsecure)),by=Year]
# ggline(ct4, x="Year", y="FoodInsecure", add=c("mean_se"))
# ggline(ct4, x="Year", y="RptTr", add=c("mean_se"))
# ggline(ct4, x="Year", y="IncomeT1k", add=c("mean_se"))
# ggline(ct4, x="Year", y="CPovT", add=c("mean_se"))
# ggplot(ct4,aes(x=Year,y=FoodInsecure,group=CountyFIPS,color=StateFIPS))+geom_line()
# ggplot(ct4,aes(x=Year,y=RptTr       ,group=CountyFIPS,color=StateFIPS))+geom_line()
# ggplot(ct4,aes(x=Year,y=IncomeT1k    ,group=CountyFIPS,color=StateFIPS))+geom_line()
# ggplot(ct4,aes(x=Year,y=CPovT       ,group=CountyFIPS,color=StateFIPS))+geom_line()





# Centering Variables
zt$Yearc        <-zt$Year        -mean(zt$Year        ,na.rm=T)
zt$CPopBPc      <-zt$CPopBP      -mean(zt$CPopBP      ,na.rm=T)
zt$CPopHPc      <-zt$CPopHP      -mean(zt$CPopHP      ,na.rm=T)
zt$ChildPTc     <-zt$ChildPT     -mean(zt$ChildPT     ,na.rm=T)
zt$ChildPWc     <-zt$ChildPW     -mean(zt$ChildPW     ,na.rm=T)
zt$ChildPBc     <-zt$ChildPB     -mean(zt$ChildPB     ,na.rm=T)
zt$ChildPHc     <-zt$ChildPH     -mean(zt$ChildPH     ,na.rm=T)
zt$CARatioT100c <-zt$CARatioT100 -mean(zt$CARatioT100 ,na.rm=T)
zt$CARatioW100c <-zt$CARatioW100 -mean(zt$CARatioW100 ,na.rm=T)
zt$CARatioB100c <-zt$CARatioB100 -mean(zt$CARatioB100 ,na.rm=T)
zt$CARatioH100c <-zt$CARatioH100 -mean(zt$CARatioH100 ,na.rm=T)
zt$MalePTc      <-zt$MalePT      -mean(zt$MalePT      ,na.rm=T)
zt$MalePWc      <-zt$MalePW      -mean(zt$MalePW      ,na.rm=T)
zt$MalePBc      <-zt$MalePB      -mean(zt$MalePB      ,na.rm=T)
zt$MalePHc      <-zt$MalePH      -mean(zt$MalePH      ,na.rm=T)
zt$MFRatioT100c <-zt$MFRatioT100 -mean(zt$MFRatioT100 ,na.rm=T)
zt$MFRatioW100c <-zt$MFRatioW100 -mean(zt$MFRatioW100 ,na.rm=T)
zt$MFRatioB100c <-zt$MFRatioB100 -mean(zt$MFRatioB100 ,na.rm=T)
zt$MFRatioH100c <-zt$MFRatioH100 -mean(zt$MFRatioH100 ,na.rm=T)
zt$ElderTc      <-zt$ElderT      -mean(zt$ElderT      ,na.rm=T)
zt$ElderWc      <-zt$ElderW      -mean(zt$ElderW      ,na.rm=T)
zt$ElderBc      <-zt$ElderB      -mean(zt$ElderB      ,na.rm=T)
zt$ElderHc      <-zt$ElderH      -mean(zt$ElderH      ,na.rm=T)
zt$SingleTc     <-zt$SingleT     -mean(zt$SingleT     ,na.rm=T)
zt$SingleWc     <-zt$SingleW     -mean(zt$SingleW     ,na.rm=T)
zt$SingleBc     <-zt$SingleB     -mean(zt$SingleB     ,na.rm=T)
zt$SingleHc     <-zt$SingleH     -mean(zt$SingleH     ,na.rm=T)
zt$FHeadTc      <-zt$FHeadT      -mean(zt$FHeadT      ,na.rm=T)
zt$FHeadWc      <-zt$FHeadW      -mean(zt$FHeadW      ,na.rm=T)
zt$FHeadBc      <-zt$FHeadB      -mean(zt$FHeadB      ,na.rm=T)
zt$FHeadHc      <-zt$FHeadH      -mean(zt$FHeadH      ,na.rm=T)
zt$NoHighTc     <-zt$NoHighT     -mean(zt$NoHighT     ,na.rm=T)
zt$NoHighWc     <-zt$NoHighW     -mean(zt$NoHighW     ,na.rm=T)
zt$NoHighBc     <-zt$NoHighB     -mean(zt$NoHighB     ,na.rm=T)
zt$NoHighHc     <-zt$NoHighH     -mean(zt$NoHighH     ,na.rm=T)
zt$UnempTc      <-zt$UnempT      -mean(zt$UnempT      ,na.rm=T)
zt$UnempWc      <-zt$UnempW      -mean(zt$UnempW      ,na.rm=T)
zt$UnempBc      <-zt$UnempB      -mean(zt$UnempB      ,na.rm=T)
zt$UnempHc      <-zt$UnempH      -mean(zt$UnempH      ,na.rm=T)
zt$CPovTc       <-zt$CPovT       -mean(zt$CPovT       ,na.rm=T)
zt$CPovWc       <-zt$CPovW       -mean(zt$CPovW       ,na.rm=T)
zt$CPovBc       <-zt$CPovB       -mean(zt$CPovB       ,na.rm=T)
zt$CPovHc       <-zt$CPovH       -mean(zt$CPovH       ,na.rm=T)
zt$CPov1c       <-zt$CPov1       -mean(zt$CPov1       ,na.rm=T)
zt$CPov2c       <-zt$CPov2       -mean(zt$CPov2       ,na.rm=T)
zt$CPov3c       <-zt$CPov3       -mean(zt$CPov3       ,na.rm=T)
zt$PubAsTc      <-zt$PubAsT      -mean(zt$PubAsT      ,na.rm=T)
zt$WelfarTc     <-zt$WelfarT     -mean(zt$WelfarT     ,na.rm=T)
zt$SnapTc       <-zt$SnapT       -mean(zt$SnapT       ,na.rm=T)
zt$SnapWc       <-zt$SnapW       -mean(zt$SnapW       ,na.rm=T)
zt$SnapBc       <-zt$SnapB       -mean(zt$SnapB       ,na.rm=T)
zt$SnapHc       <-zt$SnapH       -mean(zt$SnapH       ,na.rm=T)
zt$IncomeT1kc   <-zt$IncomeT1k   -mean(zt$IncomeT1k   ,na.rm=T)
zt$IncomeW1kc   <-zt$IncomeW1k   -mean(zt$IncomeW1k   ,na.rm=T)
zt$IncomeB1kc   <-zt$IncomeB1k   -mean(zt$IncomeB1k   ,na.rm=T)
zt$IncomeH1kc   <-zt$IncomeH1k   -mean(zt$IncomeH1k   ,na.rm=T)
zt$GiniT100c    <-zt$GiniT100    -mean(zt$GiniT100    ,na.rm=T)
zt$HValueT10kc  <-zt$HValueT10k  -mean(zt$HValueT10k  ,na.rm=T)
zt$MCostT100c   <-zt$MCostT100   -mean(zt$MCostT100   ,na.rm=T)
zt$OCostDT100c  <-zt$OCostDT100  -mean(zt$OCostDT100  ,na.rm=T)
zt$MRentDT100c  <-zt$MRentDT100  -mean(zt$MRentDT100  ,na.rm=T)
zt$OCostPTc     <-zt$OCostPT     -mean(zt$OCostPT     ,na.rm=T)
zt$MRentPTc     <-zt$MRentPT     -mean(zt$MRentPT     ,na.rm=T)
zt$MortgTc      <-zt$MortgT      -mean(zt$MortgT      ,na.rm=T)
zt$LangAPTc     <-zt$LangAPT     -mean(zt$LangAPT     ,na.rm=T)
zt$LangAPWc     <-zt$LangAPW     -mean(zt$LangAPW     ,na.rm=T)
zt$LangAPBc     <-zt$LangAPB     -mean(zt$LangAPB     ,na.rm=T)
zt$LangAPHc     <-zt$LangAPH     -mean(zt$LangAPH     ,na.rm=T)
zt$LangBPTc     <-zt$LangBPT     -mean(zt$LangBPT     ,na.rm=T)
zt$LangBPWc     <-zt$LangBPW     -mean(zt$LangBPW     ,na.rm=T)
zt$LangBPBc     <-zt$LangBPB     -mean(zt$LangBPB     ,na.rm=T)
zt$LangBPHc     <-zt$LangBPH     -mean(zt$LangBPH     ,na.rm=T)
zt$LangCPTc     <-zt$LangCPT     -mean(zt$LangCPT     ,na.rm=T)
zt$OutUsTc      <-zt$OutUsT      -mean(zt$OutUsT      ,na.rm=T)
zt$OutUsWc      <-zt$OutUsW      -mean(zt$OutUsW      ,na.rm=T)
zt$OutUsBc      <-zt$OutUsB      -mean(zt$OutUsB      ,na.rm=T)
zt$OutUsHc      <-zt$OutUsH      -mean(zt$OutUsH      ,na.rm=T)
zt$FBornTc      <-zt$FBornT      -mean(zt$FBornT      ,na.rm=T)
zt$FBornWc      <-zt$FBornW      -mean(zt$FBornW      ,na.rm=T)
zt$FBornBc      <-zt$FBornB      -mean(zt$FBornB      ,na.rm=T)
zt$FBornHc      <-zt$FBornH      -mean(zt$FBornH      ,na.rm=T)
zt$NotCtzTc     <-zt$NotCtzT     -mean(zt$NotCtzT     ,na.rm=T)
zt$NotCtzWc     <-zt$NotCtzW     -mean(zt$NotCtzW     ,na.rm=T)
zt$NotCtzBc     <-zt$NotCtzB     -mean(zt$NotCtzB     ,na.rm=T)
zt$NotCtzHc     <-zt$NotCtzH     -mean(zt$NotCtzH     ,na.rm=T)
zt$MoveTc       <-zt$MoveT       -mean(zt$MoveT       ,na.rm=T)
zt$MoveWc       <-zt$MoveW       -mean(zt$MoveW       ,na.rm=T)
zt$MoveBc       <-zt$MoveB       -mean(zt$MoveB       ,na.rm=T)
zt$MoveHc       <-zt$MoveH       -mean(zt$MoveH       ,na.rm=T)
zt$VacantTc     <-zt$VacantT     -mean(zt$VacantT     ,na.rm=T)
zt$OwnerTc      <-zt$OwnerT      -mean(zt$OwnerT      ,na.rm=T)
zt$OwnerWc      <-zt$OwnerW      -mean(zt$OwnerW      ,na.rm=T)
zt$OwnerBc      <-zt$OwnerB      -mean(zt$OwnerB      ,na.rm=T)
zt$OwnerHc      <-zt$OwnerH      -mean(zt$OwnerH      ,na.rm=T)
zt$CrowdTc      <-zt$CrowdT      -mean(zt$CrowdT      ,na.rm=T)
zt$CrowdWc      <-zt$CrowdW      -mean(zt$CrowdW      ,na.rm=T)
zt$CrowdBc      <-zt$CrowdB      -mean(zt$CrowdB      ,na.rm=T)
zt$CrowdHc      <-zt$CrowdH      -mean(zt$CrowdH      ,na.rm=T)
zt$MobileTc     <-zt$MobileT     -mean(zt$MobileT     ,na.rm=T)
zt$MobileWc     <-zt$MobileW     -mean(zt$MobileW     ,na.rm=T)
zt$MobileBc     <-zt$MobileB     -mean(zt$MobileB     ,na.rm=T)
zt$MobileHc     <-zt$MobileH     -mean(zt$MobileH     ,na.rm=T)
zt$DisablTc     <-zt$DisablT     -mean(zt$DisablT     ,na.rm=T)
zt$DisablWc     <-zt$DisablW     -mean(zt$DisablW     ,na.rm=T)
zt$DisablBc     <-zt$DisablB     -mean(zt$DisablB     ,na.rm=T)
zt$DisablHc     <-zt$DisablH     -mean(zt$DisablH     ,na.rm=T)
zt$DisablTCc    <-zt$DisablTC    -mean(zt$DisablTC    ,na.rm=T)
zt$DisablWCc    <-zt$DisablWC    -mean(zt$DisablWC    ,na.rm=T)
zt$DisablBCc    <-zt$DisablBC    -mean(zt$DisablBC    ,na.rm=T)
zt$DisablHCc    <-zt$DisablHC    -mean(zt$DisablHC    ,na.rm=T)
zt$DisablTMc    <-zt$DisablTM    -mean(zt$DisablTM    ,na.rm=T)
zt$DisablTFc    <-zt$DisablTF    -mean(zt$DisablTF    ,na.rm=T)
zt$Urban1c      <-zt$Urban1      -mean(zt$Urban1      ,na.rm=T)
zt$Urban2c      <-zt$Urban2      -mean(zt$Urban2      ,na.rm=T)
zt$ISBE_PFAc    <-zt$ISBE_PFA    -mean(zt$ISBE_PFA    ,na.rm=T)
zt$ISBE_PFAEc   <-zt$ISBE_PFAE   -mean(zt$ISBE_PFAE   ,na.rm=T)
zt$ISBE_PIc     <-zt$ISBE_PI     -mean(zt$ISBE_PI     ,na.rm=T)
zt$HeadStartc   <-zt$HeadStart   -mean(zt$HeadStart   ,na.rm=T)
zt$ElyHeadSc    <-zt$ElyHeadS    -mean(zt$ElyHeadS    ,na.rm=T)
zt$HeadSAllc    <-zt$HeadSAll    -mean(zt$HeadSAll    ,na.rm=T)
zt$PFA_HS1c     <-zt$PFA_HS1     -mean(zt$PFA_HS1     ,na.rm=T)
zt$PFA_HS2c     <-zt$PFA_HS2     -mean(zt$PFA_HS2     ,na.rm=T)
zt$LCCCc        <-zt$LCCC        -mean(zt$LCCC        ,na.rm=T)
zt$LECCCc       <-zt$LECCC       -mean(zt$LECCC       ,na.rm=T)
zt$LFCCc        <-zt$LFCC        -mean(zt$LFCC        ,na.rm=T)
zt$LLECCCc      <-zt$LLECCC      -mean(zt$LLECCC      ,na.rm=T)
zt$LCLFCCc      <-zt$LCLFCC      -mean(zt$LCLFCC      ,na.rm=T)
zt$LCCCB1c      <-zt$LCCCB1      -mean(zt$LCCCB1      ,na.rm=T)
zt$LCCCB2c      <-zt$LCCCB2      -mean(zt$LCCCB2      ,na.rm=T)
zt$LCCB1c       <-zt$LCCB1       -mean(zt$LCCB1       ,na.rm=T)
zt$LCCB2c       <-zt$LCCB2       -mean(zt$LCCB2       ,na.rm=T)
zt$LCCCS1c      <-zt$LCCCS1      -mean(zt$LCCCS1      ,na.rm=T)
zt$LCCCS2c      <-zt$LCCCS2      -mean(zt$LCCCS2      ,na.rm=T)
zt$LCCS1c       <-zt$LCCS1       -mean(zt$LCCS1       ,na.rm=T)
zt$LCCS2c       <-zt$LCCS2       -mean(zt$LCCS2       ,na.rm=T)
zt$LCCCG1c      <-zt$LCCCG1      -mean(zt$LCCCG1      ,na.rm=T)
zt$LCCCG2c      <-zt$LCCCG2      -mean(zt$LCCCG2      ,na.rm=T)
zt$LCCG1c       <-zt$LCCG1       -mean(zt$LCCG1       ,na.rm=T)
zt$LCCG2c       <-zt$LCCG2       -mean(zt$LCCG2       ,na.rm=T)
zt$ChildCare1c  <-zt$ChildCare1  -mean(zt$ChildCare1  ,na.rm=T)
zt$ChildCare2c  <-zt$ChildCare2  -mean(zt$ChildCare2  ,na.rm=T)
zt$ChildCare3c  <-zt$ChildCare3  -mean(zt$ChildCare3  ,na.rm=T)
zt$CCAPc        <-zt$CCAP        -mean(zt$CCAP        ,na.rm=T)
zt$Homelessc    <-zt$Homeless    -mean(zt$Homeless    ,na.rm=T)
zt$Homeless2c   <-zt$Homeless2   -mean(zt$Homeless2   ,na.rm=T)
zt$DHS_HFIrc    <-zt$DHS_HFIr    -mean(zt$DHS_HFIr    ,na.rm=T)
zt$DHS_PTSrc    <-zt$DHS_PTSr    -mean(zt$DHS_PTSr    ,na.rm=T)
zt$DHS_HVPrc    <-zt$DHS_HVPr    -mean(zt$DHS_HVPr    ,na.rm=T)
zt$IDHS_EIrc    <-zt$IDHS_EIr    -mean(zt$IDHS_EIr    ,na.rm=T)
zt$MHV_C4c      <-zt$MHV_C4      -mean(zt$MHV_C4      ,na.rm=T)
zt$MHV_P4c      <-zt$MHV_P4      -mean(zt$MHV_P4      ,na.rm=T)
zt$MHV_C5c      <-zt$MHV_C5      -mean(zt$MHV_C5      ,na.rm=T)
zt$MHV_P5c      <-zt$MHV_P5      -mean(zt$MHV_P5      ,na.rm=T)
zt$FoodInsPc    <-zt$FoodInsP    -mean(zt$FoodInsP    ,na.rm=T)
zt$FoodISc      <-zt$FoodIS      -mean(zt$FoodIS      ,na.rm=T)





# demean - within and between variables
zt<-cbind(zt,demean(zt,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Age 0-5
# Food Insecurity - Age 0-5
# Food Insecurity - Age 0-5
# Food Insecurity - Age 0-5
# Food Insecurity - Age 0-5
# Food Insecurity - Age 0-5
# Food Insecurity - Age 0-5
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
z1$Yearc        <-z1$Year        -mean(z1$Year        ,na.rm=T)
z1$CPopBPc      <-z1$CPopBP      -mean(z1$CPopBP      ,na.rm=T)
z1$CPopHPc      <-z1$CPopHP      -mean(z1$CPopHP      ,na.rm=T)
z1$ChildPTc     <-z1$ChildPT     -mean(z1$ChildPT     ,na.rm=T)
z1$ChildPWc     <-z1$ChildPW     -mean(z1$ChildPW     ,na.rm=T)
z1$ChildPBc     <-z1$ChildPB     -mean(z1$ChildPB     ,na.rm=T)
z1$ChildPHc     <-z1$ChildPH     -mean(z1$ChildPH     ,na.rm=T)
z1$CARatioT100c <-z1$CARatioT100 -mean(z1$CARatioT100 ,na.rm=T)
z1$CARatioW100c <-z1$CARatioW100 -mean(z1$CARatioW100 ,na.rm=T)
z1$CARatioB100c <-z1$CARatioB100 -mean(z1$CARatioB100 ,na.rm=T)
z1$CARatioH100c <-z1$CARatioH100 -mean(z1$CARatioH100 ,na.rm=T)
z1$MalePTc      <-z1$MalePT      -mean(z1$MalePT      ,na.rm=T)
z1$MalePWc      <-z1$MalePW      -mean(z1$MalePW      ,na.rm=T)
z1$MalePBc      <-z1$MalePB      -mean(z1$MalePB      ,na.rm=T)
z1$MalePHc      <-z1$MalePH      -mean(z1$MalePH      ,na.rm=T)
z1$MFRatioT100c <-z1$MFRatioT100 -mean(z1$MFRatioT100 ,na.rm=T)
z1$MFRatioW100c <-z1$MFRatioW100 -mean(z1$MFRatioW100 ,na.rm=T)
z1$MFRatioB100c <-z1$MFRatioB100 -mean(z1$MFRatioB100 ,na.rm=T)
z1$MFRatioH100c <-z1$MFRatioH100 -mean(z1$MFRatioH100 ,na.rm=T)
z1$ElderTc      <-z1$ElderT      -mean(z1$ElderT      ,na.rm=T)
z1$ElderWc      <-z1$ElderW      -mean(z1$ElderW      ,na.rm=T)
z1$ElderBc      <-z1$ElderB      -mean(z1$ElderB      ,na.rm=T)
z1$ElderHc      <-z1$ElderH      -mean(z1$ElderH      ,na.rm=T)
z1$SingleTc     <-z1$SingleT     -mean(z1$SingleT     ,na.rm=T)
z1$SingleWc     <-z1$SingleW     -mean(z1$SingleW     ,na.rm=T)
z1$SingleBc     <-z1$SingleB     -mean(z1$SingleB     ,na.rm=T)
z1$SingleHc     <-z1$SingleH     -mean(z1$SingleH     ,na.rm=T)
z1$FHeadTc      <-z1$FHeadT      -mean(z1$FHeadT      ,na.rm=T)
z1$FHeadWc      <-z1$FHeadW      -mean(z1$FHeadW      ,na.rm=T)
z1$FHeadBc      <-z1$FHeadB      -mean(z1$FHeadB      ,na.rm=T)
z1$FHeadHc      <-z1$FHeadH      -mean(z1$FHeadH      ,na.rm=T)
z1$NoHighTc     <-z1$NoHighT     -mean(z1$NoHighT     ,na.rm=T)
z1$NoHighWc     <-z1$NoHighW     -mean(z1$NoHighW     ,na.rm=T)
z1$NoHighBc     <-z1$NoHighB     -mean(z1$NoHighB     ,na.rm=T)
z1$NoHighHc     <-z1$NoHighH     -mean(z1$NoHighH     ,na.rm=T)
z1$UnempTc      <-z1$UnempT      -mean(z1$UnempT      ,na.rm=T)
z1$UnempWc      <-z1$UnempW      -mean(z1$UnempW      ,na.rm=T)
z1$UnempBc      <-z1$UnempB      -mean(z1$UnempB      ,na.rm=T)
z1$UnempHc      <-z1$UnempH      -mean(z1$UnempH      ,na.rm=T)
z1$CPovTc       <-z1$CPovT       -mean(z1$CPovT       ,na.rm=T)
z1$CPovWc       <-z1$CPovW       -mean(z1$CPovW       ,na.rm=T)
z1$CPovBc       <-z1$CPovB       -mean(z1$CPovB       ,na.rm=T)
z1$CPovHc       <-z1$CPovH       -mean(z1$CPovH       ,na.rm=T)
z1$CPov1c       <-z1$CPov1       -mean(z1$CPov1       ,na.rm=T)
z1$CPov2c       <-z1$CPov2       -mean(z1$CPov2       ,na.rm=T)
z1$CPov3c       <-z1$CPov3       -mean(z1$CPov3       ,na.rm=T)
z1$PubAsTc      <-z1$PubAsT      -mean(z1$PubAsT      ,na.rm=T)
z1$WelfarTc     <-z1$WelfarT     -mean(z1$WelfarT     ,na.rm=T)
z1$SnapTc       <-z1$SnapT       -mean(z1$SnapT       ,na.rm=T)
z1$SnapWc       <-z1$SnapW       -mean(z1$SnapW       ,na.rm=T)
z1$SnapBc       <-z1$SnapB       -mean(z1$SnapB       ,na.rm=T)
z1$SnapHc       <-z1$SnapH       -mean(z1$SnapH       ,na.rm=T)
z1$IncomeT1kc   <-z1$IncomeT1k   -mean(z1$IncomeT1k   ,na.rm=T)
z1$IncomeW1kc   <-z1$IncomeW1k   -mean(z1$IncomeW1k   ,na.rm=T)
z1$IncomeB1kc   <-z1$IncomeB1k   -mean(z1$IncomeB1k   ,na.rm=T)
z1$IncomeH1kc   <-z1$IncomeH1k   -mean(z1$IncomeH1k   ,na.rm=T)
z1$GiniT100c    <-z1$GiniT100    -mean(z1$GiniT100    ,na.rm=T)
z1$HValueT10kc  <-z1$HValueT10k  -mean(z1$HValueT10k  ,na.rm=T)
z1$MCostT100c   <-z1$MCostT100   -mean(z1$MCostT100   ,na.rm=T)
z1$OCostDT100c  <-z1$OCostDT100  -mean(z1$OCostDT100  ,na.rm=T)
z1$MRentDT100c  <-z1$MRentDT100  -mean(z1$MRentDT100  ,na.rm=T)
z1$OCostPTc     <-z1$OCostPT     -mean(z1$OCostPT     ,na.rm=T)
z1$MRentPTc     <-z1$MRentPT     -mean(z1$MRentPT     ,na.rm=T)
z1$MortgTc      <-z1$MortgT      -mean(z1$MortgT      ,na.rm=T)
z1$LangAPTc     <-z1$LangAPT     -mean(z1$LangAPT     ,na.rm=T)
z1$LangAPWc     <-z1$LangAPW     -mean(z1$LangAPW     ,na.rm=T)
z1$LangAPBc     <-z1$LangAPB     -mean(z1$LangAPB     ,na.rm=T)
z1$LangAPHc     <-z1$LangAPH     -mean(z1$LangAPH     ,na.rm=T)
z1$LangBPTc     <-z1$LangBPT     -mean(z1$LangBPT     ,na.rm=T)
z1$LangBPWc     <-z1$LangBPW     -mean(z1$LangBPW     ,na.rm=T)
z1$LangBPBc     <-z1$LangBPB     -mean(z1$LangBPB     ,na.rm=T)
z1$LangBPHc     <-z1$LangBPH     -mean(z1$LangBPH     ,na.rm=T)
z1$LangCPTc     <-z1$LangCPT     -mean(z1$LangCPT     ,na.rm=T)
z1$OutUsTc      <-z1$OutUsT      -mean(z1$OutUsT      ,na.rm=T)
z1$OutUsWc      <-z1$OutUsW      -mean(z1$OutUsW      ,na.rm=T)
z1$OutUsBc      <-z1$OutUsB      -mean(z1$OutUsB      ,na.rm=T)
z1$OutUsHc      <-z1$OutUsH      -mean(z1$OutUsH      ,na.rm=T)
z1$FBornTc      <-z1$FBornT      -mean(z1$FBornT      ,na.rm=T)
z1$FBornWc      <-z1$FBornW      -mean(z1$FBornW      ,na.rm=T)
z1$FBornBc      <-z1$FBornB      -mean(z1$FBornB      ,na.rm=T)
z1$FBornHc      <-z1$FBornH      -mean(z1$FBornH      ,na.rm=T)
z1$NotCtzTc     <-z1$NotCtzT     -mean(z1$NotCtzT     ,na.rm=T)
z1$NotCtzWc     <-z1$NotCtzW     -mean(z1$NotCtzW     ,na.rm=T)
z1$NotCtzBc     <-z1$NotCtzB     -mean(z1$NotCtzB     ,na.rm=T)
z1$NotCtzHc     <-z1$NotCtzH     -mean(z1$NotCtzH     ,na.rm=T)
z1$MoveTc       <-z1$MoveT       -mean(z1$MoveT       ,na.rm=T)
z1$MoveWc       <-z1$MoveW       -mean(z1$MoveW       ,na.rm=T)
z1$MoveBc       <-z1$MoveB       -mean(z1$MoveB       ,na.rm=T)
z1$MoveHc       <-z1$MoveH       -mean(z1$MoveH       ,na.rm=T)
z1$VacantTc     <-z1$VacantT     -mean(z1$VacantT     ,na.rm=T)
z1$OwnerTc      <-z1$OwnerT      -mean(z1$OwnerT      ,na.rm=T)
z1$OwnerWc      <-z1$OwnerW      -mean(z1$OwnerW      ,na.rm=T)
z1$OwnerBc      <-z1$OwnerB      -mean(z1$OwnerB      ,na.rm=T)
z1$OwnerHc      <-z1$OwnerH      -mean(z1$OwnerH      ,na.rm=T)
z1$CrowdTc      <-z1$CrowdT      -mean(z1$CrowdT      ,na.rm=T)
z1$CrowdWc      <-z1$CrowdW      -mean(z1$CrowdW      ,na.rm=T)
z1$CrowdBc      <-z1$CrowdB      -mean(z1$CrowdB      ,na.rm=T)
z1$CrowdHc      <-z1$CrowdH      -mean(z1$CrowdH      ,na.rm=T)
z1$MobileTc     <-z1$MobileT     -mean(z1$MobileT     ,na.rm=T)
z1$MobileWc     <-z1$MobileW     -mean(z1$MobileW     ,na.rm=T)
z1$MobileBc     <-z1$MobileB     -mean(z1$MobileB     ,na.rm=T)
z1$MobileHc     <-z1$MobileH     -mean(z1$MobileH     ,na.rm=T)
z1$DisablTc     <-z1$DisablT     -mean(z1$DisablT     ,na.rm=T)
z1$DisablWc     <-z1$DisablW     -mean(z1$DisablW     ,na.rm=T)
z1$DisablBc     <-z1$DisablB     -mean(z1$DisablB     ,na.rm=T)
z1$DisablHc     <-z1$DisablH     -mean(z1$DisablH     ,na.rm=T)
z1$DisablTCc    <-z1$DisablTC    -mean(z1$DisablTC    ,na.rm=T)
z1$DisablWCc    <-z1$DisablWC    -mean(z1$DisablWC    ,na.rm=T)
z1$DisablBCc    <-z1$DisablBC    -mean(z1$DisablBC    ,na.rm=T)
z1$DisablHCc    <-z1$DisablHC    -mean(z1$DisablHC    ,na.rm=T)
z1$DisablTMc    <-z1$DisablTM    -mean(z1$DisablTM    ,na.rm=T)
z1$DisablTFc    <-z1$DisablTF    -mean(z1$DisablTF    ,na.rm=T)
z1$Urban1c      <-z1$Urban1      -mean(z1$Urban1      ,na.rm=T)
z1$Urban2c      <-z1$Urban2      -mean(z1$Urban2      ,na.rm=T)
z1$ISBE_PFAc    <-z1$ISBE_PFA    -mean(z1$ISBE_PFA    ,na.rm=T)
z1$ISBE_PFAEc   <-z1$ISBE_PFAE   -mean(z1$ISBE_PFAE   ,na.rm=T)
z1$ISBE_PIc     <-z1$ISBE_PI     -mean(z1$ISBE_PI     ,na.rm=T)
z1$HeadStartc   <-z1$HeadStart   -mean(z1$HeadStart   ,na.rm=T)
z1$ElyHeadSc    <-z1$ElyHeadS    -mean(z1$ElyHeadS    ,na.rm=T)
z1$HeadSAllc    <-z1$HeadSAll    -mean(z1$HeadSAll    ,na.rm=T)
z1$PFA_HS1c     <-z1$PFA_HS1     -mean(z1$PFA_HS1     ,na.rm=T)
z1$PFA_HS2c     <-z1$PFA_HS2     -mean(z1$PFA_HS2     ,na.rm=T)
z1$LCCCc        <-z1$LCCC        -mean(z1$LCCC        ,na.rm=T)
z1$LECCCc       <-z1$LECCC       -mean(z1$LECCC       ,na.rm=T)
z1$LFCCc        <-z1$LFCC        -mean(z1$LFCC        ,na.rm=T)
z1$LLECCCc      <-z1$LLECCC      -mean(z1$LLECCC      ,na.rm=T)
z1$LCLFCCc      <-z1$LCLFCC      -mean(z1$LCLFCC      ,na.rm=T)
z1$LCCCB1c      <-z1$LCCCB1      -mean(z1$LCCCB1      ,na.rm=T)
z1$LCCCB2c      <-z1$LCCCB2      -mean(z1$LCCCB2      ,na.rm=T)
z1$LCCB1c       <-z1$LCCB1       -mean(z1$LCCB1       ,na.rm=T)
z1$LCCB2c       <-z1$LCCB2       -mean(z1$LCCB2       ,na.rm=T)
z1$LCCCS1c      <-z1$LCCCS1      -mean(z1$LCCCS1      ,na.rm=T)
z1$LCCCS2c      <-z1$LCCCS2      -mean(z1$LCCCS2      ,na.rm=T)
z1$LCCS1c       <-z1$LCCS1       -mean(z1$LCCS1       ,na.rm=T)
z1$LCCS2c       <-z1$LCCS2       -mean(z1$LCCS2       ,na.rm=T)
z1$LCCCG1c      <-z1$LCCCG1      -mean(z1$LCCCG1      ,na.rm=T)
z1$LCCCG2c      <-z1$LCCCG2      -mean(z1$LCCCG2      ,na.rm=T)
z1$LCCG1c       <-z1$LCCG1       -mean(z1$LCCG1       ,na.rm=T)
z1$LCCG2c       <-z1$LCCG2       -mean(z1$LCCG2       ,na.rm=T)
z1$ChildCare1c  <-z1$ChildCare1  -mean(z1$ChildCare1  ,na.rm=T)
z1$ChildCare2c  <-z1$ChildCare2  -mean(z1$ChildCare2  ,na.rm=T)
z1$ChildCare3c  <-z1$ChildCare3  -mean(z1$ChildCare3  ,na.rm=T)
z1$CCAPc        <-z1$CCAP        -mean(z1$CCAP        ,na.rm=T)
z1$Homelessc    <-z1$Homeless    -mean(z1$Homeless    ,na.rm=T)
z1$Homeless2c   <-z1$Homeless2   -mean(z1$Homeless2   ,na.rm=T)
z1$DHS_HFIrc    <-z1$DHS_HFIr    -mean(z1$DHS_HFIr    ,na.rm=T)
z1$DHS_PTSrc    <-z1$DHS_PTSr    -mean(z1$DHS_PTSr    ,na.rm=T)
z1$DHS_HVPrc    <-z1$DHS_HVPr    -mean(z1$DHS_HVPr    ,na.rm=T)
z1$IDHS_EIrc    <-z1$IDHS_EIr    -mean(z1$IDHS_EIr    ,na.rm=T)
z1$MHV_C4c      <-z1$MHV_C4      -mean(z1$MHV_C4      ,na.rm=T)
z1$MHV_P4c      <-z1$MHV_P4      -mean(z1$MHV_P4      ,na.rm=T)
z1$MHV_C5c      <-z1$MHV_C5      -mean(z1$MHV_C5      ,na.rm=T)
z1$MHV_P5c      <-z1$MHV_P5      -mean(z1$MHV_P5      ,na.rm=T)
z1$FoodInsPc    <-z1$FoodInsP    -mean(z1$FoodInsP    ,na.rm=T)
z1$FoodISc      <-z1$FoodIS      -mean(z1$FoodIS      ,na.rm=T)





# demean - within and between variables
z1<-cbind(z1,demean(z1,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Age 6-11
# Food Insecurity - Age 6-11
# Food Insecurity - Age 6-11
# Food Insecurity - Age 6-11
# Food Insecurity - Age 6-11
# Food Insecurity - Age 6-11
# Food Insecurity - Age 6-11
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
z2$Yearc        <-z2$Year        -mean(z2$Year        ,na.rm=T)
z2$CPopBPc      <-z2$CPopBP      -mean(z2$CPopBP      ,na.rm=T)
z2$CPopHPc      <-z2$CPopHP      -mean(z2$CPopHP      ,na.rm=T)
z2$ChildPTc     <-z2$ChildPT     -mean(z2$ChildPT     ,na.rm=T)
z2$ChildPWc     <-z2$ChildPW     -mean(z2$ChildPW     ,na.rm=T)
z2$ChildPBc     <-z2$ChildPB     -mean(z2$ChildPB     ,na.rm=T)
z2$ChildPHc     <-z2$ChildPH     -mean(z2$ChildPH     ,na.rm=T)
z2$CARatioT100c <-z2$CARatioT100 -mean(z2$CARatioT100 ,na.rm=T)
z2$CARatioW100c <-z2$CARatioW100 -mean(z2$CARatioW100 ,na.rm=T)
z2$CARatioB100c <-z2$CARatioB100 -mean(z2$CARatioB100 ,na.rm=T)
z2$CARatioH100c <-z2$CARatioH100 -mean(z2$CARatioH100 ,na.rm=T)
z2$MalePTc      <-z2$MalePT      -mean(z2$MalePT      ,na.rm=T)
z2$MalePWc      <-z2$MalePW      -mean(z2$MalePW      ,na.rm=T)
z2$MalePBc      <-z2$MalePB      -mean(z2$MalePB      ,na.rm=T)
z2$MalePHc      <-z2$MalePH      -mean(z2$MalePH      ,na.rm=T)
z2$MFRatioT100c <-z2$MFRatioT100 -mean(z2$MFRatioT100 ,na.rm=T)
z2$MFRatioW100c <-z2$MFRatioW100 -mean(z2$MFRatioW100 ,na.rm=T)
z2$MFRatioB100c <-z2$MFRatioB100 -mean(z2$MFRatioB100 ,na.rm=T)
z2$MFRatioH100c <-z2$MFRatioH100 -mean(z2$MFRatioH100 ,na.rm=T)
z2$ElderTc      <-z2$ElderT      -mean(z2$ElderT      ,na.rm=T)
z2$ElderWc      <-z2$ElderW      -mean(z2$ElderW      ,na.rm=T)
z2$ElderBc      <-z2$ElderB      -mean(z2$ElderB      ,na.rm=T)
z2$ElderHc      <-z2$ElderH      -mean(z2$ElderH      ,na.rm=T)
z2$SingleTc     <-z2$SingleT     -mean(z2$SingleT     ,na.rm=T)
z2$SingleWc     <-z2$SingleW     -mean(z2$SingleW     ,na.rm=T)
z2$SingleBc     <-z2$SingleB     -mean(z2$SingleB     ,na.rm=T)
z2$SingleHc     <-z2$SingleH     -mean(z2$SingleH     ,na.rm=T)
z2$FHeadTc      <-z2$FHeadT      -mean(z2$FHeadT      ,na.rm=T)
z2$FHeadWc      <-z2$FHeadW      -mean(z2$FHeadW      ,na.rm=T)
z2$FHeadBc      <-z2$FHeadB      -mean(z2$FHeadB      ,na.rm=T)
z2$FHeadHc      <-z2$FHeadH      -mean(z2$FHeadH      ,na.rm=T)
z2$NoHighTc     <-z2$NoHighT     -mean(z2$NoHighT     ,na.rm=T)
z2$NoHighWc     <-z2$NoHighW     -mean(z2$NoHighW     ,na.rm=T)
z2$NoHighBc     <-z2$NoHighB     -mean(z2$NoHighB     ,na.rm=T)
z2$NoHighHc     <-z2$NoHighH     -mean(z2$NoHighH     ,na.rm=T)
z2$UnempTc      <-z2$UnempT      -mean(z2$UnempT      ,na.rm=T)
z2$UnempWc      <-z2$UnempW      -mean(z2$UnempW      ,na.rm=T)
z2$UnempBc      <-z2$UnempB      -mean(z2$UnempB      ,na.rm=T)
z2$UnempHc      <-z2$UnempH      -mean(z2$UnempH      ,na.rm=T)
z2$CPovTc       <-z2$CPovT       -mean(z2$CPovT       ,na.rm=T)
z2$CPovWc       <-z2$CPovW       -mean(z2$CPovW       ,na.rm=T)
z2$CPovBc       <-z2$CPovB       -mean(z2$CPovB       ,na.rm=T)
z2$CPovHc       <-z2$CPovH       -mean(z2$CPovH       ,na.rm=T)
z2$CPov1c       <-z2$CPov1       -mean(z2$CPov1       ,na.rm=T)
z2$CPov2c       <-z2$CPov2       -mean(z2$CPov2       ,na.rm=T)
z2$CPov3c       <-z2$CPov3       -mean(z2$CPov3       ,na.rm=T)
z2$PubAsTc      <-z2$PubAsT      -mean(z2$PubAsT      ,na.rm=T)
z2$WelfarTc     <-z2$WelfarT     -mean(z2$WelfarT     ,na.rm=T)
z2$SnapTc       <-z2$SnapT       -mean(z2$SnapT       ,na.rm=T)
z2$SnapWc       <-z2$SnapW       -mean(z2$SnapW       ,na.rm=T)
z2$SnapBc       <-z2$SnapB       -mean(z2$SnapB       ,na.rm=T)
z2$SnapHc       <-z2$SnapH       -mean(z2$SnapH       ,na.rm=T)
z2$IncomeT1kc   <-z2$IncomeT1k   -mean(z2$IncomeT1k   ,na.rm=T)
z2$IncomeW1kc   <-z2$IncomeW1k   -mean(z2$IncomeW1k   ,na.rm=T)
z2$IncomeB1kc   <-z2$IncomeB1k   -mean(z2$IncomeB1k   ,na.rm=T)
z2$IncomeH1kc   <-z2$IncomeH1k   -mean(z2$IncomeH1k   ,na.rm=T)
z2$GiniT100c    <-z2$GiniT100    -mean(z2$GiniT100    ,na.rm=T)
z2$HValueT10kc  <-z2$HValueT10k  -mean(z2$HValueT10k  ,na.rm=T)
z2$MCostT100c   <-z2$MCostT100   -mean(z2$MCostT100   ,na.rm=T)
z2$OCostDT100c  <-z2$OCostDT100  -mean(z2$OCostDT100  ,na.rm=T)
z2$MRentDT100c  <-z2$MRentDT100  -mean(z2$MRentDT100  ,na.rm=T)
z2$OCostPTc     <-z2$OCostPT     -mean(z2$OCostPT     ,na.rm=T)
z2$MRentPTc     <-z2$MRentPT     -mean(z2$MRentPT     ,na.rm=T)
z2$MortgTc      <-z2$MortgT      -mean(z2$MortgT      ,na.rm=T)
z2$LangAPTc     <-z2$LangAPT     -mean(z2$LangAPT     ,na.rm=T)
z2$LangAPWc     <-z2$LangAPW     -mean(z2$LangAPW     ,na.rm=T)
z2$LangAPBc     <-z2$LangAPB     -mean(z2$LangAPB     ,na.rm=T)
z2$LangAPHc     <-z2$LangAPH     -mean(z2$LangAPH     ,na.rm=T)
z2$LangBPTc     <-z2$LangBPT     -mean(z2$LangBPT     ,na.rm=T)
z2$LangBPWc     <-z2$LangBPW     -mean(z2$LangBPW     ,na.rm=T)
z2$LangBPBc     <-z2$LangBPB     -mean(z2$LangBPB     ,na.rm=T)
z2$LangBPHc     <-z2$LangBPH     -mean(z2$LangBPH     ,na.rm=T)
z2$LangCPTc     <-z2$LangCPT     -mean(z2$LangCPT     ,na.rm=T)
z2$OutUsTc      <-z2$OutUsT      -mean(z2$OutUsT      ,na.rm=T)
z2$OutUsWc      <-z2$OutUsW      -mean(z2$OutUsW      ,na.rm=T)
z2$OutUsBc      <-z2$OutUsB      -mean(z2$OutUsB      ,na.rm=T)
z2$OutUsHc      <-z2$OutUsH      -mean(z2$OutUsH      ,na.rm=T)
z2$FBornTc      <-z2$FBornT      -mean(z2$FBornT      ,na.rm=T)
z2$FBornWc      <-z2$FBornW      -mean(z2$FBornW      ,na.rm=T)
z2$FBornBc      <-z2$FBornB      -mean(z2$FBornB      ,na.rm=T)
z2$FBornHc      <-z2$FBornH      -mean(z2$FBornH      ,na.rm=T)
z2$NotCtzTc     <-z2$NotCtzT     -mean(z2$NotCtzT     ,na.rm=T)
z2$NotCtzWc     <-z2$NotCtzW     -mean(z2$NotCtzW     ,na.rm=T)
z2$NotCtzBc     <-z2$NotCtzB     -mean(z2$NotCtzB     ,na.rm=T)
z2$NotCtzHc     <-z2$NotCtzH     -mean(z2$NotCtzH     ,na.rm=T)
z2$MoveTc       <-z2$MoveT       -mean(z2$MoveT       ,na.rm=T)
z2$MoveWc       <-z2$MoveW       -mean(z2$MoveW       ,na.rm=T)
z2$MoveBc       <-z2$MoveB       -mean(z2$MoveB       ,na.rm=T)
z2$MoveHc       <-z2$MoveH       -mean(z2$MoveH       ,na.rm=T)
z2$VacantTc     <-z2$VacantT     -mean(z2$VacantT     ,na.rm=T)
z2$OwnerTc      <-z2$OwnerT      -mean(z2$OwnerT      ,na.rm=T)
z2$OwnerWc      <-z2$OwnerW      -mean(z2$OwnerW      ,na.rm=T)
z2$OwnerBc      <-z2$OwnerB      -mean(z2$OwnerB      ,na.rm=T)
z2$OwnerHc      <-z2$OwnerH      -mean(z2$OwnerH      ,na.rm=T)
z2$CrowdTc      <-z2$CrowdT      -mean(z2$CrowdT      ,na.rm=T)
z2$CrowdWc      <-z2$CrowdW      -mean(z2$CrowdW      ,na.rm=T)
z2$CrowdBc      <-z2$CrowdB      -mean(z2$CrowdB      ,na.rm=T)
z2$CrowdHc      <-z2$CrowdH      -mean(z2$CrowdH      ,na.rm=T)
z2$MobileTc     <-z2$MobileT     -mean(z2$MobileT     ,na.rm=T)
z2$MobileWc     <-z2$MobileW     -mean(z2$MobileW     ,na.rm=T)
z2$MobileBc     <-z2$MobileB     -mean(z2$MobileB     ,na.rm=T)
z2$MobileHc     <-z2$MobileH     -mean(z2$MobileH     ,na.rm=T)
z2$DisablTc     <-z2$DisablT     -mean(z2$DisablT     ,na.rm=T)
z2$DisablWc     <-z2$DisablW     -mean(z2$DisablW     ,na.rm=T)
z2$DisablBc     <-z2$DisablB     -mean(z2$DisablB     ,na.rm=T)
z2$DisablHc     <-z2$DisablH     -mean(z2$DisablH     ,na.rm=T)
z2$DisablTCc    <-z2$DisablTC    -mean(z2$DisablTC    ,na.rm=T)
z2$DisablWCc    <-z2$DisablWC    -mean(z2$DisablWC    ,na.rm=T)
z2$DisablBCc    <-z2$DisablBC    -mean(z2$DisablBC    ,na.rm=T)
z2$DisablHCc    <-z2$DisablHC    -mean(z2$DisablHC    ,na.rm=T)
z2$DisablTMc    <-z2$DisablTM    -mean(z2$DisablTM    ,na.rm=T)
z2$DisablTFc    <-z2$DisablTF    -mean(z2$DisablTF    ,na.rm=T)
z2$Urban1c      <-z2$Urban1      -mean(z2$Urban1      ,na.rm=T)
z2$Urban2c      <-z2$Urban2      -mean(z2$Urban2      ,na.rm=T)
z2$ISBE_PFAc    <-z2$ISBE_PFA    -mean(z2$ISBE_PFA    ,na.rm=T)
z2$ISBE_PFAEc   <-z2$ISBE_PFAE   -mean(z2$ISBE_PFAE   ,na.rm=T)
z2$ISBE_PIc     <-z2$ISBE_PI     -mean(z2$ISBE_PI     ,na.rm=T)
z2$HeadStartc   <-z2$HeadStart   -mean(z2$HeadStart   ,na.rm=T)
z2$ElyHeadSc    <-z2$ElyHeadS    -mean(z2$ElyHeadS    ,na.rm=T)
z2$HeadSAllc    <-z2$HeadSAll    -mean(z2$HeadSAll    ,na.rm=T)
z2$PFA_HS1c     <-z2$PFA_HS1     -mean(z2$PFA_HS1     ,na.rm=T)
z2$PFA_HS2c     <-z2$PFA_HS2     -mean(z2$PFA_HS2     ,na.rm=T)
z2$LCCCc        <-z2$LCCC        -mean(z2$LCCC        ,na.rm=T)
z2$LECCCc       <-z2$LECCC       -mean(z2$LECCC       ,na.rm=T)
z2$LFCCc        <-z2$LFCC        -mean(z2$LFCC        ,na.rm=T)
z2$LLECCCc      <-z2$LLECCC      -mean(z2$LLECCC      ,na.rm=T)
z2$LCLFCCc      <-z2$LCLFCC      -mean(z2$LCLFCC      ,na.rm=T)
z2$LCCCB1c      <-z2$LCCCB1      -mean(z2$LCCCB1      ,na.rm=T)
z2$LCCCB2c      <-z2$LCCCB2      -mean(z2$LCCCB2      ,na.rm=T)
z2$LCCB1c       <-z2$LCCB1       -mean(z2$LCCB1       ,na.rm=T)
z2$LCCB2c       <-z2$LCCB2       -mean(z2$LCCB2       ,na.rm=T)
z2$LCCCS1c      <-z2$LCCCS1      -mean(z2$LCCCS1      ,na.rm=T)
z2$LCCCS2c      <-z2$LCCCS2      -mean(z2$LCCCS2      ,na.rm=T)
z2$LCCS1c       <-z2$LCCS1       -mean(z2$LCCS1       ,na.rm=T)
z2$LCCS2c       <-z2$LCCS2       -mean(z2$LCCS2       ,na.rm=T)
z2$LCCCG1c      <-z2$LCCCG1      -mean(z2$LCCCG1      ,na.rm=T)
z2$LCCCG2c      <-z2$LCCCG2      -mean(z2$LCCCG2      ,na.rm=T)
z2$LCCG1c       <-z2$LCCG1       -mean(z2$LCCG1       ,na.rm=T)
z2$LCCG2c       <-z2$LCCG2       -mean(z2$LCCG2       ,na.rm=T)
z2$ChildCare1c  <-z2$ChildCare1  -mean(z2$ChildCare1  ,na.rm=T)
z2$ChildCare2c  <-z2$ChildCare2  -mean(z2$ChildCare2  ,na.rm=T)
z2$ChildCare3c  <-z2$ChildCare3  -mean(z2$ChildCare3  ,na.rm=T)
z2$CCAPc        <-z2$CCAP        -mean(z2$CCAP        ,na.rm=T)
z2$Homelessc    <-z2$Homeless    -mean(z2$Homeless    ,na.rm=T)
z2$Homeless2c   <-z2$Homeless2   -mean(z2$Homeless2   ,na.rm=T)
z2$DHS_HFIrc    <-z2$DHS_HFIr    -mean(z2$DHS_HFIr    ,na.rm=T)
z2$DHS_PTSrc    <-z2$DHS_PTSr    -mean(z2$DHS_PTSr    ,na.rm=T)
z2$DHS_HVPrc    <-z2$DHS_HVPr    -mean(z2$DHS_HVPr    ,na.rm=T)
z2$IDHS_EIrc    <-z2$IDHS_EIr    -mean(z2$IDHS_EIr    ,na.rm=T)
z2$MHV_C4c      <-z2$MHV_C4      -mean(z2$MHV_C4      ,na.rm=T)
z2$MHV_P4c      <-z2$MHV_P4      -mean(z2$MHV_P4      ,na.rm=T)
z2$MHV_C5c      <-z2$MHV_C5      -mean(z2$MHV_C5      ,na.rm=T)
z2$MHV_P5c      <-z2$MHV_P5      -mean(z2$MHV_P5      ,na.rm=T)
z2$FoodInsPc    <-z2$FoodInsP    -mean(z2$FoodInsP    ,na.rm=T)
z2$FoodISc      <-z2$FoodIS      -mean(z2$FoodIS      ,na.rm=T)





# demean - within and between variables
z2<-cbind(z2,demean(z2,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Age 12-17
# Food Insecurity - Age 12-17
# Food Insecurity - Age 12-17
# Food Insecurity - Age 12-17
# Food Insecurity - Age 12-17
# Food Insecurity - Age 12-17
# Food Insecurity - Age 12-17
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
z3$Yearc        <-z3$Year        -mean(z3$Year        ,na.rm=T)
z3$CPopBPc      <-z3$CPopBP      -mean(z3$CPopBP      ,na.rm=T)
z3$CPopHPc      <-z3$CPopHP      -mean(z3$CPopHP      ,na.rm=T)
z3$ChildPTc     <-z3$ChildPT     -mean(z3$ChildPT     ,na.rm=T)
z3$ChildPWc     <-z3$ChildPW     -mean(z3$ChildPW     ,na.rm=T)
z3$ChildPBc     <-z3$ChildPB     -mean(z3$ChildPB     ,na.rm=T)
z3$ChildPHc     <-z3$ChildPH     -mean(z3$ChildPH     ,na.rm=T)
z3$CARatioT100c <-z3$CARatioT100 -mean(z3$CARatioT100 ,na.rm=T)
z3$CARatioW100c <-z3$CARatioW100 -mean(z3$CARatioW100 ,na.rm=T)
z3$CARatioB100c <-z3$CARatioB100 -mean(z3$CARatioB100 ,na.rm=T)
z3$CARatioH100c <-z3$CARatioH100 -mean(z3$CARatioH100 ,na.rm=T)
z3$MalePTc      <-z3$MalePT      -mean(z3$MalePT      ,na.rm=T)
z3$MalePWc      <-z3$MalePW      -mean(z3$MalePW      ,na.rm=T)
z3$MalePBc      <-z3$MalePB      -mean(z3$MalePB      ,na.rm=T)
z3$MalePHc      <-z3$MalePH      -mean(z3$MalePH      ,na.rm=T)
z3$MFRatioT100c <-z3$MFRatioT100 -mean(z3$MFRatioT100 ,na.rm=T)
z3$MFRatioW100c <-z3$MFRatioW100 -mean(z3$MFRatioW100 ,na.rm=T)
z3$MFRatioB100c <-z3$MFRatioB100 -mean(z3$MFRatioB100 ,na.rm=T)
z3$MFRatioH100c <-z3$MFRatioH100 -mean(z3$MFRatioH100 ,na.rm=T)
z3$ElderTc      <-z3$ElderT      -mean(z3$ElderT      ,na.rm=T)
z3$ElderWc      <-z3$ElderW      -mean(z3$ElderW      ,na.rm=T)
z3$ElderBc      <-z3$ElderB      -mean(z3$ElderB      ,na.rm=T)
z3$ElderHc      <-z3$ElderH      -mean(z3$ElderH      ,na.rm=T)
z3$SingleTc     <-z3$SingleT     -mean(z3$SingleT     ,na.rm=T)
z3$SingleWc     <-z3$SingleW     -mean(z3$SingleW     ,na.rm=T)
z3$SingleBc     <-z3$SingleB     -mean(z3$SingleB     ,na.rm=T)
z3$SingleHc     <-z3$SingleH     -mean(z3$SingleH     ,na.rm=T)
z3$FHeadTc      <-z3$FHeadT      -mean(z3$FHeadT      ,na.rm=T)
z3$FHeadWc      <-z3$FHeadW      -mean(z3$FHeadW      ,na.rm=T)
z3$FHeadBc      <-z3$FHeadB      -mean(z3$FHeadB      ,na.rm=T)
z3$FHeadHc      <-z3$FHeadH      -mean(z3$FHeadH      ,na.rm=T)
z3$NoHighTc     <-z3$NoHighT     -mean(z3$NoHighT     ,na.rm=T)
z3$NoHighWc     <-z3$NoHighW     -mean(z3$NoHighW     ,na.rm=T)
z3$NoHighBc     <-z3$NoHighB     -mean(z3$NoHighB     ,na.rm=T)
z3$NoHighHc     <-z3$NoHighH     -mean(z3$NoHighH     ,na.rm=T)
z3$UnempTc      <-z3$UnempT      -mean(z3$UnempT      ,na.rm=T)
z3$UnempWc      <-z3$UnempW      -mean(z3$UnempW      ,na.rm=T)
z3$UnempBc      <-z3$UnempB      -mean(z3$UnempB      ,na.rm=T)
z3$UnempHc      <-z3$UnempH      -mean(z3$UnempH      ,na.rm=T)
z3$CPovTc       <-z3$CPovT       -mean(z3$CPovT       ,na.rm=T)
z3$CPovWc       <-z3$CPovW       -mean(z3$CPovW       ,na.rm=T)
z3$CPovBc       <-z3$CPovB       -mean(z3$CPovB       ,na.rm=T)
z3$CPovHc       <-z3$CPovH       -mean(z3$CPovH       ,na.rm=T)
z3$CPov1c       <-z3$CPov1       -mean(z3$CPov1       ,na.rm=T)
z3$CPov2c       <-z3$CPov2       -mean(z3$CPov2       ,na.rm=T)
z3$CPov3c       <-z3$CPov3       -mean(z3$CPov3       ,na.rm=T)
z3$PubAsTc      <-z3$PubAsT      -mean(z3$PubAsT      ,na.rm=T)
z3$WelfarTc     <-z3$WelfarT     -mean(z3$WelfarT     ,na.rm=T)
z3$SnapTc       <-z3$SnapT       -mean(z3$SnapT       ,na.rm=T)
z3$SnapWc       <-z3$SnapW       -mean(z3$SnapW       ,na.rm=T)
z3$SnapBc       <-z3$SnapB       -mean(z3$SnapB       ,na.rm=T)
z3$SnapHc       <-z3$SnapH       -mean(z3$SnapH       ,na.rm=T)
z3$IncomeT1kc   <-z3$IncomeT1k   -mean(z3$IncomeT1k   ,na.rm=T)
z3$IncomeW1kc   <-z3$IncomeW1k   -mean(z3$IncomeW1k   ,na.rm=T)
z3$IncomeB1kc   <-z3$IncomeB1k   -mean(z3$IncomeB1k   ,na.rm=T)
z3$IncomeH1kc   <-z3$IncomeH1k   -mean(z3$IncomeH1k   ,na.rm=T)
z3$GiniT100c    <-z3$GiniT100    -mean(z3$GiniT100    ,na.rm=T)
z3$HValueT10kc  <-z3$HValueT10k  -mean(z3$HValueT10k  ,na.rm=T)
z3$MCostT100c   <-z3$MCostT100   -mean(z3$MCostT100   ,na.rm=T)
z3$OCostDT100c  <-z3$OCostDT100  -mean(z3$OCostDT100  ,na.rm=T)
z3$MRentDT100c  <-z3$MRentDT100  -mean(z3$MRentDT100  ,na.rm=T)
z3$OCostPTc     <-z3$OCostPT     -mean(z3$OCostPT     ,na.rm=T)
z3$MRentPTc     <-z3$MRentPT     -mean(z3$MRentPT     ,na.rm=T)
z3$MortgTc      <-z3$MortgT      -mean(z3$MortgT      ,na.rm=T)
z3$LangAPTc     <-z3$LangAPT     -mean(z3$LangAPT     ,na.rm=T)
z3$LangAPWc     <-z3$LangAPW     -mean(z3$LangAPW     ,na.rm=T)
z3$LangAPBc     <-z3$LangAPB     -mean(z3$LangAPB     ,na.rm=T)
z3$LangAPHc     <-z3$LangAPH     -mean(z3$LangAPH     ,na.rm=T)
z3$LangBPTc     <-z3$LangBPT     -mean(z3$LangBPT     ,na.rm=T)
z3$LangBPWc     <-z3$LangBPW     -mean(z3$LangBPW     ,na.rm=T)
z3$LangBPBc     <-z3$LangBPB     -mean(z3$LangBPB     ,na.rm=T)
z3$LangBPHc     <-z3$LangBPH     -mean(z3$LangBPH     ,na.rm=T)
z3$LangCPTc     <-z3$LangCPT     -mean(z3$LangCPT     ,na.rm=T)
z3$OutUsTc      <-z3$OutUsT      -mean(z3$OutUsT      ,na.rm=T)
z3$OutUsWc      <-z3$OutUsW      -mean(z3$OutUsW      ,na.rm=T)
z3$OutUsBc      <-z3$OutUsB      -mean(z3$OutUsB      ,na.rm=T)
z3$OutUsHc      <-z3$OutUsH      -mean(z3$OutUsH      ,na.rm=T)
z3$FBornTc      <-z3$FBornT      -mean(z3$FBornT      ,na.rm=T)
z3$FBornWc      <-z3$FBornW      -mean(z3$FBornW      ,na.rm=T)
z3$FBornBc      <-z3$FBornB      -mean(z3$FBornB      ,na.rm=T)
z3$FBornHc      <-z3$FBornH      -mean(z3$FBornH      ,na.rm=T)
z3$NotCtzTc     <-z3$NotCtzT     -mean(z3$NotCtzT     ,na.rm=T)
z3$NotCtzWc     <-z3$NotCtzW     -mean(z3$NotCtzW     ,na.rm=T)
z3$NotCtzBc     <-z3$NotCtzB     -mean(z3$NotCtzB     ,na.rm=T)
z3$NotCtzHc     <-z3$NotCtzH     -mean(z3$NotCtzH     ,na.rm=T)
z3$MoveTc       <-z3$MoveT       -mean(z3$MoveT       ,na.rm=T)
z3$MoveWc       <-z3$MoveW       -mean(z3$MoveW       ,na.rm=T)
z3$MoveBc       <-z3$MoveB       -mean(z3$MoveB       ,na.rm=T)
z3$MoveHc       <-z3$MoveH       -mean(z3$MoveH       ,na.rm=T)
z3$VacantTc     <-z3$VacantT     -mean(z3$VacantT     ,na.rm=T)
z3$OwnerTc      <-z3$OwnerT      -mean(z3$OwnerT      ,na.rm=T)
z3$OwnerWc      <-z3$OwnerW      -mean(z3$OwnerW      ,na.rm=T)
z3$OwnerBc      <-z3$OwnerB      -mean(z3$OwnerB      ,na.rm=T)
z3$OwnerHc      <-z3$OwnerH      -mean(z3$OwnerH      ,na.rm=T)
z3$CrowdTc      <-z3$CrowdT      -mean(z3$CrowdT      ,na.rm=T)
z3$CrowdWc      <-z3$CrowdW      -mean(z3$CrowdW      ,na.rm=T)
z3$CrowdBc      <-z3$CrowdB      -mean(z3$CrowdB      ,na.rm=T)
z3$CrowdHc      <-z3$CrowdH      -mean(z3$CrowdH      ,na.rm=T)
z3$MobileTc     <-z3$MobileT     -mean(z3$MobileT     ,na.rm=T)
z3$MobileWc     <-z3$MobileW     -mean(z3$MobileW     ,na.rm=T)
z3$MobileBc     <-z3$MobileB     -mean(z3$MobileB     ,na.rm=T)
z3$MobileHc     <-z3$MobileH     -mean(z3$MobileH     ,na.rm=T)
z3$DisablTc     <-z3$DisablT     -mean(z3$DisablT     ,na.rm=T)
z3$DisablWc     <-z3$DisablW     -mean(z3$DisablW     ,na.rm=T)
z3$DisablBc     <-z3$DisablB     -mean(z3$DisablB     ,na.rm=T)
z3$DisablHc     <-z3$DisablH     -mean(z3$DisablH     ,na.rm=T)
z3$DisablTCc    <-z3$DisablTC    -mean(z3$DisablTC    ,na.rm=T)
z3$DisablWCc    <-z3$DisablWC    -mean(z3$DisablWC    ,na.rm=T)
z3$DisablBCc    <-z3$DisablBC    -mean(z3$DisablBC    ,na.rm=T)
z3$DisablHCc    <-z3$DisablHC    -mean(z3$DisablHC    ,na.rm=T)
z3$DisablTMc    <-z3$DisablTM    -mean(z3$DisablTM    ,na.rm=T)
z3$DisablTFc    <-z3$DisablTF    -mean(z3$DisablTF    ,na.rm=T)
z3$Urban1c      <-z3$Urban1      -mean(z3$Urban1      ,na.rm=T)
z3$Urban2c      <-z3$Urban2      -mean(z3$Urban2      ,na.rm=T)
z3$ISBE_PFAc    <-z3$ISBE_PFA    -mean(z3$ISBE_PFA    ,na.rm=T)
z3$ISBE_PFAEc   <-z3$ISBE_PFAE   -mean(z3$ISBE_PFAE   ,na.rm=T)
z3$ISBE_PIc     <-z3$ISBE_PI     -mean(z3$ISBE_PI     ,na.rm=T)
z3$HeadStartc   <-z3$HeadStart   -mean(z3$HeadStart   ,na.rm=T)
z3$ElyHeadSc    <-z3$ElyHeadS    -mean(z3$ElyHeadS    ,na.rm=T)
z3$HeadSAllc    <-z3$HeadSAll    -mean(z3$HeadSAll    ,na.rm=T)
z3$PFA_HS1c     <-z3$PFA_HS1     -mean(z3$PFA_HS1     ,na.rm=T)
z3$PFA_HS2c     <-z3$PFA_HS2     -mean(z3$PFA_HS2     ,na.rm=T)
z3$LCCCc        <-z3$LCCC        -mean(z3$LCCC        ,na.rm=T)
z3$LECCCc       <-z3$LECCC       -mean(z3$LECCC       ,na.rm=T)
z3$LFCCc        <-z3$LFCC        -mean(z3$LFCC        ,na.rm=T)
z3$LLECCCc      <-z3$LLECCC      -mean(z3$LLECCC      ,na.rm=T)
z3$LCLFCCc      <-z3$LCLFCC      -mean(z3$LCLFCC      ,na.rm=T)
z3$LCCCB1c      <-z3$LCCCB1      -mean(z3$LCCCB1      ,na.rm=T)
z3$LCCCB2c      <-z3$LCCCB2      -mean(z3$LCCCB2      ,na.rm=T)
z3$LCCB1c       <-z3$LCCB1       -mean(z3$LCCB1       ,na.rm=T)
z3$LCCB2c       <-z3$LCCB2       -mean(z3$LCCB2       ,na.rm=T)
z3$LCCCS1c      <-z3$LCCCS1      -mean(z3$LCCCS1      ,na.rm=T)
z3$LCCCS2c      <-z3$LCCCS2      -mean(z3$LCCCS2      ,na.rm=T)
z3$LCCS1c       <-z3$LCCS1       -mean(z3$LCCS1       ,na.rm=T)
z3$LCCS2c       <-z3$LCCS2       -mean(z3$LCCS2       ,na.rm=T)
z3$LCCCG1c      <-z3$LCCCG1      -mean(z3$LCCCG1      ,na.rm=T)
z3$LCCCG2c      <-z3$LCCCG2      -mean(z3$LCCCG2      ,na.rm=T)
z3$LCCG1c       <-z3$LCCG1       -mean(z3$LCCG1       ,na.rm=T)
z3$LCCG2c       <-z3$LCCG2       -mean(z3$LCCG2       ,na.rm=T)
z3$ChildCare1c  <-z3$ChildCare1  -mean(z3$ChildCare1  ,na.rm=T)
z3$ChildCare2c  <-z3$ChildCare2  -mean(z3$ChildCare2  ,na.rm=T)
z3$ChildCare3c  <-z3$ChildCare3  -mean(z3$ChildCare3  ,na.rm=T)
z3$CCAPc        <-z3$CCAP        -mean(z3$CCAP        ,na.rm=T)
z3$Homelessc    <-z3$Homeless    -mean(z3$Homeless    ,na.rm=T)
z3$Homeless2c   <-z3$Homeless2   -mean(z3$Homeless2   ,na.rm=T)
z3$DHS_HFIrc    <-z3$DHS_HFIr    -mean(z3$DHS_HFIr    ,na.rm=T)
z3$DHS_PTSrc    <-z3$DHS_PTSr    -mean(z3$DHS_PTSr    ,na.rm=T)
z3$DHS_HVPrc    <-z3$DHS_HVPr    -mean(z3$DHS_HVPr    ,na.rm=T)
z3$IDHS_EIrc    <-z3$IDHS_EIr    -mean(z3$IDHS_EIr    ,na.rm=T)
z3$MHV_C4c      <-z3$MHV_C4      -mean(z3$MHV_C4      ,na.rm=T)
z3$MHV_P4c      <-z3$MHV_P4      -mean(z3$MHV_P4      ,na.rm=T)
z3$MHV_C5c      <-z3$MHV_C5      -mean(z3$MHV_C5      ,na.rm=T)
z3$MHV_P5c      <-z3$MHV_P5      -mean(z3$MHV_P5      ,na.rm=T)
z3$FoodInsPc    <-z3$FoodInsP    -mean(z3$FoodInsP    ,na.rm=T)
z3$FoodISc      <-z3$FoodIS      -mean(z3$FoodIS      ,na.rm=T)





# demean - within and between variables
z3<-cbind(z3,demean(z3,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Male Children
# Food Insecurity - Male Children
# Food Insecurity - Male Children
# Food Insecurity - Male Children
# Food Insecurity - Male Children
# Food Insecurity - Male Children
# Food Insecurity - Male Children
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
zm$Yearc        <-zm$Year        -mean(zm$Year        ,na.rm=T)
zm$CPopBPc      <-zm$CPopBP      -mean(zm$CPopBP      ,na.rm=T)
zm$CPopHPc      <-zm$CPopHP      -mean(zm$CPopHP      ,na.rm=T)
zm$ChildPTc     <-zm$ChildPT     -mean(zm$ChildPT     ,na.rm=T)
zm$ChildPWc     <-zm$ChildPW     -mean(zm$ChildPW     ,na.rm=T)
zm$ChildPBc     <-zm$ChildPB     -mean(zm$ChildPB     ,na.rm=T)
zm$ChildPHc     <-zm$ChildPH     -mean(zm$ChildPH     ,na.rm=T)
zm$CARatioT100c <-zm$CARatioT100 -mean(zm$CARatioT100 ,na.rm=T)
zm$CARatioW100c <-zm$CARatioW100 -mean(zm$CARatioW100 ,na.rm=T)
zm$CARatioB100c <-zm$CARatioB100 -mean(zm$CARatioB100 ,na.rm=T)
zm$CARatioH100c <-zm$CARatioH100 -mean(zm$CARatioH100 ,na.rm=T)
zm$MalePTc      <-zm$MalePT      -mean(zm$MalePT      ,na.rm=T)
zm$MalePWc      <-zm$MalePW      -mean(zm$MalePW      ,na.rm=T)
zm$MalePBc      <-zm$MalePB      -mean(zm$MalePB      ,na.rm=T)
zm$MalePHc      <-zm$MalePH      -mean(zm$MalePH      ,na.rm=T)
zm$MFRatioT100c <-zm$MFRatioT100 -mean(zm$MFRatioT100 ,na.rm=T)
zm$MFRatioW100c <-zm$MFRatioW100 -mean(zm$MFRatioW100 ,na.rm=T)
zm$MFRatioB100c <-zm$MFRatioB100 -mean(zm$MFRatioB100 ,na.rm=T)
zm$MFRatioH100c <-zm$MFRatioH100 -mean(zm$MFRatioH100 ,na.rm=T)
zm$ElderTc      <-zm$ElderT      -mean(zm$ElderT      ,na.rm=T)
zm$ElderWc      <-zm$ElderW      -mean(zm$ElderW      ,na.rm=T)
zm$ElderBc      <-zm$ElderB      -mean(zm$ElderB      ,na.rm=T)
zm$ElderHc      <-zm$ElderH      -mean(zm$ElderH      ,na.rm=T)
zm$SingleTc     <-zm$SingleT     -mean(zm$SingleT     ,na.rm=T)
zm$SingleWc     <-zm$SingleW     -mean(zm$SingleW     ,na.rm=T)
zm$SingleBc     <-zm$SingleB     -mean(zm$SingleB     ,na.rm=T)
zm$SingleHc     <-zm$SingleH     -mean(zm$SingleH     ,na.rm=T)
zm$FHeadTc      <-zm$FHeadT      -mean(zm$FHeadT      ,na.rm=T)
zm$FHeadWc      <-zm$FHeadW      -mean(zm$FHeadW      ,na.rm=T)
zm$FHeadBc      <-zm$FHeadB      -mean(zm$FHeadB      ,na.rm=T)
zm$FHeadHc      <-zm$FHeadH      -mean(zm$FHeadH      ,na.rm=T)
zm$NoHighTc     <-zm$NoHighT     -mean(zm$NoHighT     ,na.rm=T)
zm$NoHighWc     <-zm$NoHighW     -mean(zm$NoHighW     ,na.rm=T)
zm$NoHighBc     <-zm$NoHighB     -mean(zm$NoHighB     ,na.rm=T)
zm$NoHighHc     <-zm$NoHighH     -mean(zm$NoHighH     ,na.rm=T)
zm$UnempTc      <-zm$UnempT      -mean(zm$UnempT      ,na.rm=T)
zm$UnempWc      <-zm$UnempW      -mean(zm$UnempW      ,na.rm=T)
zm$UnempBc      <-zm$UnempB      -mean(zm$UnempB      ,na.rm=T)
zm$UnempHc      <-zm$UnempH      -mean(zm$UnempH      ,na.rm=T)
zm$CPovTc       <-zm$CPovT       -mean(zm$CPovT       ,na.rm=T)
zm$CPovWc       <-zm$CPovW       -mean(zm$CPovW       ,na.rm=T)
zm$CPovBc       <-zm$CPovB       -mean(zm$CPovB       ,na.rm=T)
zm$CPovHc       <-zm$CPovH       -mean(zm$CPovH       ,na.rm=T)
zm$CPov1c       <-zm$CPov1       -mean(zm$CPov1       ,na.rm=T)
zm$CPov2c       <-zm$CPov2       -mean(zm$CPov2       ,na.rm=T)
zm$CPov3c       <-zm$CPov3       -mean(zm$CPov3       ,na.rm=T)
zm$PubAsTc      <-zm$PubAsT      -mean(zm$PubAsT      ,na.rm=T)
zm$WelfarTc     <-zm$WelfarT     -mean(zm$WelfarT     ,na.rm=T)
zm$SnapTc       <-zm$SnapT       -mean(zm$SnapT       ,na.rm=T)
zm$SnapWc       <-zm$SnapW       -mean(zm$SnapW       ,na.rm=T)
zm$SnapBc       <-zm$SnapB       -mean(zm$SnapB       ,na.rm=T)
zm$SnapHc       <-zm$SnapH       -mean(zm$SnapH       ,na.rm=T)
zm$IncomeT1kc   <-zm$IncomeT1k   -mean(zm$IncomeT1k   ,na.rm=T)
zm$IncomeW1kc   <-zm$IncomeW1k   -mean(zm$IncomeW1k   ,na.rm=T)
zm$IncomeB1kc   <-zm$IncomeB1k   -mean(zm$IncomeB1k   ,na.rm=T)
zm$IncomeH1kc   <-zm$IncomeH1k   -mean(zm$IncomeH1k   ,na.rm=T)
zm$GiniT100c    <-zm$GiniT100    -mean(zm$GiniT100    ,na.rm=T)
zm$HValueT10kc  <-zm$HValueT10k  -mean(zm$HValueT10k  ,na.rm=T)
zm$MCostT100c   <-zm$MCostT100   -mean(zm$MCostT100   ,na.rm=T)
zm$OCostDT100c  <-zm$OCostDT100  -mean(zm$OCostDT100  ,na.rm=T)
zm$MRentDT100c  <-zm$MRentDT100  -mean(zm$MRentDT100  ,na.rm=T)
zm$OCostPTc     <-zm$OCostPT     -mean(zm$OCostPT     ,na.rm=T)
zm$MRentPTc     <-zm$MRentPT     -mean(zm$MRentPT     ,na.rm=T)
zm$MortgTc      <-zm$MortgT      -mean(zm$MortgT      ,na.rm=T)
zm$LangAPTc     <-zm$LangAPT     -mean(zm$LangAPT     ,na.rm=T)
zm$LangAPWc     <-zm$LangAPW     -mean(zm$LangAPW     ,na.rm=T)
zm$LangAPBc     <-zm$LangAPB     -mean(zm$LangAPB     ,na.rm=T)
zm$LangAPHc     <-zm$LangAPH     -mean(zm$LangAPH     ,na.rm=T)
zm$LangBPTc     <-zm$LangBPT     -mean(zm$LangBPT     ,na.rm=T)
zm$LangBPWc     <-zm$LangBPW     -mean(zm$LangBPW     ,na.rm=T)
zm$LangBPBc     <-zm$LangBPB     -mean(zm$LangBPB     ,na.rm=T)
zm$LangBPHc     <-zm$LangBPH     -mean(zm$LangBPH     ,na.rm=T)
zm$LangCPTc     <-zm$LangCPT     -mean(zm$LangCPT     ,na.rm=T)
zm$OutUsTc      <-zm$OutUsT      -mean(zm$OutUsT      ,na.rm=T)
zm$OutUsWc      <-zm$OutUsW      -mean(zm$OutUsW      ,na.rm=T)
zm$OutUsBc      <-zm$OutUsB      -mean(zm$OutUsB      ,na.rm=T)
zm$OutUsHc      <-zm$OutUsH      -mean(zm$OutUsH      ,na.rm=T)
zm$FBornTc      <-zm$FBornT      -mean(zm$FBornT      ,na.rm=T)
zm$FBornWc      <-zm$FBornW      -mean(zm$FBornW      ,na.rm=T)
zm$FBornBc      <-zm$FBornB      -mean(zm$FBornB      ,na.rm=T)
zm$FBornHc      <-zm$FBornH      -mean(zm$FBornH      ,na.rm=T)
zm$NotCtzTc     <-zm$NotCtzT     -mean(zm$NotCtzT     ,na.rm=T)
zm$NotCtzWc     <-zm$NotCtzW     -mean(zm$NotCtzW     ,na.rm=T)
zm$NotCtzBc     <-zm$NotCtzB     -mean(zm$NotCtzB     ,na.rm=T)
zm$NotCtzHc     <-zm$NotCtzH     -mean(zm$NotCtzH     ,na.rm=T)
zm$MoveTc       <-zm$MoveT       -mean(zm$MoveT       ,na.rm=T)
zm$MoveWc       <-zm$MoveW       -mean(zm$MoveW       ,na.rm=T)
zm$MoveBc       <-zm$MoveB       -mean(zm$MoveB       ,na.rm=T)
zm$MoveHc       <-zm$MoveH       -mean(zm$MoveH       ,na.rm=T)
zm$VacantTc     <-zm$VacantT     -mean(zm$VacantT     ,na.rm=T)
zm$OwnerTc      <-zm$OwnerT      -mean(zm$OwnerT      ,na.rm=T)
zm$OwnerWc      <-zm$OwnerW      -mean(zm$OwnerW      ,na.rm=T)
zm$OwnerBc      <-zm$OwnerB      -mean(zm$OwnerB      ,na.rm=T)
zm$OwnerHc      <-zm$OwnerH      -mean(zm$OwnerH      ,na.rm=T)
zm$CrowdTc      <-zm$CrowdT      -mean(zm$CrowdT      ,na.rm=T)
zm$CrowdWc      <-zm$CrowdW      -mean(zm$CrowdW      ,na.rm=T)
zm$CrowdBc      <-zm$CrowdB      -mean(zm$CrowdB      ,na.rm=T)
zm$CrowdHc      <-zm$CrowdH      -mean(zm$CrowdH      ,na.rm=T)
zm$MobileTc     <-zm$MobileT     -mean(zm$MobileT     ,na.rm=T)
zm$MobileWc     <-zm$MobileW     -mean(zm$MobileW     ,na.rm=T)
zm$MobileBc     <-zm$MobileB     -mean(zm$MobileB     ,na.rm=T)
zm$MobileHc     <-zm$MobileH     -mean(zm$MobileH     ,na.rm=T)
zm$DisablTc     <-zm$DisablT     -mean(zm$DisablT     ,na.rm=T)
zm$DisablWc     <-zm$DisablW     -mean(zm$DisablW     ,na.rm=T)
zm$DisablBc     <-zm$DisablB     -mean(zm$DisablB     ,na.rm=T)
zm$DisablHc     <-zm$DisablH     -mean(zm$DisablH     ,na.rm=T)
zm$DisablTCc    <-zm$DisablTC    -mean(zm$DisablTC    ,na.rm=T)
zm$DisablWCc    <-zm$DisablWC    -mean(zm$DisablWC    ,na.rm=T)
zm$DisablBCc    <-zm$DisablBC    -mean(zm$DisablBC    ,na.rm=T)
zm$DisablHCc    <-zm$DisablHC    -mean(zm$DisablHC    ,na.rm=T)
zm$DisablTMc    <-zm$DisablTM    -mean(zm$DisablTM    ,na.rm=T)
zm$DisablTFc    <-zm$DisablTF    -mean(zm$DisablTF    ,na.rm=T)
zm$Urban1c      <-zm$Urban1      -mean(zm$Urban1      ,na.rm=T)
zm$Urban2c      <-zm$Urban2      -mean(zm$Urban2      ,na.rm=T)
zm$ISBE_PFAc    <-zm$ISBE_PFA    -mean(zm$ISBE_PFA    ,na.rm=T)
zm$ISBE_PFAEc   <-zm$ISBE_PFAE   -mean(zm$ISBE_PFAE   ,na.rm=T)
zm$ISBE_PIc     <-zm$ISBE_PI     -mean(zm$ISBE_PI     ,na.rm=T)
zm$HeadStartc   <-zm$HeadStart   -mean(zm$HeadStart   ,na.rm=T)
zm$ElyHeadSc    <-zm$ElyHeadS    -mean(zm$ElyHeadS    ,na.rm=T)
zm$HeadSAllc    <-zm$HeadSAll    -mean(zm$HeadSAll    ,na.rm=T)
zm$PFA_HS1c     <-zm$PFA_HS1     -mean(zm$PFA_HS1     ,na.rm=T)
zm$PFA_HS2c     <-zm$PFA_HS2     -mean(zm$PFA_HS2     ,na.rm=T)
zm$LCCCc        <-zm$LCCC        -mean(zm$LCCC        ,na.rm=T)
zm$LECCCc       <-zm$LECCC       -mean(zm$LECCC       ,na.rm=T)
zm$LFCCc        <-zm$LFCC        -mean(zm$LFCC        ,na.rm=T)
zm$LLECCCc      <-zm$LLECCC      -mean(zm$LLECCC      ,na.rm=T)
zm$LCLFCCc      <-zm$LCLFCC      -mean(zm$LCLFCC      ,na.rm=T)
zm$LCCCB1c      <-zm$LCCCB1      -mean(zm$LCCCB1      ,na.rm=T)
zm$LCCCB2c      <-zm$LCCCB2      -mean(zm$LCCCB2      ,na.rm=T)
zm$LCCB1c       <-zm$LCCB1       -mean(zm$LCCB1       ,na.rm=T)
zm$LCCB2c       <-zm$LCCB2       -mean(zm$LCCB2       ,na.rm=T)
zm$LCCCS1c      <-zm$LCCCS1      -mean(zm$LCCCS1      ,na.rm=T)
zm$LCCCS2c      <-zm$LCCCS2      -mean(zm$LCCCS2      ,na.rm=T)
zm$LCCS1c       <-zm$LCCS1       -mean(zm$LCCS1       ,na.rm=T)
zm$LCCS2c       <-zm$LCCS2       -mean(zm$LCCS2       ,na.rm=T)
zm$LCCCG1c      <-zm$LCCCG1      -mean(zm$LCCCG1      ,na.rm=T)
zm$LCCCG2c      <-zm$LCCCG2      -mean(zm$LCCCG2      ,na.rm=T)
zm$LCCG1c       <-zm$LCCG1       -mean(zm$LCCG1       ,na.rm=T)
zm$LCCG2c       <-zm$LCCG2       -mean(zm$LCCG2       ,na.rm=T)
zm$ChildCare1c  <-zm$ChildCare1  -mean(zm$ChildCare1  ,na.rm=T)
zm$ChildCare2c  <-zm$ChildCare2  -mean(zm$ChildCare2  ,na.rm=T)
zm$ChildCare3c  <-zm$ChildCare3  -mean(zm$ChildCare3  ,na.rm=T)
zm$CCAPc        <-zm$CCAP        -mean(zm$CCAP        ,na.rm=T)
zm$Homelessc    <-zm$Homeless    -mean(zm$Homeless    ,na.rm=T)
zm$Homeless2c   <-zm$Homeless2   -mean(zm$Homeless2   ,na.rm=T)
zm$DHS_HFIrc    <-zm$DHS_HFIr    -mean(zm$DHS_HFIr    ,na.rm=T)
zm$DHS_PTSrc    <-zm$DHS_PTSr    -mean(zm$DHS_PTSr    ,na.rm=T)
zm$DHS_HVPrc    <-zm$DHS_HVPr    -mean(zm$DHS_HVPr    ,na.rm=T)
zm$IDHS_EIrc    <-zm$IDHS_EIr    -mean(zm$IDHS_EIr    ,na.rm=T)
zm$MHV_C4c      <-zm$MHV_C4      -mean(zm$MHV_C4      ,na.rm=T)
zm$MHV_P4c      <-zm$MHV_P4      -mean(zm$MHV_P4      ,na.rm=T)
zm$MHV_C5c      <-zm$MHV_C5      -mean(zm$MHV_C5      ,na.rm=T)
zm$MHV_P5c      <-zm$MHV_P5      -mean(zm$MHV_P5      ,na.rm=T)
zm$FoodInsPc    <-zm$FoodInsP    -mean(zm$FoodInsP    ,na.rm=T)
zm$FoodISc      <-zm$FoodIS      -mean(zm$FoodIS      ,na.rm=T)





# demean - within and between variables
zm<-cbind(zm,demean(zm,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Female Children
# Food Insecurity - Female Children
# Food Insecurity - Female Children
# Food Insecurity - Female Children
# Food Insecurity - Female Children
# Food Insecurity - Female Children
# Food Insecurity - Female Children
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
zf$Yearc        <-zf$Year        -mean(zf$Year        ,na.rm=T)
zf$CPopBPc      <-zf$CPopBP      -mean(zf$CPopBP      ,na.rm=T)
zf$CPopHPc      <-zf$CPopHP      -mean(zf$CPopHP      ,na.rm=T)
zf$ChildPTc     <-zf$ChildPT     -mean(zf$ChildPT     ,na.rm=T)
zf$ChildPWc     <-zf$ChildPW     -mean(zf$ChildPW     ,na.rm=T)
zf$ChildPBc     <-zf$ChildPB     -mean(zf$ChildPB     ,na.rm=T)
zf$ChildPHc     <-zf$ChildPH     -mean(zf$ChildPH     ,na.rm=T)
zf$CARatioT100c <-zf$CARatioT100 -mean(zf$CARatioT100 ,na.rm=T)
zf$CARatioW100c <-zf$CARatioW100 -mean(zf$CARatioW100 ,na.rm=T)
zf$CARatioB100c <-zf$CARatioB100 -mean(zf$CARatioB100 ,na.rm=T)
zf$CARatioH100c <-zf$CARatioH100 -mean(zf$CARatioH100 ,na.rm=T)
zf$MalePTc      <-zf$MalePT      -mean(zf$MalePT      ,na.rm=T)
zf$MalePWc      <-zf$MalePW      -mean(zf$MalePW      ,na.rm=T)
zf$MalePBc      <-zf$MalePB      -mean(zf$MalePB      ,na.rm=T)
zf$MalePHc      <-zf$MalePH      -mean(zf$MalePH      ,na.rm=T)
zf$MFRatioT100c <-zf$MFRatioT100 -mean(zf$MFRatioT100 ,na.rm=T)
zf$MFRatioW100c <-zf$MFRatioW100 -mean(zf$MFRatioW100 ,na.rm=T)
zf$MFRatioB100c <-zf$MFRatioB100 -mean(zf$MFRatioB100 ,na.rm=T)
zf$MFRatioH100c <-zf$MFRatioH100 -mean(zf$MFRatioH100 ,na.rm=T)
zf$ElderTc      <-zf$ElderT      -mean(zf$ElderT      ,na.rm=T)
zf$ElderWc      <-zf$ElderW      -mean(zf$ElderW      ,na.rm=T)
zf$ElderBc      <-zf$ElderB      -mean(zf$ElderB      ,na.rm=T)
zf$ElderHc      <-zf$ElderH      -mean(zf$ElderH      ,na.rm=T)
zf$SingleTc     <-zf$SingleT     -mean(zf$SingleT     ,na.rm=T)
zf$SingleWc     <-zf$SingleW     -mean(zf$SingleW     ,na.rm=T)
zf$SingleBc     <-zf$SingleB     -mean(zf$SingleB     ,na.rm=T)
zf$SingleHc     <-zf$SingleH     -mean(zf$SingleH     ,na.rm=T)
zf$FHeadTc      <-zf$FHeadT      -mean(zf$FHeadT      ,na.rm=T)
zf$FHeadWc      <-zf$FHeadW      -mean(zf$FHeadW      ,na.rm=T)
zf$FHeadBc      <-zf$FHeadB      -mean(zf$FHeadB      ,na.rm=T)
zf$FHeadHc      <-zf$FHeadH      -mean(zf$FHeadH      ,na.rm=T)
zf$NoHighTc     <-zf$NoHighT     -mean(zf$NoHighT     ,na.rm=T)
zf$NoHighWc     <-zf$NoHighW     -mean(zf$NoHighW     ,na.rm=T)
zf$NoHighBc     <-zf$NoHighB     -mean(zf$NoHighB     ,na.rm=T)
zf$NoHighHc     <-zf$NoHighH     -mean(zf$NoHighH     ,na.rm=T)
zf$UnempTc      <-zf$UnempT      -mean(zf$UnempT      ,na.rm=T)
zf$UnempWc      <-zf$UnempW      -mean(zf$UnempW      ,na.rm=T)
zf$UnempBc      <-zf$UnempB      -mean(zf$UnempB      ,na.rm=T)
zf$UnempHc      <-zf$UnempH      -mean(zf$UnempH      ,na.rm=T)
zf$CPovTc       <-zf$CPovT       -mean(zf$CPovT       ,na.rm=T)
zf$CPovWc       <-zf$CPovW       -mean(zf$CPovW       ,na.rm=T)
zf$CPovBc       <-zf$CPovB       -mean(zf$CPovB       ,na.rm=T)
zf$CPovHc       <-zf$CPovH       -mean(zf$CPovH       ,na.rm=T)
zf$CPov1c       <-zf$CPov1       -mean(zf$CPov1       ,na.rm=T)
zf$CPov2c       <-zf$CPov2       -mean(zf$CPov2       ,na.rm=T)
zf$CPov3c       <-zf$CPov3       -mean(zf$CPov3       ,na.rm=T)
zf$PubAsTc      <-zf$PubAsT      -mean(zf$PubAsT      ,na.rm=T)
zf$WelfarTc     <-zf$WelfarT     -mean(zf$WelfarT     ,na.rm=T)
zf$SnapTc       <-zf$SnapT       -mean(zf$SnapT       ,na.rm=T)
zf$SnapWc       <-zf$SnapW       -mean(zf$SnapW       ,na.rm=T)
zf$SnapBc       <-zf$SnapB       -mean(zf$SnapB       ,na.rm=T)
zf$SnapHc       <-zf$SnapH       -mean(zf$SnapH       ,na.rm=T)
zf$IncomeT1kc   <-zf$IncomeT1k   -mean(zf$IncomeT1k   ,na.rm=T)
zf$IncomeW1kc   <-zf$IncomeW1k   -mean(zf$IncomeW1k   ,na.rm=T)
zf$IncomeB1kc   <-zf$IncomeB1k   -mean(zf$IncomeB1k   ,na.rm=T)
zf$IncomeH1kc   <-zf$IncomeH1k   -mean(zf$IncomeH1k   ,na.rm=T)
zf$GiniT100c    <-zf$GiniT100    -mean(zf$GiniT100    ,na.rm=T)
zf$HValueT10kc  <-zf$HValueT10k  -mean(zf$HValueT10k  ,na.rm=T)
zf$MCostT100c   <-zf$MCostT100   -mean(zf$MCostT100   ,na.rm=T)
zf$OCostDT100c  <-zf$OCostDT100  -mean(zf$OCostDT100  ,na.rm=T)
zf$MRentDT100c  <-zf$MRentDT100  -mean(zf$MRentDT100  ,na.rm=T)
zf$OCostPTc     <-zf$OCostPT     -mean(zf$OCostPT     ,na.rm=T)
zf$MRentPTc     <-zf$MRentPT     -mean(zf$MRentPT     ,na.rm=T)
zf$MortgTc      <-zf$MortgT      -mean(zf$MortgT      ,na.rm=T)
zf$LangAPTc     <-zf$LangAPT     -mean(zf$LangAPT     ,na.rm=T)
zf$LangAPWc     <-zf$LangAPW     -mean(zf$LangAPW     ,na.rm=T)
zf$LangAPBc     <-zf$LangAPB     -mean(zf$LangAPB     ,na.rm=T)
zf$LangAPHc     <-zf$LangAPH     -mean(zf$LangAPH     ,na.rm=T)
zf$LangBPTc     <-zf$LangBPT     -mean(zf$LangBPT     ,na.rm=T)
zf$LangBPWc     <-zf$LangBPW     -mean(zf$LangBPW     ,na.rm=T)
zf$LangBPBc     <-zf$LangBPB     -mean(zf$LangBPB     ,na.rm=T)
zf$LangBPHc     <-zf$LangBPH     -mean(zf$LangBPH     ,na.rm=T)
zf$LangCPTc     <-zf$LangCPT     -mean(zf$LangCPT     ,na.rm=T)
zf$OutUsTc      <-zf$OutUsT      -mean(zf$OutUsT      ,na.rm=T)
zf$OutUsWc      <-zf$OutUsW      -mean(zf$OutUsW      ,na.rm=T)
zf$OutUsBc      <-zf$OutUsB      -mean(zf$OutUsB      ,na.rm=T)
zf$OutUsHc      <-zf$OutUsH      -mean(zf$OutUsH      ,na.rm=T)
zf$FBornTc      <-zf$FBornT      -mean(zf$FBornT      ,na.rm=T)
zf$FBornWc      <-zf$FBornW      -mean(zf$FBornW      ,na.rm=T)
zf$FBornBc      <-zf$FBornB      -mean(zf$FBornB      ,na.rm=T)
zf$FBornHc      <-zf$FBornH      -mean(zf$FBornH      ,na.rm=T)
zf$NotCtzTc     <-zf$NotCtzT     -mean(zf$NotCtzT     ,na.rm=T)
zf$NotCtzWc     <-zf$NotCtzW     -mean(zf$NotCtzW     ,na.rm=T)
zf$NotCtzBc     <-zf$NotCtzB     -mean(zf$NotCtzB     ,na.rm=T)
zf$NotCtzHc     <-zf$NotCtzH     -mean(zf$NotCtzH     ,na.rm=T)
zf$MoveTc       <-zf$MoveT       -mean(zf$MoveT       ,na.rm=T)
zf$MoveWc       <-zf$MoveW       -mean(zf$MoveW       ,na.rm=T)
zf$MoveBc       <-zf$MoveB       -mean(zf$MoveB       ,na.rm=T)
zf$MoveHc       <-zf$MoveH       -mean(zf$MoveH       ,na.rm=T)
zf$VacantTc     <-zf$VacantT     -mean(zf$VacantT     ,na.rm=T)
zf$OwnerTc      <-zf$OwnerT      -mean(zf$OwnerT      ,na.rm=T)
zf$OwnerWc      <-zf$OwnerW      -mean(zf$OwnerW      ,na.rm=T)
zf$OwnerBc      <-zf$OwnerB      -mean(zf$OwnerB      ,na.rm=T)
zf$OwnerHc      <-zf$OwnerH      -mean(zf$OwnerH      ,na.rm=T)
zf$CrowdTc      <-zf$CrowdT      -mean(zf$CrowdT      ,na.rm=T)
zf$CrowdWc      <-zf$CrowdW      -mean(zf$CrowdW      ,na.rm=T)
zf$CrowdBc      <-zf$CrowdB      -mean(zf$CrowdB      ,na.rm=T)
zf$CrowdHc      <-zf$CrowdH      -mean(zf$CrowdH      ,na.rm=T)
zf$MobileTc     <-zf$MobileT     -mean(zf$MobileT     ,na.rm=T)
zf$MobileWc     <-zf$MobileW     -mean(zf$MobileW     ,na.rm=T)
zf$MobileBc     <-zf$MobileB     -mean(zf$MobileB     ,na.rm=T)
zf$MobileHc     <-zf$MobileH     -mean(zf$MobileH     ,na.rm=T)
zf$DisablTc     <-zf$DisablT     -mean(zf$DisablT     ,na.rm=T)
zf$DisablWc     <-zf$DisablW     -mean(zf$DisablW     ,na.rm=T)
zf$DisablBc     <-zf$DisablB     -mean(zf$DisablB     ,na.rm=T)
zf$DisablHc     <-zf$DisablH     -mean(zf$DisablH     ,na.rm=T)
zf$DisablTCc    <-zf$DisablTC    -mean(zf$DisablTC    ,na.rm=T)
zf$DisablWCc    <-zf$DisablWC    -mean(zf$DisablWC    ,na.rm=T)
zf$DisablBCc    <-zf$DisablBC    -mean(zf$DisablBC    ,na.rm=T)
zf$DisablHCc    <-zf$DisablHC    -mean(zf$DisablHC    ,na.rm=T)
zf$DisablTMc    <-zf$DisablTM    -mean(zf$DisablTM    ,na.rm=T)
zf$DisablTFc    <-zf$DisablTF    -mean(zf$DisablTF    ,na.rm=T)
zf$Urban1c      <-zf$Urban1      -mean(zf$Urban1      ,na.rm=T)
zf$Urban2c      <-zf$Urban2      -mean(zf$Urban2      ,na.rm=T)
zf$ISBE_PFAc    <-zf$ISBE_PFA    -mean(zf$ISBE_PFA    ,na.rm=T)
zf$ISBE_PFAEc   <-zf$ISBE_PFAE   -mean(zf$ISBE_PFAE   ,na.rm=T)
zf$ISBE_PIc     <-zf$ISBE_PI     -mean(zf$ISBE_PI     ,na.rm=T)
zf$HeadStartc   <-zf$HeadStart   -mean(zf$HeadStart   ,na.rm=T)
zf$ElyHeadSc    <-zf$ElyHeadS    -mean(zf$ElyHeadS    ,na.rm=T)
zf$HeadSAllc    <-zf$HeadSAll    -mean(zf$HeadSAll    ,na.rm=T)
zf$PFA_HS1c     <-zf$PFA_HS1     -mean(zf$PFA_HS1     ,na.rm=T)
zf$PFA_HS2c     <-zf$PFA_HS2     -mean(zf$PFA_HS2     ,na.rm=T)
zf$LCCCc        <-zf$LCCC        -mean(zf$LCCC        ,na.rm=T)
zf$LECCCc       <-zf$LECCC       -mean(zf$LECCC       ,na.rm=T)
zf$LFCCc        <-zf$LFCC        -mean(zf$LFCC        ,na.rm=T)
zf$LLECCCc      <-zf$LLECCC      -mean(zf$LLECCC      ,na.rm=T)
zf$LCLFCCc      <-zf$LCLFCC      -mean(zf$LCLFCC      ,na.rm=T)
zf$LCCCB1c      <-zf$LCCCB1      -mean(zf$LCCCB1      ,na.rm=T)
zf$LCCCB2c      <-zf$LCCCB2      -mean(zf$LCCCB2      ,na.rm=T)
zf$LCCB1c       <-zf$LCCB1       -mean(zf$LCCB1       ,na.rm=T)
zf$LCCB2c       <-zf$LCCB2       -mean(zf$LCCB2       ,na.rm=T)
zf$LCCCS1c      <-zf$LCCCS1      -mean(zf$LCCCS1      ,na.rm=T)
zf$LCCCS2c      <-zf$LCCCS2      -mean(zf$LCCCS2      ,na.rm=T)
zf$LCCS1c       <-zf$LCCS1       -mean(zf$LCCS1       ,na.rm=T)
zf$LCCS2c       <-zf$LCCS2       -mean(zf$LCCS2       ,na.rm=T)
zf$LCCCG1c      <-zf$LCCCG1      -mean(zf$LCCCG1      ,na.rm=T)
zf$LCCCG2c      <-zf$LCCCG2      -mean(zf$LCCCG2      ,na.rm=T)
zf$LCCG1c       <-zf$LCCG1       -mean(zf$LCCG1       ,na.rm=T)
zf$LCCG2c       <-zf$LCCG2       -mean(zf$LCCG2       ,na.rm=T)
zf$ChildCare1c  <-zf$ChildCare1  -mean(zf$ChildCare1  ,na.rm=T)
zf$ChildCare2c  <-zf$ChildCare2  -mean(zf$ChildCare2  ,na.rm=T)
zf$ChildCare3c  <-zf$ChildCare3  -mean(zf$ChildCare3  ,na.rm=T)
zf$CCAPc        <-zf$CCAP        -mean(zf$CCAP        ,na.rm=T)
zf$Homelessc    <-zf$Homeless    -mean(zf$Homeless    ,na.rm=T)
zf$Homeless2c   <-zf$Homeless2   -mean(zf$Homeless2   ,na.rm=T)
zf$DHS_HFIrc    <-zf$DHS_HFIr    -mean(zf$DHS_HFIr    ,na.rm=T)
zf$DHS_PTSrc    <-zf$DHS_PTSr    -mean(zf$DHS_PTSr    ,na.rm=T)
zf$DHS_HVPrc    <-zf$DHS_HVPr    -mean(zf$DHS_HVPr    ,na.rm=T)
zf$IDHS_EIrc    <-zf$IDHS_EIr    -mean(zf$IDHS_EIr    ,na.rm=T)
zf$MHV_C4c      <-zf$MHV_C4      -mean(zf$MHV_C4      ,na.rm=T)
zf$MHV_P4c      <-zf$MHV_P4      -mean(zf$MHV_P4      ,na.rm=T)
zf$MHV_C5c      <-zf$MHV_C5      -mean(zf$MHV_C5      ,na.rm=T)
zf$MHV_P5c      <-zf$MHV_P5      -mean(zf$MHV_P5      ,na.rm=T)
zf$FoodInsPc    <-zf$FoodInsP    -mean(zf$FoodInsP    ,na.rm=T)
zf$FoodISc      <-zf$FoodIS      -mean(zf$FoodIS      ,na.rm=T)





# demean - within and between variables
zf<-cbind(zf,demean(zf,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Neglect
# Food Insecurity - Neglect
# Food Insecurity - Neglect
# Food Insecurity - Neglect
# Food Insecurity - Neglect
# Food Insecurity - Neglect
# Food Insecurity - Neglect
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
zn$Yearc        <-zn$Year        -mean(zn$Year        ,na.rm=T)
zn$CPopBPc      <-zn$CPopBP      -mean(zn$CPopBP      ,na.rm=T)
zn$CPopHPc      <-zn$CPopHP      -mean(zn$CPopHP      ,na.rm=T)
zn$ChildPTc     <-zn$ChildPT     -mean(zn$ChildPT     ,na.rm=T)
zn$ChildPWc     <-zn$ChildPW     -mean(zn$ChildPW     ,na.rm=T)
zn$ChildPBc     <-zn$ChildPB     -mean(zn$ChildPB     ,na.rm=T)
zn$ChildPHc     <-zn$ChildPH     -mean(zn$ChildPH     ,na.rm=T)
zn$CARatioT100c <-zn$CARatioT100 -mean(zn$CARatioT100 ,na.rm=T)
zn$CARatioW100c <-zn$CARatioW100 -mean(zn$CARatioW100 ,na.rm=T)
zn$CARatioB100c <-zn$CARatioB100 -mean(zn$CARatioB100 ,na.rm=T)
zn$CARatioH100c <-zn$CARatioH100 -mean(zn$CARatioH100 ,na.rm=T)
zn$MalePTc      <-zn$MalePT      -mean(zn$MalePT      ,na.rm=T)
zn$MalePWc      <-zn$MalePW      -mean(zn$MalePW      ,na.rm=T)
zn$MalePBc      <-zn$MalePB      -mean(zn$MalePB      ,na.rm=T)
zn$MalePHc      <-zn$MalePH      -mean(zn$MalePH      ,na.rm=T)
zn$MFRatioT100c <-zn$MFRatioT100 -mean(zn$MFRatioT100 ,na.rm=T)
zn$MFRatioW100c <-zn$MFRatioW100 -mean(zn$MFRatioW100 ,na.rm=T)
zn$MFRatioB100c <-zn$MFRatioB100 -mean(zn$MFRatioB100 ,na.rm=T)
zn$MFRatioH100c <-zn$MFRatioH100 -mean(zn$MFRatioH100 ,na.rm=T)
zn$ElderTc      <-zn$ElderT      -mean(zn$ElderT      ,na.rm=T)
zn$ElderWc      <-zn$ElderW      -mean(zn$ElderW      ,na.rm=T)
zn$ElderBc      <-zn$ElderB      -mean(zn$ElderB      ,na.rm=T)
zn$ElderHc      <-zn$ElderH      -mean(zn$ElderH      ,na.rm=T)
zn$SingleTc     <-zn$SingleT     -mean(zn$SingleT     ,na.rm=T)
zn$SingleWc     <-zn$SingleW     -mean(zn$SingleW     ,na.rm=T)
zn$SingleBc     <-zn$SingleB     -mean(zn$SingleB     ,na.rm=T)
zn$SingleHc     <-zn$SingleH     -mean(zn$SingleH     ,na.rm=T)
zn$FHeadTc      <-zn$FHeadT      -mean(zn$FHeadT      ,na.rm=T)
zn$FHeadWc      <-zn$FHeadW      -mean(zn$FHeadW      ,na.rm=T)
zn$FHeadBc      <-zn$FHeadB      -mean(zn$FHeadB      ,na.rm=T)
zn$FHeadHc      <-zn$FHeadH      -mean(zn$FHeadH      ,na.rm=T)
zn$NoHighTc     <-zn$NoHighT     -mean(zn$NoHighT     ,na.rm=T)
zn$NoHighWc     <-zn$NoHighW     -mean(zn$NoHighW     ,na.rm=T)
zn$NoHighBc     <-zn$NoHighB     -mean(zn$NoHighB     ,na.rm=T)
zn$NoHighHc     <-zn$NoHighH     -mean(zn$NoHighH     ,na.rm=T)
zn$UnempTc      <-zn$UnempT      -mean(zn$UnempT      ,na.rm=T)
zn$UnempWc      <-zn$UnempW      -mean(zn$UnempW      ,na.rm=T)
zn$UnempBc      <-zn$UnempB      -mean(zn$UnempB      ,na.rm=T)
zn$UnempHc      <-zn$UnempH      -mean(zn$UnempH      ,na.rm=T)
zn$CPovTc       <-zn$CPovT       -mean(zn$CPovT       ,na.rm=T)
zn$CPovWc       <-zn$CPovW       -mean(zn$CPovW       ,na.rm=T)
zn$CPovBc       <-zn$CPovB       -mean(zn$CPovB       ,na.rm=T)
zn$CPovHc       <-zn$CPovH       -mean(zn$CPovH       ,na.rm=T)
zn$CPov1c       <-zn$CPov1       -mean(zn$CPov1       ,na.rm=T)
zn$CPov2c       <-zn$CPov2       -mean(zn$CPov2       ,na.rm=T)
zn$CPov3c       <-zn$CPov3       -mean(zn$CPov3       ,na.rm=T)
zn$PubAsTc      <-zn$PubAsT      -mean(zn$PubAsT      ,na.rm=T)
zn$WelfarTc     <-zn$WelfarT     -mean(zn$WelfarT     ,na.rm=T)
zn$SnapTc       <-zn$SnapT       -mean(zn$SnapT       ,na.rm=T)
zn$SnapWc       <-zn$SnapW       -mean(zn$SnapW       ,na.rm=T)
zn$SnapBc       <-zn$SnapB       -mean(zn$SnapB       ,na.rm=T)
zn$SnapHc       <-zn$SnapH       -mean(zn$SnapH       ,na.rm=T)
zn$IncomeT1kc   <-zn$IncomeT1k   -mean(zn$IncomeT1k   ,na.rm=T)
zn$IncomeW1kc   <-zn$IncomeW1k   -mean(zn$IncomeW1k   ,na.rm=T)
zn$IncomeB1kc   <-zn$IncomeB1k   -mean(zn$IncomeB1k   ,na.rm=T)
zn$IncomeH1kc   <-zn$IncomeH1k   -mean(zn$IncomeH1k   ,na.rm=T)
zn$GiniT100c    <-zn$GiniT100    -mean(zn$GiniT100    ,na.rm=T)
zn$HValueT10kc  <-zn$HValueT10k  -mean(zn$HValueT10k  ,na.rm=T)
zn$MCostT100c   <-zn$MCostT100   -mean(zn$MCostT100   ,na.rm=T)
zn$OCostDT100c  <-zn$OCostDT100  -mean(zn$OCostDT100  ,na.rm=T)
zn$MRentDT100c  <-zn$MRentDT100  -mean(zn$MRentDT100  ,na.rm=T)
zn$OCostPTc     <-zn$OCostPT     -mean(zn$OCostPT     ,na.rm=T)
zn$MRentPTc     <-zn$MRentPT     -mean(zn$MRentPT     ,na.rm=T)
zn$MortgTc      <-zn$MortgT      -mean(zn$MortgT      ,na.rm=T)
zn$LangAPTc     <-zn$LangAPT     -mean(zn$LangAPT     ,na.rm=T)
zn$LangAPWc     <-zn$LangAPW     -mean(zn$LangAPW     ,na.rm=T)
zn$LangAPBc     <-zn$LangAPB     -mean(zn$LangAPB     ,na.rm=T)
zn$LangAPHc     <-zn$LangAPH     -mean(zn$LangAPH     ,na.rm=T)
zn$LangBPTc     <-zn$LangBPT     -mean(zn$LangBPT     ,na.rm=T)
zn$LangBPWc     <-zn$LangBPW     -mean(zn$LangBPW     ,na.rm=T)
zn$LangBPBc     <-zn$LangBPB     -mean(zn$LangBPB     ,na.rm=T)
zn$LangBPHc     <-zn$LangBPH     -mean(zn$LangBPH     ,na.rm=T)
zn$LangCPTc     <-zn$LangCPT     -mean(zn$LangCPT     ,na.rm=T)
zn$OutUsTc      <-zn$OutUsT      -mean(zn$OutUsT      ,na.rm=T)
zn$OutUsWc      <-zn$OutUsW      -mean(zn$OutUsW      ,na.rm=T)
zn$OutUsBc      <-zn$OutUsB      -mean(zn$OutUsB      ,na.rm=T)
zn$OutUsHc      <-zn$OutUsH      -mean(zn$OutUsH      ,na.rm=T)
zn$FBornTc      <-zn$FBornT      -mean(zn$FBornT      ,na.rm=T)
zn$FBornWc      <-zn$FBornW      -mean(zn$FBornW      ,na.rm=T)
zn$FBornBc      <-zn$FBornB      -mean(zn$FBornB      ,na.rm=T)
zn$FBornHc      <-zn$FBornH      -mean(zn$FBornH      ,na.rm=T)
zn$NotCtzTc     <-zn$NotCtzT     -mean(zn$NotCtzT     ,na.rm=T)
zn$NotCtzWc     <-zn$NotCtzW     -mean(zn$NotCtzW     ,na.rm=T)
zn$NotCtzBc     <-zn$NotCtzB     -mean(zn$NotCtzB     ,na.rm=T)
zn$NotCtzHc     <-zn$NotCtzH     -mean(zn$NotCtzH     ,na.rm=T)
zn$MoveTc       <-zn$MoveT       -mean(zn$MoveT       ,na.rm=T)
zn$MoveWc       <-zn$MoveW       -mean(zn$MoveW       ,na.rm=T)
zn$MoveBc       <-zn$MoveB       -mean(zn$MoveB       ,na.rm=T)
zn$MoveHc       <-zn$MoveH       -mean(zn$MoveH       ,na.rm=T)
zn$VacantTc     <-zn$VacantT     -mean(zn$VacantT     ,na.rm=T)
zn$OwnerTc      <-zn$OwnerT      -mean(zn$OwnerT      ,na.rm=T)
zn$OwnerWc      <-zn$OwnerW      -mean(zn$OwnerW      ,na.rm=T)
zn$OwnerBc      <-zn$OwnerB      -mean(zn$OwnerB      ,na.rm=T)
zn$OwnerHc      <-zn$OwnerH      -mean(zn$OwnerH      ,na.rm=T)
zn$CrowdTc      <-zn$CrowdT      -mean(zn$CrowdT      ,na.rm=T)
zn$CrowdWc      <-zn$CrowdW      -mean(zn$CrowdW      ,na.rm=T)
zn$CrowdBc      <-zn$CrowdB      -mean(zn$CrowdB      ,na.rm=T)
zn$CrowdHc      <-zn$CrowdH      -mean(zn$CrowdH      ,na.rm=T)
zn$MobileTc     <-zn$MobileT     -mean(zn$MobileT     ,na.rm=T)
zn$MobileWc     <-zn$MobileW     -mean(zn$MobileW     ,na.rm=T)
zn$MobileBc     <-zn$MobileB     -mean(zn$MobileB     ,na.rm=T)
zn$MobileHc     <-zn$MobileH     -mean(zn$MobileH     ,na.rm=T)
zn$DisablTc     <-zn$DisablT     -mean(zn$DisablT     ,na.rm=T)
zn$DisablWc     <-zn$DisablW     -mean(zn$DisablW     ,na.rm=T)
zn$DisablBc     <-zn$DisablB     -mean(zn$DisablB     ,na.rm=T)
zn$DisablHc     <-zn$DisablH     -mean(zn$DisablH     ,na.rm=T)
zn$DisablTCc    <-zn$DisablTC    -mean(zn$DisablTC    ,na.rm=T)
zn$DisablWCc    <-zn$DisablWC    -mean(zn$DisablWC    ,na.rm=T)
zn$DisablBCc    <-zn$DisablBC    -mean(zn$DisablBC    ,na.rm=T)
zn$DisablHCc    <-zn$DisablHC    -mean(zn$DisablHC    ,na.rm=T)
zn$DisablTMc    <-zn$DisablTM    -mean(zn$DisablTM    ,na.rm=T)
zn$DisablTFc    <-zn$DisablTF    -mean(zn$DisablTF    ,na.rm=T)
zn$Urban1c      <-zn$Urban1      -mean(zn$Urban1      ,na.rm=T)
zn$Urban2c      <-zn$Urban2      -mean(zn$Urban2      ,na.rm=T)
zn$ISBE_PFAc    <-zn$ISBE_PFA    -mean(zn$ISBE_PFA    ,na.rm=T)
zn$ISBE_PFAEc   <-zn$ISBE_PFAE   -mean(zn$ISBE_PFAE   ,na.rm=T)
zn$ISBE_PIc     <-zn$ISBE_PI     -mean(zn$ISBE_PI     ,na.rm=T)
zn$HeadStartc   <-zn$HeadStart   -mean(zn$HeadStart   ,na.rm=T)
zn$ElyHeadSc    <-zn$ElyHeadS    -mean(zn$ElyHeadS    ,na.rm=T)
zn$HeadSAllc    <-zn$HeadSAll    -mean(zn$HeadSAll    ,na.rm=T)
zn$PFA_HS1c     <-zn$PFA_HS1     -mean(zn$PFA_HS1     ,na.rm=T)
zn$PFA_HS2c     <-zn$PFA_HS2     -mean(zn$PFA_HS2     ,na.rm=T)
zn$LCCCc        <-zn$LCCC        -mean(zn$LCCC        ,na.rm=T)
zn$LECCCc       <-zn$LECCC       -mean(zn$LECCC       ,na.rm=T)
zn$LFCCc        <-zn$LFCC        -mean(zn$LFCC        ,na.rm=T)
zn$LLECCCc      <-zn$LLECCC      -mean(zn$LLECCC      ,na.rm=T)
zn$LCLFCCc      <-zn$LCLFCC      -mean(zn$LCLFCC      ,na.rm=T)
zn$LCCCB1c      <-zn$LCCCB1      -mean(zn$LCCCB1      ,na.rm=T)
zn$LCCCB2c      <-zn$LCCCB2      -mean(zn$LCCCB2      ,na.rm=T)
zn$LCCB1c       <-zn$LCCB1       -mean(zn$LCCB1       ,na.rm=T)
zn$LCCB2c       <-zn$LCCB2       -mean(zn$LCCB2       ,na.rm=T)
zn$LCCCS1c      <-zn$LCCCS1      -mean(zn$LCCCS1      ,na.rm=T)
zn$LCCCS2c      <-zn$LCCCS2      -mean(zn$LCCCS2      ,na.rm=T)
zn$LCCS1c       <-zn$LCCS1       -mean(zn$LCCS1       ,na.rm=T)
zn$LCCS2c       <-zn$LCCS2       -mean(zn$LCCS2       ,na.rm=T)
zn$LCCCG1c      <-zn$LCCCG1      -mean(zn$LCCCG1      ,na.rm=T)
zn$LCCCG2c      <-zn$LCCCG2      -mean(zn$LCCCG2      ,na.rm=T)
zn$LCCG1c       <-zn$LCCG1       -mean(zn$LCCG1       ,na.rm=T)
zn$LCCG2c       <-zn$LCCG2       -mean(zn$LCCG2       ,na.rm=T)
zn$ChildCare1c  <-zn$ChildCare1  -mean(zn$ChildCare1  ,na.rm=T)
zn$ChildCare2c  <-zn$ChildCare2  -mean(zn$ChildCare2  ,na.rm=T)
zn$ChildCare3c  <-zn$ChildCare3  -mean(zn$ChildCare3  ,na.rm=T)
zn$CCAPc        <-zn$CCAP        -mean(zn$CCAP        ,na.rm=T)
zn$Homelessc    <-zn$Homeless    -mean(zn$Homeless    ,na.rm=T)
zn$Homeless2c   <-zn$Homeless2   -mean(zn$Homeless2   ,na.rm=T)
zn$DHS_HFIrc    <-zn$DHS_HFIr    -mean(zn$DHS_HFIr    ,na.rm=T)
zn$DHS_PTSrc    <-zn$DHS_PTSr    -mean(zn$DHS_PTSr    ,na.rm=T)
zn$DHS_HVPrc    <-zn$DHS_HVPr    -mean(zn$DHS_HVPr    ,na.rm=T)
zn$IDHS_EIrc    <-zn$IDHS_EIr    -mean(zn$IDHS_EIr    ,na.rm=T)
zn$MHV_C4c      <-zn$MHV_C4      -mean(zn$MHV_C4      ,na.rm=T)
zn$MHV_P4c      <-zn$MHV_P4      -mean(zn$MHV_P4      ,na.rm=T)
zn$MHV_C5c      <-zn$MHV_C5      -mean(zn$MHV_C5      ,na.rm=T)
zn$MHV_P5c      <-zn$MHV_P5      -mean(zn$MHV_P5      ,na.rm=T)
zn$FoodInsPc    <-zn$FoodInsP    -mean(zn$FoodInsP    ,na.rm=T)
zn$FoodISc      <-zn$FoodIS      -mean(zn$FoodIS      ,na.rm=T)





# demean - within and between variables
zn<-cbind(zn,demean(zn,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Physical Abuse
# Food Insecurity - Physical Abuse
# Food Insecurity - Physical Abuse
# Food Insecurity - Physical Abuse
# Food Insecurity - Physical Abuse
# Food Insecurity - Physical Abuse
# Food Insecurity - Physical Abuse
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
zp$Yearc        <-zp$Year        -mean(zp$Year        ,na.rm=T)
zp$CPopBPc      <-zp$CPopBP      -mean(zp$CPopBP      ,na.rm=T)
zp$CPopHPc      <-zp$CPopHP      -mean(zp$CPopHP      ,na.rm=T)
zp$ChildPTc     <-zp$ChildPT     -mean(zp$ChildPT     ,na.rm=T)
zp$ChildPWc     <-zp$ChildPW     -mean(zp$ChildPW     ,na.rm=T)
zp$ChildPBc     <-zp$ChildPB     -mean(zp$ChildPB     ,na.rm=T)
zp$ChildPHc     <-zp$ChildPH     -mean(zp$ChildPH     ,na.rm=T)
zp$CARatioT100c <-zp$CARatioT100 -mean(zp$CARatioT100 ,na.rm=T)
zp$CARatioW100c <-zp$CARatioW100 -mean(zp$CARatioW100 ,na.rm=T)
zp$CARatioB100c <-zp$CARatioB100 -mean(zp$CARatioB100 ,na.rm=T)
zp$CARatioH100c <-zp$CARatioH100 -mean(zp$CARatioH100 ,na.rm=T)
zp$MalePTc      <-zp$MalePT      -mean(zp$MalePT      ,na.rm=T)
zp$MalePWc      <-zp$MalePW      -mean(zp$MalePW      ,na.rm=T)
zp$MalePBc      <-zp$MalePB      -mean(zp$MalePB      ,na.rm=T)
zp$MalePHc      <-zp$MalePH      -mean(zp$MalePH      ,na.rm=T)
zp$MFRatioT100c <-zp$MFRatioT100 -mean(zp$MFRatioT100 ,na.rm=T)
zp$MFRatioW100c <-zp$MFRatioW100 -mean(zp$MFRatioW100 ,na.rm=T)
zp$MFRatioB100c <-zp$MFRatioB100 -mean(zp$MFRatioB100 ,na.rm=T)
zp$MFRatioH100c <-zp$MFRatioH100 -mean(zp$MFRatioH100 ,na.rm=T)
zp$ElderTc      <-zp$ElderT      -mean(zp$ElderT      ,na.rm=T)
zp$ElderWc      <-zp$ElderW      -mean(zp$ElderW      ,na.rm=T)
zp$ElderBc      <-zp$ElderB      -mean(zp$ElderB      ,na.rm=T)
zp$ElderHc      <-zp$ElderH      -mean(zp$ElderH      ,na.rm=T)
zp$SingleTc     <-zp$SingleT     -mean(zp$SingleT     ,na.rm=T)
zp$SingleWc     <-zp$SingleW     -mean(zp$SingleW     ,na.rm=T)
zp$SingleBc     <-zp$SingleB     -mean(zp$SingleB     ,na.rm=T)
zp$SingleHc     <-zp$SingleH     -mean(zp$SingleH     ,na.rm=T)
zp$FHeadTc      <-zp$FHeadT      -mean(zp$FHeadT      ,na.rm=T)
zp$FHeadWc      <-zp$FHeadW      -mean(zp$FHeadW      ,na.rm=T)
zp$FHeadBc      <-zp$FHeadB      -mean(zp$FHeadB      ,na.rm=T)
zp$FHeadHc      <-zp$FHeadH      -mean(zp$FHeadH      ,na.rm=T)
zp$NoHighTc     <-zp$NoHighT     -mean(zp$NoHighT     ,na.rm=T)
zp$NoHighWc     <-zp$NoHighW     -mean(zp$NoHighW     ,na.rm=T)
zp$NoHighBc     <-zp$NoHighB     -mean(zp$NoHighB     ,na.rm=T)
zp$NoHighHc     <-zp$NoHighH     -mean(zp$NoHighH     ,na.rm=T)
zp$UnempTc      <-zp$UnempT      -mean(zp$UnempT      ,na.rm=T)
zp$UnempWc      <-zp$UnempW      -mean(zp$UnempW      ,na.rm=T)
zp$UnempBc      <-zp$UnempB      -mean(zp$UnempB      ,na.rm=T)
zp$UnempHc      <-zp$UnempH      -mean(zp$UnempH      ,na.rm=T)
zp$CPovTc       <-zp$CPovT       -mean(zp$CPovT       ,na.rm=T)
zp$CPovWc       <-zp$CPovW       -mean(zp$CPovW       ,na.rm=T)
zp$CPovBc       <-zp$CPovB       -mean(zp$CPovB       ,na.rm=T)
zp$CPovHc       <-zp$CPovH       -mean(zp$CPovH       ,na.rm=T)
zp$CPov1c       <-zp$CPov1       -mean(zp$CPov1       ,na.rm=T)
zp$CPov2c       <-zp$CPov2       -mean(zp$CPov2       ,na.rm=T)
zp$CPov3c       <-zp$CPov3       -mean(zp$CPov3       ,na.rm=T)
zp$PubAsTc      <-zp$PubAsT      -mean(zp$PubAsT      ,na.rm=T)
zp$WelfarTc     <-zp$WelfarT     -mean(zp$WelfarT     ,na.rm=T)
zp$SnapTc       <-zp$SnapT       -mean(zp$SnapT       ,na.rm=T)
zp$SnapWc       <-zp$SnapW       -mean(zp$SnapW       ,na.rm=T)
zp$SnapBc       <-zp$SnapB       -mean(zp$SnapB       ,na.rm=T)
zp$SnapHc       <-zp$SnapH       -mean(zp$SnapH       ,na.rm=T)
zp$IncomeT1kc   <-zp$IncomeT1k   -mean(zp$IncomeT1k   ,na.rm=T)
zp$IncomeW1kc   <-zp$IncomeW1k   -mean(zp$IncomeW1k   ,na.rm=T)
zp$IncomeB1kc   <-zp$IncomeB1k   -mean(zp$IncomeB1k   ,na.rm=T)
zp$IncomeH1kc   <-zp$IncomeH1k   -mean(zp$IncomeH1k   ,na.rm=T)
zp$GiniT100c    <-zp$GiniT100    -mean(zp$GiniT100    ,na.rm=T)
zp$HValueT10kc  <-zp$HValueT10k  -mean(zp$HValueT10k  ,na.rm=T)
zp$MCostT100c   <-zp$MCostT100   -mean(zp$MCostT100   ,na.rm=T)
zp$OCostDT100c  <-zp$OCostDT100  -mean(zp$OCostDT100  ,na.rm=T)
zp$MRentDT100c  <-zp$MRentDT100  -mean(zp$MRentDT100  ,na.rm=T)
zp$OCostPTc     <-zp$OCostPT     -mean(zp$OCostPT     ,na.rm=T)
zp$MRentPTc     <-zp$MRentPT     -mean(zp$MRentPT     ,na.rm=T)
zp$MortgTc      <-zp$MortgT      -mean(zp$MortgT      ,na.rm=T)
zp$LangAPTc     <-zp$LangAPT     -mean(zp$LangAPT     ,na.rm=T)
zp$LangAPWc     <-zp$LangAPW     -mean(zp$LangAPW     ,na.rm=T)
zp$LangAPBc     <-zp$LangAPB     -mean(zp$LangAPB     ,na.rm=T)
zp$LangAPHc     <-zp$LangAPH     -mean(zp$LangAPH     ,na.rm=T)
zp$LangBPTc     <-zp$LangBPT     -mean(zp$LangBPT     ,na.rm=T)
zp$LangBPWc     <-zp$LangBPW     -mean(zp$LangBPW     ,na.rm=T)
zp$LangBPBc     <-zp$LangBPB     -mean(zp$LangBPB     ,na.rm=T)
zp$LangBPHc     <-zp$LangBPH     -mean(zp$LangBPH     ,na.rm=T)
zp$LangCPTc     <-zp$LangCPT     -mean(zp$LangCPT     ,na.rm=T)
zp$OutUsTc      <-zp$OutUsT      -mean(zp$OutUsT      ,na.rm=T)
zp$OutUsWc      <-zp$OutUsW      -mean(zp$OutUsW      ,na.rm=T)
zp$OutUsBc      <-zp$OutUsB      -mean(zp$OutUsB      ,na.rm=T)
zp$OutUsHc      <-zp$OutUsH      -mean(zp$OutUsH      ,na.rm=T)
zp$FBornTc      <-zp$FBornT      -mean(zp$FBornT      ,na.rm=T)
zp$FBornWc      <-zp$FBornW      -mean(zp$FBornW      ,na.rm=T)
zp$FBornBc      <-zp$FBornB      -mean(zp$FBornB      ,na.rm=T)
zp$FBornHc      <-zp$FBornH      -mean(zp$FBornH      ,na.rm=T)
zp$NotCtzTc     <-zp$NotCtzT     -mean(zp$NotCtzT     ,na.rm=T)
zp$NotCtzWc     <-zp$NotCtzW     -mean(zp$NotCtzW     ,na.rm=T)
zp$NotCtzBc     <-zp$NotCtzB     -mean(zp$NotCtzB     ,na.rm=T)
zp$NotCtzHc     <-zp$NotCtzH     -mean(zp$NotCtzH     ,na.rm=T)
zp$MoveTc       <-zp$MoveT       -mean(zp$MoveT       ,na.rm=T)
zp$MoveWc       <-zp$MoveW       -mean(zp$MoveW       ,na.rm=T)
zp$MoveBc       <-zp$MoveB       -mean(zp$MoveB       ,na.rm=T)
zp$MoveHc       <-zp$MoveH       -mean(zp$MoveH       ,na.rm=T)
zp$VacantTc     <-zp$VacantT     -mean(zp$VacantT     ,na.rm=T)
zp$OwnerTc      <-zp$OwnerT      -mean(zp$OwnerT      ,na.rm=T)
zp$OwnerWc      <-zp$OwnerW      -mean(zp$OwnerW      ,na.rm=T)
zp$OwnerBc      <-zp$OwnerB      -mean(zp$OwnerB      ,na.rm=T)
zp$OwnerHc      <-zp$OwnerH      -mean(zp$OwnerH      ,na.rm=T)
zp$CrowdTc      <-zp$CrowdT      -mean(zp$CrowdT      ,na.rm=T)
zp$CrowdWc      <-zp$CrowdW      -mean(zp$CrowdW      ,na.rm=T)
zp$CrowdBc      <-zp$CrowdB      -mean(zp$CrowdB      ,na.rm=T)
zp$CrowdHc      <-zp$CrowdH      -mean(zp$CrowdH      ,na.rm=T)
zp$MobileTc     <-zp$MobileT     -mean(zp$MobileT     ,na.rm=T)
zp$MobileWc     <-zp$MobileW     -mean(zp$MobileW     ,na.rm=T)
zp$MobileBc     <-zp$MobileB     -mean(zp$MobileB     ,na.rm=T)
zp$MobileHc     <-zp$MobileH     -mean(zp$MobileH     ,na.rm=T)
zp$DisablTc     <-zp$DisablT     -mean(zp$DisablT     ,na.rm=T)
zp$DisablWc     <-zp$DisablW     -mean(zp$DisablW     ,na.rm=T)
zp$DisablBc     <-zp$DisablB     -mean(zp$DisablB     ,na.rm=T)
zp$DisablHc     <-zp$DisablH     -mean(zp$DisablH     ,na.rm=T)
zp$DisablTCc    <-zp$DisablTC    -mean(zp$DisablTC    ,na.rm=T)
zp$DisablWCc    <-zp$DisablWC    -mean(zp$DisablWC    ,na.rm=T)
zp$DisablBCc    <-zp$DisablBC    -mean(zp$DisablBC    ,na.rm=T)
zp$DisablHCc    <-zp$DisablHC    -mean(zp$DisablHC    ,na.rm=T)
zp$DisablTMc    <-zp$DisablTM    -mean(zp$DisablTM    ,na.rm=T)
zp$DisablTFc    <-zp$DisablTF    -mean(zp$DisablTF    ,na.rm=T)
zp$Urban1c      <-zp$Urban1      -mean(zp$Urban1      ,na.rm=T)
zp$Urban2c      <-zp$Urban2      -mean(zp$Urban2      ,na.rm=T)
zp$ISBE_PFAc    <-zp$ISBE_PFA    -mean(zp$ISBE_PFA    ,na.rm=T)
zp$ISBE_PFAEc   <-zp$ISBE_PFAE   -mean(zp$ISBE_PFAE   ,na.rm=T)
zp$ISBE_PIc     <-zp$ISBE_PI     -mean(zp$ISBE_PI     ,na.rm=T)
zp$HeadStartc   <-zp$HeadStart   -mean(zp$HeadStart   ,na.rm=T)
zp$ElyHeadSc    <-zp$ElyHeadS    -mean(zp$ElyHeadS    ,na.rm=T)
zp$HeadSAllc    <-zp$HeadSAll    -mean(zp$HeadSAll    ,na.rm=T)
zp$PFA_HS1c     <-zp$PFA_HS1     -mean(zp$PFA_HS1     ,na.rm=T)
zp$PFA_HS2c     <-zp$PFA_HS2     -mean(zp$PFA_HS2     ,na.rm=T)
zp$LCCCc        <-zp$LCCC        -mean(zp$LCCC        ,na.rm=T)
zp$LECCCc       <-zp$LECCC       -mean(zp$LECCC       ,na.rm=T)
zp$LFCCc        <-zp$LFCC        -mean(zp$LFCC        ,na.rm=T)
zp$LLECCCc      <-zp$LLECCC      -mean(zp$LLECCC      ,na.rm=T)
zp$LCLFCCc      <-zp$LCLFCC      -mean(zp$LCLFCC      ,na.rm=T)
zp$LCCCB1c      <-zp$LCCCB1      -mean(zp$LCCCB1      ,na.rm=T)
zp$LCCCB2c      <-zp$LCCCB2      -mean(zp$LCCCB2      ,na.rm=T)
zp$LCCB1c       <-zp$LCCB1       -mean(zp$LCCB1       ,na.rm=T)
zp$LCCB2c       <-zp$LCCB2       -mean(zp$LCCB2       ,na.rm=T)
zp$LCCCS1c      <-zp$LCCCS1      -mean(zp$LCCCS1      ,na.rm=T)
zp$LCCCS2c      <-zp$LCCCS2      -mean(zp$LCCCS2      ,na.rm=T)
zp$LCCS1c       <-zp$LCCS1       -mean(zp$LCCS1       ,na.rm=T)
zp$LCCS2c       <-zp$LCCS2       -mean(zp$LCCS2       ,na.rm=T)
zp$LCCCG1c      <-zp$LCCCG1      -mean(zp$LCCCG1      ,na.rm=T)
zp$LCCCG2c      <-zp$LCCCG2      -mean(zp$LCCCG2      ,na.rm=T)
zp$LCCG1c       <-zp$LCCG1       -mean(zp$LCCG1       ,na.rm=T)
zp$LCCG2c       <-zp$LCCG2       -mean(zp$LCCG2       ,na.rm=T)
zp$ChildCare1c  <-zp$ChildCare1  -mean(zp$ChildCare1  ,na.rm=T)
zp$ChildCare2c  <-zp$ChildCare2  -mean(zp$ChildCare2  ,na.rm=T)
zp$ChildCare3c  <-zp$ChildCare3  -mean(zp$ChildCare3  ,na.rm=T)
zp$CCAPc        <-zp$CCAP        -mean(zp$CCAP        ,na.rm=T)
zp$Homelessc    <-zp$Homeless    -mean(zp$Homeless    ,na.rm=T)
zp$Homeless2c   <-zp$Homeless2   -mean(zp$Homeless2   ,na.rm=T)
zp$DHS_HFIrc    <-zp$DHS_HFIr    -mean(zp$DHS_HFIr    ,na.rm=T)
zp$DHS_PTSrc    <-zp$DHS_PTSr    -mean(zp$DHS_PTSr    ,na.rm=T)
zp$DHS_HVPrc    <-zp$DHS_HVPr    -mean(zp$DHS_HVPr    ,na.rm=T)
zp$IDHS_EIrc    <-zp$IDHS_EIr    -mean(zp$IDHS_EIr    ,na.rm=T)
zp$MHV_C4c      <-zp$MHV_C4      -mean(zp$MHV_C4      ,na.rm=T)
zp$MHV_P4c      <-zp$MHV_P4      -mean(zp$MHV_P4      ,na.rm=T)
zp$MHV_C5c      <-zp$MHV_C5      -mean(zp$MHV_C5      ,na.rm=T)
zp$MHV_P5c      <-zp$MHV_P5      -mean(zp$MHV_P5      ,na.rm=T)
zp$FoodInsPc    <-zp$FoodInsP    -mean(zp$FoodInsP    ,na.rm=T)
zp$FoodISc      <-zp$FoodIS      -mean(zp$FoodIS      ,na.rm=T)





# demean - within and between variables
zp<-cbind(zp,demean(zp,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Sexual Abuse
# Food Insecurity - Sexual Abuse
# Food Insecurity - Sexual Abuse
# Food Insecurity - Sexual Abuse
# Food Insecurity - Sexual Abuse
# Food Insecurity - Sexual Abuse
# Food Insecurity - Sexual Abuse
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
zs$Yearc        <-zs$Year        -mean(zs$Year        ,na.rm=T)
zs$CPopBPc      <-zs$CPopBP      -mean(zs$CPopBP      ,na.rm=T)
zs$CPopHPc      <-zs$CPopHP      -mean(zs$CPopHP      ,na.rm=T)
zs$ChildPTc     <-zs$ChildPT     -mean(zs$ChildPT     ,na.rm=T)
zs$ChildPWc     <-zs$ChildPW     -mean(zs$ChildPW     ,na.rm=T)
zs$ChildPBc     <-zs$ChildPB     -mean(zs$ChildPB     ,na.rm=T)
zs$ChildPHc     <-zs$ChildPH     -mean(zs$ChildPH     ,na.rm=T)
zs$CARatioT100c <-zs$CARatioT100 -mean(zs$CARatioT100 ,na.rm=T)
zs$CARatioW100c <-zs$CARatioW100 -mean(zs$CARatioW100 ,na.rm=T)
zs$CARatioB100c <-zs$CARatioB100 -mean(zs$CARatioB100 ,na.rm=T)
zs$CARatioH100c <-zs$CARatioH100 -mean(zs$CARatioH100 ,na.rm=T)
zs$MalePTc      <-zs$MalePT      -mean(zs$MalePT      ,na.rm=T)
zs$MalePWc      <-zs$MalePW      -mean(zs$MalePW      ,na.rm=T)
zs$MalePBc      <-zs$MalePB      -mean(zs$MalePB      ,na.rm=T)
zs$MalePHc      <-zs$MalePH      -mean(zs$MalePH      ,na.rm=T)
zs$MFRatioT100c <-zs$MFRatioT100 -mean(zs$MFRatioT100 ,na.rm=T)
zs$MFRatioW100c <-zs$MFRatioW100 -mean(zs$MFRatioW100 ,na.rm=T)
zs$MFRatioB100c <-zs$MFRatioB100 -mean(zs$MFRatioB100 ,na.rm=T)
zs$MFRatioH100c <-zs$MFRatioH100 -mean(zs$MFRatioH100 ,na.rm=T)
zs$ElderTc      <-zs$ElderT      -mean(zs$ElderT      ,na.rm=T)
zs$ElderWc      <-zs$ElderW      -mean(zs$ElderW      ,na.rm=T)
zs$ElderBc      <-zs$ElderB      -mean(zs$ElderB      ,na.rm=T)
zs$ElderHc      <-zs$ElderH      -mean(zs$ElderH      ,na.rm=T)
zs$SingleTc     <-zs$SingleT     -mean(zs$SingleT     ,na.rm=T)
zs$SingleWc     <-zs$SingleW     -mean(zs$SingleW     ,na.rm=T)
zs$SingleBc     <-zs$SingleB     -mean(zs$SingleB     ,na.rm=T)
zs$SingleHc     <-zs$SingleH     -mean(zs$SingleH     ,na.rm=T)
zs$FHeadTc      <-zs$FHeadT      -mean(zs$FHeadT      ,na.rm=T)
zs$FHeadWc      <-zs$FHeadW      -mean(zs$FHeadW      ,na.rm=T)
zs$FHeadBc      <-zs$FHeadB      -mean(zs$FHeadB      ,na.rm=T)
zs$FHeadHc      <-zs$FHeadH      -mean(zs$FHeadH      ,na.rm=T)
zs$NoHighTc     <-zs$NoHighT     -mean(zs$NoHighT     ,na.rm=T)
zs$NoHighWc     <-zs$NoHighW     -mean(zs$NoHighW     ,na.rm=T)
zs$NoHighBc     <-zs$NoHighB     -mean(zs$NoHighB     ,na.rm=T)
zs$NoHighHc     <-zs$NoHighH     -mean(zs$NoHighH     ,na.rm=T)
zs$UnempTc      <-zs$UnempT      -mean(zs$UnempT      ,na.rm=T)
zs$UnempWc      <-zs$UnempW      -mean(zs$UnempW      ,na.rm=T)
zs$UnempBc      <-zs$UnempB      -mean(zs$UnempB      ,na.rm=T)
zs$UnempHc      <-zs$UnempH      -mean(zs$UnempH      ,na.rm=T)
zs$CPovTc       <-zs$CPovT       -mean(zs$CPovT       ,na.rm=T)
zs$CPovWc       <-zs$CPovW       -mean(zs$CPovW       ,na.rm=T)
zs$CPovBc       <-zs$CPovB       -mean(zs$CPovB       ,na.rm=T)
zs$CPovHc       <-zs$CPovH       -mean(zs$CPovH       ,na.rm=T)
zs$CPov1c       <-zs$CPov1       -mean(zs$CPov1       ,na.rm=T)
zs$CPov2c       <-zs$CPov2       -mean(zs$CPov2       ,na.rm=T)
zs$CPov3c       <-zs$CPov3       -mean(zs$CPov3       ,na.rm=T)
zs$PubAsTc      <-zs$PubAsT      -mean(zs$PubAsT      ,na.rm=T)
zs$WelfarTc     <-zs$WelfarT     -mean(zs$WelfarT     ,na.rm=T)
zs$SnapTc       <-zs$SnapT       -mean(zs$SnapT       ,na.rm=T)
zs$SnapWc       <-zs$SnapW       -mean(zs$SnapW       ,na.rm=T)
zs$SnapBc       <-zs$SnapB       -mean(zs$SnapB       ,na.rm=T)
zs$SnapHc       <-zs$SnapH       -mean(zs$SnapH       ,na.rm=T)
zs$IncomeT1kc   <-zs$IncomeT1k   -mean(zs$IncomeT1k   ,na.rm=T)
zs$IncomeW1kc   <-zs$IncomeW1k   -mean(zs$IncomeW1k   ,na.rm=T)
zs$IncomeB1kc   <-zs$IncomeB1k   -mean(zs$IncomeB1k   ,na.rm=T)
zs$IncomeH1kc   <-zs$IncomeH1k   -mean(zs$IncomeH1k   ,na.rm=T)
zs$GiniT100c    <-zs$GiniT100    -mean(zs$GiniT100    ,na.rm=T)
zs$HValueT10kc  <-zs$HValueT10k  -mean(zs$HValueT10k  ,na.rm=T)
zs$MCostT100c   <-zs$MCostT100   -mean(zs$MCostT100   ,na.rm=T)
zs$OCostDT100c  <-zs$OCostDT100  -mean(zs$OCostDT100  ,na.rm=T)
zs$MRentDT100c  <-zs$MRentDT100  -mean(zs$MRentDT100  ,na.rm=T)
zs$OCostPTc     <-zs$OCostPT     -mean(zs$OCostPT     ,na.rm=T)
zs$MRentPTc     <-zs$MRentPT     -mean(zs$MRentPT     ,na.rm=T)
zs$MortgTc      <-zs$MortgT      -mean(zs$MortgT      ,na.rm=T)
zs$LangAPTc     <-zs$LangAPT     -mean(zs$LangAPT     ,na.rm=T)
zs$LangAPWc     <-zs$LangAPW     -mean(zs$LangAPW     ,na.rm=T)
zs$LangAPBc     <-zs$LangAPB     -mean(zs$LangAPB     ,na.rm=T)
zs$LangAPHc     <-zs$LangAPH     -mean(zs$LangAPH     ,na.rm=T)
zs$LangBPTc     <-zs$LangBPT     -mean(zs$LangBPT     ,na.rm=T)
zs$LangBPWc     <-zs$LangBPW     -mean(zs$LangBPW     ,na.rm=T)
zs$LangBPBc     <-zs$LangBPB     -mean(zs$LangBPB     ,na.rm=T)
zs$LangBPHc     <-zs$LangBPH     -mean(zs$LangBPH     ,na.rm=T)
zs$LangCPTc     <-zs$LangCPT     -mean(zs$LangCPT     ,na.rm=T)
zs$OutUsTc      <-zs$OutUsT      -mean(zs$OutUsT      ,na.rm=T)
zs$OutUsWc      <-zs$OutUsW      -mean(zs$OutUsW      ,na.rm=T)
zs$OutUsBc      <-zs$OutUsB      -mean(zs$OutUsB      ,na.rm=T)
zs$OutUsHc      <-zs$OutUsH      -mean(zs$OutUsH      ,na.rm=T)
zs$FBornTc      <-zs$FBornT      -mean(zs$FBornT      ,na.rm=T)
zs$FBornWc      <-zs$FBornW      -mean(zs$FBornW      ,na.rm=T)
zs$FBornBc      <-zs$FBornB      -mean(zs$FBornB      ,na.rm=T)
zs$FBornHc      <-zs$FBornH      -mean(zs$FBornH      ,na.rm=T)
zs$NotCtzTc     <-zs$NotCtzT     -mean(zs$NotCtzT     ,na.rm=T)
zs$NotCtzWc     <-zs$NotCtzW     -mean(zs$NotCtzW     ,na.rm=T)
zs$NotCtzBc     <-zs$NotCtzB     -mean(zs$NotCtzB     ,na.rm=T)
zs$NotCtzHc     <-zs$NotCtzH     -mean(zs$NotCtzH     ,na.rm=T)
zs$MoveTc       <-zs$MoveT       -mean(zs$MoveT       ,na.rm=T)
zs$MoveWc       <-zs$MoveW       -mean(zs$MoveW       ,na.rm=T)
zs$MoveBc       <-zs$MoveB       -mean(zs$MoveB       ,na.rm=T)
zs$MoveHc       <-zs$MoveH       -mean(zs$MoveH       ,na.rm=T)
zs$VacantTc     <-zs$VacantT     -mean(zs$VacantT     ,na.rm=T)
zs$OwnerTc      <-zs$OwnerT      -mean(zs$OwnerT      ,na.rm=T)
zs$OwnerWc      <-zs$OwnerW      -mean(zs$OwnerW      ,na.rm=T)
zs$OwnerBc      <-zs$OwnerB      -mean(zs$OwnerB      ,na.rm=T)
zs$OwnerHc      <-zs$OwnerH      -mean(zs$OwnerH      ,na.rm=T)
zs$CrowdTc      <-zs$CrowdT      -mean(zs$CrowdT      ,na.rm=T)
zs$CrowdWc      <-zs$CrowdW      -mean(zs$CrowdW      ,na.rm=T)
zs$CrowdBc      <-zs$CrowdB      -mean(zs$CrowdB      ,na.rm=T)
zs$CrowdHc      <-zs$CrowdH      -mean(zs$CrowdH      ,na.rm=T)
zs$MobileTc     <-zs$MobileT     -mean(zs$MobileT     ,na.rm=T)
zs$MobileWc     <-zs$MobileW     -mean(zs$MobileW     ,na.rm=T)
zs$MobileBc     <-zs$MobileB     -mean(zs$MobileB     ,na.rm=T)
zs$MobileHc     <-zs$MobileH     -mean(zs$MobileH     ,na.rm=T)
zs$DisablTc     <-zs$DisablT     -mean(zs$DisablT     ,na.rm=T)
zs$DisablWc     <-zs$DisablW     -mean(zs$DisablW     ,na.rm=T)
zs$DisablBc     <-zs$DisablB     -mean(zs$DisablB     ,na.rm=T)
zs$DisablHc     <-zs$DisablH     -mean(zs$DisablH     ,na.rm=T)
zs$DisablTCc    <-zs$DisablTC    -mean(zs$DisablTC    ,na.rm=T)
zs$DisablWCc    <-zs$DisablWC    -mean(zs$DisablWC    ,na.rm=T)
zs$DisablBCc    <-zs$DisablBC    -mean(zs$DisablBC    ,na.rm=T)
zs$DisablHCc    <-zs$DisablHC    -mean(zs$DisablHC    ,na.rm=T)
zs$DisablTMc    <-zs$DisablTM    -mean(zs$DisablTM    ,na.rm=T)
zs$DisablTFc    <-zs$DisablTF    -mean(zs$DisablTF    ,na.rm=T)
zs$Urban1c      <-zs$Urban1      -mean(zs$Urban1      ,na.rm=T)
zs$Urban2c      <-zs$Urban2      -mean(zs$Urban2      ,na.rm=T)
zs$ISBE_PFAc    <-zs$ISBE_PFA    -mean(zs$ISBE_PFA    ,na.rm=T)
zs$ISBE_PFAEc   <-zs$ISBE_PFAE   -mean(zs$ISBE_PFAE   ,na.rm=T)
zs$ISBE_PIc     <-zs$ISBE_PI     -mean(zs$ISBE_PI     ,na.rm=T)
zs$HeadStartc   <-zs$HeadStart   -mean(zs$HeadStart   ,na.rm=T)
zs$ElyHeadSc    <-zs$ElyHeadS    -mean(zs$ElyHeadS    ,na.rm=T)
zs$HeadSAllc    <-zs$HeadSAll    -mean(zs$HeadSAll    ,na.rm=T)
zs$PFA_HS1c     <-zs$PFA_HS1     -mean(zs$PFA_HS1     ,na.rm=T)
zs$PFA_HS2c     <-zs$PFA_HS2     -mean(zs$PFA_HS2     ,na.rm=T)
zs$LCCCc        <-zs$LCCC        -mean(zs$LCCC        ,na.rm=T)
zs$LECCCc       <-zs$LECCC       -mean(zs$LECCC       ,na.rm=T)
zs$LFCCc        <-zs$LFCC        -mean(zs$LFCC        ,na.rm=T)
zs$LLECCCc      <-zs$LLECCC      -mean(zs$LLECCC      ,na.rm=T)
zs$LCLFCCc      <-zs$LCLFCC      -mean(zs$LCLFCC      ,na.rm=T)
zs$LCCCB1c      <-zs$LCCCB1      -mean(zs$LCCCB1      ,na.rm=T)
zs$LCCCB2c      <-zs$LCCCB2      -mean(zs$LCCCB2      ,na.rm=T)
zs$LCCB1c       <-zs$LCCB1       -mean(zs$LCCB1       ,na.rm=T)
zs$LCCB2c       <-zs$LCCB2       -mean(zs$LCCB2       ,na.rm=T)
zs$LCCCS1c      <-zs$LCCCS1      -mean(zs$LCCCS1      ,na.rm=T)
zs$LCCCS2c      <-zs$LCCCS2      -mean(zs$LCCCS2      ,na.rm=T)
zs$LCCS1c       <-zs$LCCS1       -mean(zs$LCCS1       ,na.rm=T)
zs$LCCS2c       <-zs$LCCS2       -mean(zs$LCCS2       ,na.rm=T)
zs$LCCCG1c      <-zs$LCCCG1      -mean(zs$LCCCG1      ,na.rm=T)
zs$LCCCG2c      <-zs$LCCCG2      -mean(zs$LCCCG2      ,na.rm=T)
zs$LCCG1c       <-zs$LCCG1       -mean(zs$LCCG1       ,na.rm=T)
zs$LCCG2c       <-zs$LCCG2       -mean(zs$LCCG2       ,na.rm=T)
zs$ChildCare1c  <-zs$ChildCare1  -mean(zs$ChildCare1  ,na.rm=T)
zs$ChildCare2c  <-zs$ChildCare2  -mean(zs$ChildCare2  ,na.rm=T)
zs$ChildCare3c  <-zs$ChildCare3  -mean(zs$ChildCare3  ,na.rm=T)
zs$CCAPc        <-zs$CCAP        -mean(zs$CCAP        ,na.rm=T)
zs$Homelessc    <-zs$Homeless    -mean(zs$Homeless    ,na.rm=T)
zs$Homeless2c   <-zs$Homeless2   -mean(zs$Homeless2   ,na.rm=T)
zs$DHS_HFIrc    <-zs$DHS_HFIr    -mean(zs$DHS_HFIr    ,na.rm=T)
zs$DHS_PTSrc    <-zs$DHS_PTSr    -mean(zs$DHS_PTSr    ,na.rm=T)
zs$DHS_HVPrc    <-zs$DHS_HVPr    -mean(zs$DHS_HVPr    ,na.rm=T)
zs$IDHS_EIrc    <-zs$IDHS_EIr    -mean(zs$IDHS_EIr    ,na.rm=T)
zs$MHV_C4c      <-zs$MHV_C4      -mean(zs$MHV_C4      ,na.rm=T)
zs$MHV_P4c      <-zs$MHV_P4      -mean(zs$MHV_P4      ,na.rm=T)
zs$MHV_C5c      <-zs$MHV_C5      -mean(zs$MHV_C5      ,na.rm=T)
zs$MHV_P5c      <-zs$MHV_P5      -mean(zs$MHV_P5      ,na.rm=T)
zs$FoodInsPc    <-zs$FoodInsP    -mean(zs$FoodInsP    ,na.rm=T)
zs$FoodISc      <-zs$FoodIS      -mean(zs$FoodIS      ,na.rm=T)





# demean - within and between variables
zs<-cbind(zs,demean(zs,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - White
# Food Insecurity - White
# Food Insecurity - White
# Food Insecurity - White
# Food Insecurity - White
# Food Insecurity - White
# Food Insecurity - White
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
zw$Yearc        <-zw$Year        -mean(zw$Year        ,na.rm=T)
zw$CPopBPc      <-zw$CPopBP      -mean(zw$CPopBP      ,na.rm=T)
zw$CPopHPc      <-zw$CPopHP      -mean(zw$CPopHP      ,na.rm=T)
zw$ChildPTc     <-zw$ChildPT     -mean(zw$ChildPT     ,na.rm=T)
zw$ChildPWc     <-zw$ChildPW     -mean(zw$ChildPW     ,na.rm=T)
zw$ChildPBc     <-zw$ChildPB     -mean(zw$ChildPB     ,na.rm=T)
zw$ChildPHc     <-zw$ChildPH     -mean(zw$ChildPH     ,na.rm=T)
zw$CARatioT100c <-zw$CARatioT100 -mean(zw$CARatioT100 ,na.rm=T)
zw$CARatioW100c <-zw$CARatioW100 -mean(zw$CARatioW100 ,na.rm=T)
zw$CARatioB100c <-zw$CARatioB100 -mean(zw$CARatioB100 ,na.rm=T)
zw$CARatioH100c <-zw$CARatioH100 -mean(zw$CARatioH100 ,na.rm=T)
zw$MalePTc      <-zw$MalePT      -mean(zw$MalePT      ,na.rm=T)
zw$MalePWc      <-zw$MalePW      -mean(zw$MalePW      ,na.rm=T)
zw$MalePBc      <-zw$MalePB      -mean(zw$MalePB      ,na.rm=T)
zw$MalePHc      <-zw$MalePH      -mean(zw$MalePH      ,na.rm=T)
zw$MFRatioT100c <-zw$MFRatioT100 -mean(zw$MFRatioT100 ,na.rm=T)
zw$MFRatioW100c <-zw$MFRatioW100 -mean(zw$MFRatioW100 ,na.rm=T)
zw$MFRatioB100c <-zw$MFRatioB100 -mean(zw$MFRatioB100 ,na.rm=T)
zw$MFRatioH100c <-zw$MFRatioH100 -mean(zw$MFRatioH100 ,na.rm=T)
zw$ElderTc      <-zw$ElderT      -mean(zw$ElderT      ,na.rm=T)
zw$ElderWc      <-zw$ElderW      -mean(zw$ElderW      ,na.rm=T)
zw$ElderBc      <-zw$ElderB      -mean(zw$ElderB      ,na.rm=T)
zw$ElderHc      <-zw$ElderH      -mean(zw$ElderH      ,na.rm=T)
zw$SingleTc     <-zw$SingleT     -mean(zw$SingleT     ,na.rm=T)
zw$SingleWc     <-zw$SingleW     -mean(zw$SingleW     ,na.rm=T)
zw$SingleBc     <-zw$SingleB     -mean(zw$SingleB     ,na.rm=T)
zw$SingleHc     <-zw$SingleH     -mean(zw$SingleH     ,na.rm=T)
zw$FHeadTc      <-zw$FHeadT      -mean(zw$FHeadT      ,na.rm=T)
zw$FHeadWc      <-zw$FHeadW      -mean(zw$FHeadW      ,na.rm=T)
zw$FHeadBc      <-zw$FHeadB      -mean(zw$FHeadB      ,na.rm=T)
zw$FHeadHc      <-zw$FHeadH      -mean(zw$FHeadH      ,na.rm=T)
zw$NoHighTc     <-zw$NoHighT     -mean(zw$NoHighT     ,na.rm=T)
zw$NoHighWc     <-zw$NoHighW     -mean(zw$NoHighW     ,na.rm=T)
zw$NoHighBc     <-zw$NoHighB     -mean(zw$NoHighB     ,na.rm=T)
zw$NoHighHc     <-zw$NoHighH     -mean(zw$NoHighH     ,na.rm=T)
zw$UnempTc      <-zw$UnempT      -mean(zw$UnempT      ,na.rm=T)
zw$UnempWc      <-zw$UnempW      -mean(zw$UnempW      ,na.rm=T)
zw$UnempBc      <-zw$UnempB      -mean(zw$UnempB      ,na.rm=T)
zw$UnempHc      <-zw$UnempH      -mean(zw$UnempH      ,na.rm=T)
zw$CPovTc       <-zw$CPovT       -mean(zw$CPovT       ,na.rm=T)
zw$CPovWc       <-zw$CPovW       -mean(zw$CPovW       ,na.rm=T)
zw$CPovBc       <-zw$CPovB       -mean(zw$CPovB       ,na.rm=T)
zw$CPovHc       <-zw$CPovH       -mean(zw$CPovH       ,na.rm=T)
zw$CPov1c       <-zw$CPov1       -mean(zw$CPov1       ,na.rm=T)
zw$CPov2c       <-zw$CPov2       -mean(zw$CPov2       ,na.rm=T)
zw$CPov3c       <-zw$CPov3       -mean(zw$CPov3       ,na.rm=T)
zw$PubAsTc      <-zw$PubAsT      -mean(zw$PubAsT      ,na.rm=T)
zw$WelfarTc     <-zw$WelfarT     -mean(zw$WelfarT     ,na.rm=T)
zw$SnapTc       <-zw$SnapT       -mean(zw$SnapT       ,na.rm=T)
zw$SnapWc       <-zw$SnapW       -mean(zw$SnapW       ,na.rm=T)
zw$SnapBc       <-zw$SnapB       -mean(zw$SnapB       ,na.rm=T)
zw$SnapHc       <-zw$SnapH       -mean(zw$SnapH       ,na.rm=T)
zw$IncomeT1kc   <-zw$IncomeT1k   -mean(zw$IncomeT1k   ,na.rm=T)
zw$IncomeW1kc   <-zw$IncomeW1k   -mean(zw$IncomeW1k   ,na.rm=T)
zw$IncomeB1kc   <-zw$IncomeB1k   -mean(zw$IncomeB1k   ,na.rm=T)
zw$IncomeH1kc   <-zw$IncomeH1k   -mean(zw$IncomeH1k   ,na.rm=T)
zw$GiniT100c    <-zw$GiniT100    -mean(zw$GiniT100    ,na.rm=T)
zw$HValueT10kc  <-zw$HValueT10k  -mean(zw$HValueT10k  ,na.rm=T)
zw$MCostT100c   <-zw$MCostT100   -mean(zw$MCostT100   ,na.rm=T)
zw$OCostDT100c  <-zw$OCostDT100  -mean(zw$OCostDT100  ,na.rm=T)
zw$MRentDT100c  <-zw$MRentDT100  -mean(zw$MRentDT100  ,na.rm=T)
zw$OCostPTc     <-zw$OCostPT     -mean(zw$OCostPT     ,na.rm=T)
zw$MRentPTc     <-zw$MRentPT     -mean(zw$MRentPT     ,na.rm=T)
zw$MortgTc      <-zw$MortgT      -mean(zw$MortgT      ,na.rm=T)
zw$LangAPTc     <-zw$LangAPT     -mean(zw$LangAPT     ,na.rm=T)
zw$LangAPWc     <-zw$LangAPW     -mean(zw$LangAPW     ,na.rm=T)
zw$LangAPBc     <-zw$LangAPB     -mean(zw$LangAPB     ,na.rm=T)
zw$LangAPHc     <-zw$LangAPH     -mean(zw$LangAPH     ,na.rm=T)
zw$LangBPTc     <-zw$LangBPT     -mean(zw$LangBPT     ,na.rm=T)
zw$LangBPWc     <-zw$LangBPW     -mean(zw$LangBPW     ,na.rm=T)
zw$LangBPBc     <-zw$LangBPB     -mean(zw$LangBPB     ,na.rm=T)
zw$LangBPHc     <-zw$LangBPH     -mean(zw$LangBPH     ,na.rm=T)
zw$LangCPTc     <-zw$LangCPT     -mean(zw$LangCPT     ,na.rm=T)
zw$OutUsTc      <-zw$OutUsT      -mean(zw$OutUsT      ,na.rm=T)
zw$OutUsWc      <-zw$OutUsW      -mean(zw$OutUsW      ,na.rm=T)
zw$OutUsBc      <-zw$OutUsB      -mean(zw$OutUsB      ,na.rm=T)
zw$OutUsHc      <-zw$OutUsH      -mean(zw$OutUsH      ,na.rm=T)
zw$FBornTc      <-zw$FBornT      -mean(zw$FBornT      ,na.rm=T)
zw$FBornWc      <-zw$FBornW      -mean(zw$FBornW      ,na.rm=T)
zw$FBornBc      <-zw$FBornB      -mean(zw$FBornB      ,na.rm=T)
zw$FBornHc      <-zw$FBornH      -mean(zw$FBornH      ,na.rm=T)
zw$NotCtzTc     <-zw$NotCtzT     -mean(zw$NotCtzT     ,na.rm=T)
zw$NotCtzWc     <-zw$NotCtzW     -mean(zw$NotCtzW     ,na.rm=T)
zw$NotCtzBc     <-zw$NotCtzB     -mean(zw$NotCtzB     ,na.rm=T)
zw$NotCtzHc     <-zw$NotCtzH     -mean(zw$NotCtzH     ,na.rm=T)
zw$MoveTc       <-zw$MoveT       -mean(zw$MoveT       ,na.rm=T)
zw$MoveWc       <-zw$MoveW       -mean(zw$MoveW       ,na.rm=T)
zw$MoveBc       <-zw$MoveB       -mean(zw$MoveB       ,na.rm=T)
zw$MoveHc       <-zw$MoveH       -mean(zw$MoveH       ,na.rm=T)
zw$VacantTc     <-zw$VacantT     -mean(zw$VacantT     ,na.rm=T)
zw$OwnerTc      <-zw$OwnerT      -mean(zw$OwnerT      ,na.rm=T)
zw$OwnerWc      <-zw$OwnerW      -mean(zw$OwnerW      ,na.rm=T)
zw$OwnerBc      <-zw$OwnerB      -mean(zw$OwnerB      ,na.rm=T)
zw$OwnerHc      <-zw$OwnerH      -mean(zw$OwnerH      ,na.rm=T)
zw$CrowdTc      <-zw$CrowdT      -mean(zw$CrowdT      ,na.rm=T)
zw$CrowdWc      <-zw$CrowdW      -mean(zw$CrowdW      ,na.rm=T)
zw$CrowdBc      <-zw$CrowdB      -mean(zw$CrowdB      ,na.rm=T)
zw$CrowdHc      <-zw$CrowdH      -mean(zw$CrowdH      ,na.rm=T)
zw$MobileTc     <-zw$MobileT     -mean(zw$MobileT     ,na.rm=T)
zw$MobileWc     <-zw$MobileW     -mean(zw$MobileW     ,na.rm=T)
zw$MobileBc     <-zw$MobileB     -mean(zw$MobileB     ,na.rm=T)
zw$MobileHc     <-zw$MobileH     -mean(zw$MobileH     ,na.rm=T)
zw$DisablTc     <-zw$DisablT     -mean(zw$DisablT     ,na.rm=T)
zw$DisablWc     <-zw$DisablW     -mean(zw$DisablW     ,na.rm=T)
zw$DisablBc     <-zw$DisablB     -mean(zw$DisablB     ,na.rm=T)
zw$DisablHc     <-zw$DisablH     -mean(zw$DisablH     ,na.rm=T)
zw$DisablTCc    <-zw$DisablTC    -mean(zw$DisablTC    ,na.rm=T)
zw$DisablWCc    <-zw$DisablWC    -mean(zw$DisablWC    ,na.rm=T)
zw$DisablBCc    <-zw$DisablBC    -mean(zw$DisablBC    ,na.rm=T)
zw$DisablHCc    <-zw$DisablHC    -mean(zw$DisablHC    ,na.rm=T)
zw$DisablTMc    <-zw$DisablTM    -mean(zw$DisablTM    ,na.rm=T)
zw$DisablTFc    <-zw$DisablTF    -mean(zw$DisablTF    ,na.rm=T)
zw$Urban1c      <-zw$Urban1      -mean(zw$Urban1      ,na.rm=T)
zw$Urban2c      <-zw$Urban2      -mean(zw$Urban2      ,na.rm=T)
zw$ISBE_PFAc    <-zw$ISBE_PFA    -mean(zw$ISBE_PFA    ,na.rm=T)
zw$ISBE_PFAEc   <-zw$ISBE_PFAE   -mean(zw$ISBE_PFAE   ,na.rm=T)
zw$ISBE_PIc     <-zw$ISBE_PI     -mean(zw$ISBE_PI     ,na.rm=T)
zw$HeadStartc   <-zw$HeadStart   -mean(zw$HeadStart   ,na.rm=T)
zw$ElyHeadSc    <-zw$ElyHeadS    -mean(zw$ElyHeadS    ,na.rm=T)
zw$HeadSAllc    <-zw$HeadSAll    -mean(zw$HeadSAll    ,na.rm=T)
zw$PFA_HS1c     <-zw$PFA_HS1     -mean(zw$PFA_HS1     ,na.rm=T)
zw$PFA_HS2c     <-zw$PFA_HS2     -mean(zw$PFA_HS2     ,na.rm=T)
zw$LCCCc        <-zw$LCCC        -mean(zw$LCCC        ,na.rm=T)
zw$LECCCc       <-zw$LECCC       -mean(zw$LECCC       ,na.rm=T)
zw$LFCCc        <-zw$LFCC        -mean(zw$LFCC        ,na.rm=T)
zw$LLECCCc      <-zw$LLECCC      -mean(zw$LLECCC      ,na.rm=T)
zw$LCLFCCc      <-zw$LCLFCC      -mean(zw$LCLFCC      ,na.rm=T)
zw$LCCCB1c      <-zw$LCCCB1      -mean(zw$LCCCB1      ,na.rm=T)
zw$LCCCB2c      <-zw$LCCCB2      -mean(zw$LCCCB2      ,na.rm=T)
zw$LCCB1c       <-zw$LCCB1       -mean(zw$LCCB1       ,na.rm=T)
zw$LCCB2c       <-zw$LCCB2       -mean(zw$LCCB2       ,na.rm=T)
zw$LCCCS1c      <-zw$LCCCS1      -mean(zw$LCCCS1      ,na.rm=T)
zw$LCCCS2c      <-zw$LCCCS2      -mean(zw$LCCCS2      ,na.rm=T)
zw$LCCS1c       <-zw$LCCS1       -mean(zw$LCCS1       ,na.rm=T)
zw$LCCS2c       <-zw$LCCS2       -mean(zw$LCCS2       ,na.rm=T)
zw$LCCCG1c      <-zw$LCCCG1      -mean(zw$LCCCG1      ,na.rm=T)
zw$LCCCG2c      <-zw$LCCCG2      -mean(zw$LCCCG2      ,na.rm=T)
zw$LCCG1c       <-zw$LCCG1       -mean(zw$LCCG1       ,na.rm=T)
zw$LCCG2c       <-zw$LCCG2       -mean(zw$LCCG2       ,na.rm=T)
zw$ChildCare1c  <-zw$ChildCare1  -mean(zw$ChildCare1  ,na.rm=T)
zw$ChildCare2c  <-zw$ChildCare2  -mean(zw$ChildCare2  ,na.rm=T)
zw$ChildCare3c  <-zw$ChildCare3  -mean(zw$ChildCare3  ,na.rm=T)
zw$CCAPc        <-zw$CCAP        -mean(zw$CCAP        ,na.rm=T)
zw$Homelessc    <-zw$Homeless    -mean(zw$Homeless    ,na.rm=T)
zw$Homeless2c   <-zw$Homeless2   -mean(zw$Homeless2   ,na.rm=T)
zw$DHS_HFIrc    <-zw$DHS_HFIr    -mean(zw$DHS_HFIr    ,na.rm=T)
zw$DHS_PTSrc    <-zw$DHS_PTSr    -mean(zw$DHS_PTSr    ,na.rm=T)
zw$DHS_HVPrc    <-zw$DHS_HVPr    -mean(zw$DHS_HVPr    ,na.rm=T)
zw$IDHS_EIrc    <-zw$IDHS_EIr    -mean(zw$IDHS_EIr    ,na.rm=T)
zw$MHV_C4c      <-zw$MHV_C4      -mean(zw$MHV_C4      ,na.rm=T)
zw$MHV_P4c      <-zw$MHV_P4      -mean(zw$MHV_P4      ,na.rm=T)
zw$MHV_C5c      <-zw$MHV_C5      -mean(zw$MHV_C5      ,na.rm=T)
zw$MHV_P5c      <-zw$MHV_P5      -mean(zw$MHV_P5      ,na.rm=T)
zw$FoodInsPc    <-zw$FoodInsP    -mean(zw$FoodInsP    ,na.rm=T)
zw$FoodISc      <-zw$FoodIS      -mean(zw$FoodIS      ,na.rm=T)





# demean - within and between variables
zw<-cbind(zw,demean(zw,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Black
# Food Insecurity - Black
# Food Insecurity - Black
# Food Insecurity - Black
# Food Insecurity - Black
# Food Insecurity - Black
# Food Insecurity - Black
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
zb$Yearc        <-zb$Year        -mean(zb$Year        ,na.rm=T)
zb$CPopBPc      <-zb$CPopBP      -mean(zb$CPopBP      ,na.rm=T)
zb$CPopHPc      <-zb$CPopHP      -mean(zb$CPopHP      ,na.rm=T)
zb$ChildPTc     <-zb$ChildPT     -mean(zb$ChildPT     ,na.rm=T)
zb$ChildPWc     <-zb$ChildPW     -mean(zb$ChildPW     ,na.rm=T)
zb$ChildPBc     <-zb$ChildPB     -mean(zb$ChildPB     ,na.rm=T)
zb$ChildPHc     <-zb$ChildPH     -mean(zb$ChildPH     ,na.rm=T)
zb$CARatioT100c <-zb$CARatioT100 -mean(zb$CARatioT100 ,na.rm=T)
zb$CARatioW100c <-zb$CARatioW100 -mean(zb$CARatioW100 ,na.rm=T)
zb$CARatioB100c <-zb$CARatioB100 -mean(zb$CARatioB100 ,na.rm=T)
zb$CARatioH100c <-zb$CARatioH100 -mean(zb$CARatioH100 ,na.rm=T)
zb$MalePTc      <-zb$MalePT      -mean(zb$MalePT      ,na.rm=T)
zb$MalePWc      <-zb$MalePW      -mean(zb$MalePW      ,na.rm=T)
zb$MalePBc      <-zb$MalePB      -mean(zb$MalePB      ,na.rm=T)
zb$MalePHc      <-zb$MalePH      -mean(zb$MalePH      ,na.rm=T)
zb$MFRatioT100c <-zb$MFRatioT100 -mean(zb$MFRatioT100 ,na.rm=T)
zb$MFRatioW100c <-zb$MFRatioW100 -mean(zb$MFRatioW100 ,na.rm=T)
zb$MFRatioB100c <-zb$MFRatioB100 -mean(zb$MFRatioB100 ,na.rm=T)
zb$MFRatioH100c <-zb$MFRatioH100 -mean(zb$MFRatioH100 ,na.rm=T)
zb$ElderTc      <-zb$ElderT      -mean(zb$ElderT      ,na.rm=T)
zb$ElderWc      <-zb$ElderW      -mean(zb$ElderW      ,na.rm=T)
zb$ElderBc      <-zb$ElderB      -mean(zb$ElderB      ,na.rm=T)
zb$ElderHc      <-zb$ElderH      -mean(zb$ElderH      ,na.rm=T)
zb$SingleTc     <-zb$SingleT     -mean(zb$SingleT     ,na.rm=T)
zb$SingleWc     <-zb$SingleW     -mean(zb$SingleW     ,na.rm=T)
zb$SingleBc     <-zb$SingleB     -mean(zb$SingleB     ,na.rm=T)
zb$SingleHc     <-zb$SingleH     -mean(zb$SingleH     ,na.rm=T)
zb$FHeadTc      <-zb$FHeadT      -mean(zb$FHeadT      ,na.rm=T)
zb$FHeadWc      <-zb$FHeadW      -mean(zb$FHeadW      ,na.rm=T)
zb$FHeadBc      <-zb$FHeadB      -mean(zb$FHeadB      ,na.rm=T)
zb$FHeadHc      <-zb$FHeadH      -mean(zb$FHeadH      ,na.rm=T)
zb$NoHighTc     <-zb$NoHighT     -mean(zb$NoHighT     ,na.rm=T)
zb$NoHighWc     <-zb$NoHighW     -mean(zb$NoHighW     ,na.rm=T)
zb$NoHighBc     <-zb$NoHighB     -mean(zb$NoHighB     ,na.rm=T)
zb$NoHighHc     <-zb$NoHighH     -mean(zb$NoHighH     ,na.rm=T)
zb$UnempTc      <-zb$UnempT      -mean(zb$UnempT      ,na.rm=T)
zb$UnempWc      <-zb$UnempW      -mean(zb$UnempW      ,na.rm=T)
zb$UnempBc      <-zb$UnempB      -mean(zb$UnempB      ,na.rm=T)
zb$UnempHc      <-zb$UnempH      -mean(zb$UnempH      ,na.rm=T)
zb$CPovTc       <-zb$CPovT       -mean(zb$CPovT       ,na.rm=T)
zb$CPovWc       <-zb$CPovW       -mean(zb$CPovW       ,na.rm=T)
zb$CPovBc       <-zb$CPovB       -mean(zb$CPovB       ,na.rm=T)
zb$CPovHc       <-zb$CPovH       -mean(zb$CPovH       ,na.rm=T)
zb$CPov1c       <-zb$CPov1       -mean(zb$CPov1       ,na.rm=T)
zb$CPov2c       <-zb$CPov2       -mean(zb$CPov2       ,na.rm=T)
zb$CPov3c       <-zb$CPov3       -mean(zb$CPov3       ,na.rm=T)
zb$PubAsTc      <-zb$PubAsT      -mean(zb$PubAsT      ,na.rm=T)
zb$WelfarTc     <-zb$WelfarT     -mean(zb$WelfarT     ,na.rm=T)
zb$SnapTc       <-zb$SnapT       -mean(zb$SnapT       ,na.rm=T)
zb$SnapWc       <-zb$SnapW       -mean(zb$SnapW       ,na.rm=T)
zb$SnapBc       <-zb$SnapB       -mean(zb$SnapB       ,na.rm=T)
zb$SnapHc       <-zb$SnapH       -mean(zb$SnapH       ,na.rm=T)
zb$IncomeT1kc   <-zb$IncomeT1k   -mean(zb$IncomeT1k   ,na.rm=T)
zb$IncomeW1kc   <-zb$IncomeW1k   -mean(zb$IncomeW1k   ,na.rm=T)
zb$IncomeB1kc   <-zb$IncomeB1k   -mean(zb$IncomeB1k   ,na.rm=T)
zb$IncomeH1kc   <-zb$IncomeH1k   -mean(zb$IncomeH1k   ,na.rm=T)
zb$GiniT100c    <-zb$GiniT100    -mean(zb$GiniT100    ,na.rm=T)
zb$HValueT10kc  <-zb$HValueT10k  -mean(zb$HValueT10k  ,na.rm=T)
zb$MCostT100c   <-zb$MCostT100   -mean(zb$MCostT100   ,na.rm=T)
zb$OCostDT100c  <-zb$OCostDT100  -mean(zb$OCostDT100  ,na.rm=T)
zb$MRentDT100c  <-zb$MRentDT100  -mean(zb$MRentDT100  ,na.rm=T)
zb$OCostPTc     <-zb$OCostPT     -mean(zb$OCostPT     ,na.rm=T)
zb$MRentPTc     <-zb$MRentPT     -mean(zb$MRentPT     ,na.rm=T)
zb$MortgTc      <-zb$MortgT      -mean(zb$MortgT      ,na.rm=T)
zb$LangAPTc     <-zb$LangAPT     -mean(zb$LangAPT     ,na.rm=T)
zb$LangAPWc     <-zb$LangAPW     -mean(zb$LangAPW     ,na.rm=T)
zb$LangAPBc     <-zb$LangAPB     -mean(zb$LangAPB     ,na.rm=T)
zb$LangAPHc     <-zb$LangAPH     -mean(zb$LangAPH     ,na.rm=T)
zb$LangBPTc     <-zb$LangBPT     -mean(zb$LangBPT     ,na.rm=T)
zb$LangBPWc     <-zb$LangBPW     -mean(zb$LangBPW     ,na.rm=T)
zb$LangBPBc     <-zb$LangBPB     -mean(zb$LangBPB     ,na.rm=T)
zb$LangBPHc     <-zb$LangBPH     -mean(zb$LangBPH     ,na.rm=T)
zb$LangCPTc     <-zb$LangCPT     -mean(zb$LangCPT     ,na.rm=T)
zb$OutUsTc      <-zb$OutUsT      -mean(zb$OutUsT      ,na.rm=T)
zb$OutUsWc      <-zb$OutUsW      -mean(zb$OutUsW      ,na.rm=T)
zb$OutUsBc      <-zb$OutUsB      -mean(zb$OutUsB      ,na.rm=T)
zb$OutUsHc      <-zb$OutUsH      -mean(zb$OutUsH      ,na.rm=T)
zb$FBornTc      <-zb$FBornT      -mean(zb$FBornT      ,na.rm=T)
zb$FBornWc      <-zb$FBornW      -mean(zb$FBornW      ,na.rm=T)
zb$FBornBc      <-zb$FBornB      -mean(zb$FBornB      ,na.rm=T)
zb$FBornHc      <-zb$FBornH      -mean(zb$FBornH      ,na.rm=T)
zb$NotCtzTc     <-zb$NotCtzT     -mean(zb$NotCtzT     ,na.rm=T)
zb$NotCtzWc     <-zb$NotCtzW     -mean(zb$NotCtzW     ,na.rm=T)
zb$NotCtzBc     <-zb$NotCtzB     -mean(zb$NotCtzB     ,na.rm=T)
zb$NotCtzHc     <-zb$NotCtzH     -mean(zb$NotCtzH     ,na.rm=T)
zb$MoveTc       <-zb$MoveT       -mean(zb$MoveT       ,na.rm=T)
zb$MoveWc       <-zb$MoveW       -mean(zb$MoveW       ,na.rm=T)
zb$MoveBc       <-zb$MoveB       -mean(zb$MoveB       ,na.rm=T)
zb$MoveHc       <-zb$MoveH       -mean(zb$MoveH       ,na.rm=T)
zb$VacantTc     <-zb$VacantT     -mean(zb$VacantT     ,na.rm=T)
zb$OwnerTc      <-zb$OwnerT      -mean(zb$OwnerT      ,na.rm=T)
zb$OwnerWc      <-zb$OwnerW      -mean(zb$OwnerW      ,na.rm=T)
zb$OwnerBc      <-zb$OwnerB      -mean(zb$OwnerB      ,na.rm=T)
zb$OwnerHc      <-zb$OwnerH      -mean(zb$OwnerH      ,na.rm=T)
zb$CrowdTc      <-zb$CrowdT      -mean(zb$CrowdT      ,na.rm=T)
zb$CrowdWc      <-zb$CrowdW      -mean(zb$CrowdW      ,na.rm=T)
zb$CrowdBc      <-zb$CrowdB      -mean(zb$CrowdB      ,na.rm=T)
zb$CrowdHc      <-zb$CrowdH      -mean(zb$CrowdH      ,na.rm=T)
zb$MobileTc     <-zb$MobileT     -mean(zb$MobileT     ,na.rm=T)
zb$MobileWc     <-zb$MobileW     -mean(zb$MobileW     ,na.rm=T)
zb$MobileBc     <-zb$MobileB     -mean(zb$MobileB     ,na.rm=T)
zb$MobileHc     <-zb$MobileH     -mean(zb$MobileH     ,na.rm=T)
zb$DisablTc     <-zb$DisablT     -mean(zb$DisablT     ,na.rm=T)
zb$DisablWc     <-zb$DisablW     -mean(zb$DisablW     ,na.rm=T)
zb$DisablBc     <-zb$DisablB     -mean(zb$DisablB     ,na.rm=T)
zb$DisablHc     <-zb$DisablH     -mean(zb$DisablH     ,na.rm=T)
zb$DisablTCc    <-zb$DisablTC    -mean(zb$DisablTC    ,na.rm=T)
zb$DisablWCc    <-zb$DisablWC    -mean(zb$DisablWC    ,na.rm=T)
zb$DisablBCc    <-zb$DisablBC    -mean(zb$DisablBC    ,na.rm=T)
zb$DisablHCc    <-zb$DisablHC    -mean(zb$DisablHC    ,na.rm=T)
zb$DisablTMc    <-zb$DisablTM    -mean(zb$DisablTM    ,na.rm=T)
zb$DisablTFc    <-zb$DisablTF    -mean(zb$DisablTF    ,na.rm=T)
zb$Urban1c      <-zb$Urban1      -mean(zb$Urban1      ,na.rm=T)
zb$Urban2c      <-zb$Urban2      -mean(zb$Urban2      ,na.rm=T)
zb$ISBE_PFAc    <-zb$ISBE_PFA    -mean(zb$ISBE_PFA    ,na.rm=T)
zb$ISBE_PFAEc   <-zb$ISBE_PFAE   -mean(zb$ISBE_PFAE   ,na.rm=T)
zb$ISBE_PIc     <-zb$ISBE_PI     -mean(zb$ISBE_PI     ,na.rm=T)
zb$HeadStartc   <-zb$HeadStart   -mean(zb$HeadStart   ,na.rm=T)
zb$ElyHeadSc    <-zb$ElyHeadS    -mean(zb$ElyHeadS    ,na.rm=T)
zb$HeadSAllc    <-zb$HeadSAll    -mean(zb$HeadSAll    ,na.rm=T)
zb$PFA_HS1c     <-zb$PFA_HS1     -mean(zb$PFA_HS1     ,na.rm=T)
zb$PFA_HS2c     <-zb$PFA_HS2     -mean(zb$PFA_HS2     ,na.rm=T)
zb$LCCCc        <-zb$LCCC        -mean(zb$LCCC        ,na.rm=T)
zb$LECCCc       <-zb$LECCC       -mean(zb$LECCC       ,na.rm=T)
zb$LFCCc        <-zb$LFCC        -mean(zb$LFCC        ,na.rm=T)
zb$LLECCCc      <-zb$LLECCC      -mean(zb$LLECCC      ,na.rm=T)
zb$LCLFCCc      <-zb$LCLFCC      -mean(zb$LCLFCC      ,na.rm=T)
zb$LCCCB1c      <-zb$LCCCB1      -mean(zb$LCCCB1      ,na.rm=T)
zb$LCCCB2c      <-zb$LCCCB2      -mean(zb$LCCCB2      ,na.rm=T)
zb$LCCB1c       <-zb$LCCB1       -mean(zb$LCCB1       ,na.rm=T)
zb$LCCB2c       <-zb$LCCB2       -mean(zb$LCCB2       ,na.rm=T)
zb$LCCCS1c      <-zb$LCCCS1      -mean(zb$LCCCS1      ,na.rm=T)
zb$LCCCS2c      <-zb$LCCCS2      -mean(zb$LCCCS2      ,na.rm=T)
zb$LCCS1c       <-zb$LCCS1       -mean(zb$LCCS1       ,na.rm=T)
zb$LCCS2c       <-zb$LCCS2       -mean(zb$LCCS2       ,na.rm=T)
zb$LCCCG1c      <-zb$LCCCG1      -mean(zb$LCCCG1      ,na.rm=T)
zb$LCCCG2c      <-zb$LCCCG2      -mean(zb$LCCCG2      ,na.rm=T)
zb$LCCG1c       <-zb$LCCG1       -mean(zb$LCCG1       ,na.rm=T)
zb$LCCG2c       <-zb$LCCG2       -mean(zb$LCCG2       ,na.rm=T)
zb$ChildCare1c  <-zb$ChildCare1  -mean(zb$ChildCare1  ,na.rm=T)
zb$ChildCare2c  <-zb$ChildCare2  -mean(zb$ChildCare2  ,na.rm=T)
zb$ChildCare3c  <-zb$ChildCare3  -mean(zb$ChildCare3  ,na.rm=T)
zb$CCAPc        <-zb$CCAP        -mean(zb$CCAP        ,na.rm=T)
zb$Homelessc    <-zb$Homeless    -mean(zb$Homeless    ,na.rm=T)
zb$Homeless2c   <-zb$Homeless2   -mean(zb$Homeless2   ,na.rm=T)
zb$DHS_HFIrc    <-zb$DHS_HFIr    -mean(zb$DHS_HFIr    ,na.rm=T)
zb$DHS_PTSrc    <-zb$DHS_PTSr    -mean(zb$DHS_PTSr    ,na.rm=T)
zb$DHS_HVPrc    <-zb$DHS_HVPr    -mean(zb$DHS_HVPr    ,na.rm=T)
zb$IDHS_EIrc    <-zb$IDHS_EIr    -mean(zb$IDHS_EIr    ,na.rm=T)
zb$MHV_C4c      <-zb$MHV_C4      -mean(zb$MHV_C4      ,na.rm=T)
zb$MHV_P4c      <-zb$MHV_P4      -mean(zb$MHV_P4      ,na.rm=T)
zb$MHV_C5c      <-zb$MHV_C5      -mean(zb$MHV_C5      ,na.rm=T)
zb$MHV_P5c      <-zb$MHV_P5      -mean(zb$MHV_P5      ,na.rm=T)
zb$FoodInsPc    <-zb$FoodInsP    -mean(zb$FoodInsP    ,na.rm=T)
zb$FoodISc      <-zb$FoodIS      -mean(zb$FoodIS      ,na.rm=T)





# demean - within and between variables
zb<-cbind(zb,demean(zb,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc"
),group="CountyFIPS"))





###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
# Food Insecurity - Hispanic
# Food Insecurity - Hispanic
# Food Insecurity - Hispanic
# Food Insecurity - Hispanic
# Food Insecurity - Hispanic
# Food Insecurity - Hispanic
# Food Insecurity - Hispanic
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################
###############################################################################################################

# Centering Variables
zh$Yearc        <-zh$Year        -mean(zh$Year        ,na.rm=T)
zh$CPopBPc      <-zh$CPopBP      -mean(zh$CPopBP      ,na.rm=T)
zh$CPopHPc      <-zh$CPopHP      -mean(zh$CPopHP      ,na.rm=T)
zh$ChildPTc     <-zh$ChildPT     -mean(zh$ChildPT     ,na.rm=T)
zh$ChildPWc     <-zh$ChildPW     -mean(zh$ChildPW     ,na.rm=T)
zh$ChildPBc     <-zh$ChildPB     -mean(zh$ChildPB     ,na.rm=T)
zh$ChildPHc     <-zh$ChildPH     -mean(zh$ChildPH     ,na.rm=T)
zh$CARatioT100c <-zh$CARatioT100 -mean(zh$CARatioT100 ,na.rm=T)
zh$CARatioW100c <-zh$CARatioW100 -mean(zh$CARatioW100 ,na.rm=T)
zh$CARatioB100c <-zh$CARatioB100 -mean(zh$CARatioB100 ,na.rm=T)
zh$CARatioH100c <-zh$CARatioH100 -mean(zh$CARatioH100 ,na.rm=T)
zh$MalePTc      <-zh$MalePT      -mean(zh$MalePT      ,na.rm=T)
zh$MalePWc      <-zh$MalePW      -mean(zh$MalePW      ,na.rm=T)
zh$MalePBc      <-zh$MalePB      -mean(zh$MalePB      ,na.rm=T)
zh$MalePHc      <-zh$MalePH      -mean(zh$MalePH      ,na.rm=T)
zh$MFRatioT100c <-zh$MFRatioT100 -mean(zh$MFRatioT100 ,na.rm=T)
zh$MFRatioW100c <-zh$MFRatioW100 -mean(zh$MFRatioW100 ,na.rm=T)
zh$MFRatioB100c <-zh$MFRatioB100 -mean(zh$MFRatioB100 ,na.rm=T)
zh$MFRatioH100c <-zh$MFRatioH100 -mean(zh$MFRatioH100 ,na.rm=T)
zh$ElderTc      <-zh$ElderT      -mean(zh$ElderT      ,na.rm=T)
zh$ElderWc      <-zh$ElderW      -mean(zh$ElderW      ,na.rm=T)
zh$ElderBc      <-zh$ElderB      -mean(zh$ElderB      ,na.rm=T)
zh$ElderHc      <-zh$ElderH      -mean(zh$ElderH      ,na.rm=T)
zh$SingleTc     <-zh$SingleT     -mean(zh$SingleT     ,na.rm=T)
zh$SingleWc     <-zh$SingleW     -mean(zh$SingleW     ,na.rm=T)
zh$SingleBc     <-zh$SingleB     -mean(zh$SingleB     ,na.rm=T)
zh$SingleHc     <-zh$SingleH     -mean(zh$SingleH     ,na.rm=T)
zh$FHeadTc      <-zh$FHeadT      -mean(zh$FHeadT      ,na.rm=T)
zh$FHeadWc      <-zh$FHeadW      -mean(zh$FHeadW      ,na.rm=T)
zh$FHeadBc      <-zh$FHeadB      -mean(zh$FHeadB      ,na.rm=T)
zh$FHeadHc      <-zh$FHeadH      -mean(zh$FHeadH      ,na.rm=T)
zh$NoHighTc     <-zh$NoHighT     -mean(zh$NoHighT     ,na.rm=T)
zh$NoHighWc     <-zh$NoHighW     -mean(zh$NoHighW     ,na.rm=T)
zh$NoHighBc     <-zh$NoHighB     -mean(zh$NoHighB     ,na.rm=T)
zh$NoHighHc     <-zh$NoHighH     -mean(zh$NoHighH     ,na.rm=T)
zh$UnempTc      <-zh$UnempT      -mean(zh$UnempT      ,na.rm=T)
zh$UnempWc      <-zh$UnempW      -mean(zh$UnempW      ,na.rm=T)
zh$UnempBc      <-zh$UnempB      -mean(zh$UnempB      ,na.rm=T)
zh$UnempHc      <-zh$UnempH      -mean(zh$UnempH      ,na.rm=T)
zh$CPovTc       <-zh$CPovT       -mean(zh$CPovT       ,na.rm=T)
zh$CPovWc       <-zh$CPovW       -mean(zh$CPovW       ,na.rm=T)
zh$CPovBc       <-zh$CPovB       -mean(zh$CPovB       ,na.rm=T)
zh$CPovHc       <-zh$CPovH       -mean(zh$CPovH       ,na.rm=T)
zh$CPov1c       <-zh$CPov1       -mean(zh$CPov1       ,na.rm=T)
zh$CPov2c       <-zh$CPov2       -mean(zh$CPov2       ,na.rm=T)
zh$CPov3c       <-zh$CPov3       -mean(zh$CPov3       ,na.rm=T)
zh$PubAsTc      <-zh$PubAsT      -mean(zh$PubAsT      ,na.rm=T)
zh$WelfarTc     <-zh$WelfarT     -mean(zh$WelfarT     ,na.rm=T)
zh$SnapTc       <-zh$SnapT       -mean(zh$SnapT       ,na.rm=T)
zh$SnapWc       <-zh$SnapW       -mean(zh$SnapW       ,na.rm=T)
zh$SnapBc       <-zh$SnapB       -mean(zh$SnapB       ,na.rm=T)
zh$SnapHc       <-zh$SnapH       -mean(zh$SnapH       ,na.rm=T)
zh$IncomeT1kc   <-zh$IncomeT1k   -mean(zh$IncomeT1k   ,na.rm=T)
zh$IncomeW1kc   <-zh$IncomeW1k   -mean(zh$IncomeW1k   ,na.rm=T)
zh$IncomeB1kc   <-zh$IncomeB1k   -mean(zh$IncomeB1k   ,na.rm=T)
zh$IncomeH1kc   <-zh$IncomeH1k   -mean(zh$IncomeH1k   ,na.rm=T)
zh$GiniT100c    <-zh$GiniT100    -mean(zh$GiniT100    ,na.rm=T)
zh$HValueT10kc  <-zh$HValueT10k  -mean(zh$HValueT10k  ,na.rm=T)
zh$MCostT100c   <-zh$MCostT100   -mean(zh$MCostT100   ,na.rm=T)
zh$OCostDT100c  <-zh$OCostDT100  -mean(zh$OCostDT100  ,na.rm=T)
zh$MRentDT100c  <-zh$MRentDT100  -mean(zh$MRentDT100  ,na.rm=T)
zh$OCostPTc     <-zh$OCostPT     -mean(zh$OCostPT     ,na.rm=T)
zh$MRentPTc     <-zh$MRentPT     -mean(zh$MRentPT     ,na.rm=T)
zh$MortgTc      <-zh$MortgT      -mean(zh$MortgT      ,na.rm=T)
zh$LangAPTc     <-zh$LangAPT     -mean(zh$LangAPT     ,na.rm=T)
zh$LangAPWc     <-zh$LangAPW     -mean(zh$LangAPW     ,na.rm=T)
zh$LangAPBc     <-zh$LangAPB     -mean(zh$LangAPB     ,na.rm=T)
zh$LangAPHc     <-zh$LangAPH     -mean(zh$LangAPH     ,na.rm=T)
zh$LangBPTc     <-zh$LangBPT     -mean(zh$LangBPT     ,na.rm=T)
zh$LangBPWc     <-zh$LangBPW     -mean(zh$LangBPW     ,na.rm=T)
zh$LangBPBc     <-zh$LangBPB     -mean(zh$LangBPB     ,na.rm=T)
zh$LangBPHc     <-zh$LangBPH     -mean(zh$LangBPH     ,na.rm=T)
zh$LangCPTc     <-zh$LangCPT     -mean(zh$LangCPT     ,na.rm=T)
zh$OutUsTc      <-zh$OutUsT      -mean(zh$OutUsT      ,na.rm=T)
zh$OutUsWc      <-zh$OutUsW      -mean(zh$OutUsW      ,na.rm=T)
zh$OutUsBc      <-zh$OutUsB      -mean(zh$OutUsB      ,na.rm=T)
zh$OutUsHc      <-zh$OutUsH      -mean(zh$OutUsH      ,na.rm=T)
zh$FBornTc      <-zh$FBornT      -mean(zh$FBornT      ,na.rm=T)
zh$FBornWc      <-zh$FBornW      -mean(zh$FBornW      ,na.rm=T)
zh$FBornBc      <-zh$FBornB      -mean(zh$FBornB      ,na.rm=T)
zh$FBornHc      <-zh$FBornH      -mean(zh$FBornH      ,na.rm=T)
zh$NotCtzTc     <-zh$NotCtzT     -mean(zh$NotCtzT     ,na.rm=T)
zh$NotCtzWc     <-zh$NotCtzW     -mean(zh$NotCtzW     ,na.rm=T)
zh$NotCtzBc     <-zh$NotCtzB     -mean(zh$NotCtzB     ,na.rm=T)
zh$NotCtzHc     <-zh$NotCtzH     -mean(zh$NotCtzH     ,na.rm=T)
zh$MoveTc       <-zh$MoveT       -mean(zh$MoveT       ,na.rm=T)
zh$MoveWc       <-zh$MoveW       -mean(zh$MoveW       ,na.rm=T)
zh$MoveBc       <-zh$MoveB       -mean(zh$MoveB       ,na.rm=T)
zh$MoveHc       <-zh$MoveH       -mean(zh$MoveH       ,na.rm=T)
zh$VacantTc     <-zh$VacantT     -mean(zh$VacantT     ,na.rm=T)
zh$OwnerTc      <-zh$OwnerT      -mean(zh$OwnerT      ,na.rm=T)
zh$OwnerWc      <-zh$OwnerW      -mean(zh$OwnerW      ,na.rm=T)
zh$OwnerBc      <-zh$OwnerB      -mean(zh$OwnerB      ,na.rm=T)
zh$OwnerHc      <-zh$OwnerH      -mean(zh$OwnerH      ,na.rm=T)
zh$CrowdTc      <-zh$CrowdT      -mean(zh$CrowdT      ,na.rm=T)
zh$CrowdWc      <-zh$CrowdW      -mean(zh$CrowdW      ,na.rm=T)
zh$CrowdBc      <-zh$CrowdB      -mean(zh$CrowdB      ,na.rm=T)
zh$CrowdHc      <-zh$CrowdH      -mean(zh$CrowdH      ,na.rm=T)
zh$MobileTc     <-zh$MobileT     -mean(zh$MobileT     ,na.rm=T)
zh$MobileWc     <-zh$MobileW     -mean(zh$MobileW     ,na.rm=T)
zh$MobileBc     <-zh$MobileB     -mean(zh$MobileB     ,na.rm=T)
zh$MobileHc     <-zh$MobileH     -mean(zh$MobileH     ,na.rm=T)
zh$DisablTc     <-zh$DisablT     -mean(zh$DisablT     ,na.rm=T)
zh$DisablWc     <-zh$DisablW     -mean(zh$DisablW     ,na.rm=T)
zh$DisablBc     <-zh$DisablB     -mean(zh$DisablB     ,na.rm=T)
zh$DisablHc     <-zh$DisablH     -mean(zh$DisablH     ,na.rm=T)
zh$DisablTCc    <-zh$DisablTC    -mean(zh$DisablTC    ,na.rm=T)
zh$DisablWCc    <-zh$DisablWC    -mean(zh$DisablWC    ,na.rm=T)
zh$DisablBCc    <-zh$DisablBC    -mean(zh$DisablBC    ,na.rm=T)
zh$DisablHCc    <-zh$DisablHC    -mean(zh$DisablHC    ,na.rm=T)
zh$DisablTMc    <-zh$DisablTM    -mean(zh$DisablTM    ,na.rm=T)
zh$DisablTFc    <-zh$DisablTF    -mean(zh$DisablTF    ,na.rm=T)
zh$Urban1c      <-zh$Urban1      -mean(zh$Urban1      ,na.rm=T)
zh$Urban2c      <-zh$Urban2      -mean(zh$Urban2      ,na.rm=T)
zh$ISBE_PFAc    <-zh$ISBE_PFA    -mean(zh$ISBE_PFA    ,na.rm=T)
zh$ISBE_PFAEc   <-zh$ISBE_PFAE   -mean(zh$ISBE_PFAE   ,na.rm=T)
zh$ISBE_PIc     <-zh$ISBE_PI     -mean(zh$ISBE_PI     ,na.rm=T)
zh$HeadStartc   <-zh$HeadStart   -mean(zh$HeadStart   ,na.rm=T)
zh$ElyHeadSc    <-zh$ElyHeadS    -mean(zh$ElyHeadS    ,na.rm=T)
zh$HeadSAllc    <-zh$HeadSAll    -mean(zh$HeadSAll    ,na.rm=T)
zh$PFA_HS1c     <-zh$PFA_HS1     -mean(zh$PFA_HS1     ,na.rm=T)
zh$PFA_HS2c     <-zh$PFA_HS2     -mean(zh$PFA_HS2     ,na.rm=T)
zh$LCCCc        <-zh$LCCC        -mean(zh$LCCC        ,na.rm=T)
zh$LECCCc       <-zh$LECCC       -mean(zh$LECCC       ,na.rm=T)
zh$LFCCc        <-zh$LFCC        -mean(zh$LFCC        ,na.rm=T)
zh$LLECCCc      <-zh$LLECCC      -mean(zh$LLECCC      ,na.rm=T)
zh$LCLFCCc      <-zh$LCLFCC      -mean(zh$LCLFCC      ,na.rm=T)
zh$LCCCB1c      <-zh$LCCCB1      -mean(zh$LCCCB1      ,na.rm=T)
zh$LCCCB2c      <-zh$LCCCB2      -mean(zh$LCCCB2      ,na.rm=T)
zh$LCCB1c       <-zh$LCCB1       -mean(zh$LCCB1       ,na.rm=T)
zh$LCCB2c       <-zh$LCCB2       -mean(zh$LCCB2       ,na.rm=T)
zh$LCCCS1c      <-zh$LCCCS1      -mean(zh$LCCCS1      ,na.rm=T)
zh$LCCCS2c      <-zh$LCCCS2      -mean(zh$LCCCS2      ,na.rm=T)
zh$LCCS1c       <-zh$LCCS1       -mean(zh$LCCS1       ,na.rm=T)
zh$LCCS2c       <-zh$LCCS2       -mean(zh$LCCS2       ,na.rm=T)
zh$LCCCG1c      <-zh$LCCCG1      -mean(zh$LCCCG1      ,na.rm=T)
zh$LCCCG2c      <-zh$LCCCG2      -mean(zh$LCCCG2      ,na.rm=T)
zh$LCCG1c       <-zh$LCCG1       -mean(zh$LCCG1       ,na.rm=T)
zh$LCCG2c       <-zh$LCCG2       -mean(zh$LCCG2       ,na.rm=T)
zh$ChildCare1c  <-zh$ChildCare1  -mean(zh$ChildCare1  ,na.rm=T)
zh$ChildCare2c  <-zh$ChildCare2  -mean(zh$ChildCare2  ,na.rm=T)
zh$ChildCare3c  <-zh$ChildCare3  -mean(zh$ChildCare3  ,na.rm=T)
zh$CCAPc        <-zh$CCAP        -mean(zh$CCAP        ,na.rm=T)
zh$Homelessc    <-zh$Homeless    -mean(zh$Homeless    ,na.rm=T)
zh$Homeless2c   <-zh$Homeless2   -mean(zh$Homeless2   ,na.rm=T)
zh$DHS_HFIrc    <-zh$DHS_HFIr    -mean(zh$DHS_HFIr    ,na.rm=T)
zh$DHS_PTSrc    <-zh$DHS_PTSr    -mean(zh$DHS_PTSr    ,na.rm=T)
zh$DHS_HVPrc    <-zh$DHS_HVPr    -mean(zh$DHS_HVPr    ,na.rm=T)
zh$IDHS_EIrc    <-zh$IDHS_EIr    -mean(zh$IDHS_EIr    ,na.rm=T)
zh$MHV_C4c      <-zh$MHV_C4      -mean(zh$MHV_C4      ,na.rm=T)
zh$MHV_P4c      <-zh$MHV_P4      -mean(zh$MHV_P4      ,na.rm=T)
zh$MHV_C5c      <-zh$MHV_C5      -mean(zh$MHV_C5      ,na.rm=T)
zh$MHV_P5c      <-zh$MHV_P5      -mean(zh$MHV_P5      ,na.rm=T)
zh$FoodInsPc    <-zh$FoodInsP    -mean(zh$FoodInsP    ,na.rm=T)
zh$FoodISc      <-zh$FoodIS      -mean(zh$FoodIS      ,na.rm=T)





# demean - within and between variables
zh<-cbind(zh,demean(zh,select=c(
  "Year","Yearc",
  "CPopBP","CPopBPc",
  "CPopHP","CPopHPc",
  "ChildPT","ChildPTc",
  "ChildPW","ChildPWc",
  "ChildPB","ChildPBc",
  "ChildPH","ChildPHc",
  "CARatioT100","CARatioT100c",
  "CARatioW100","CARatioW100c",
  "CARatioB100","CARatioB100c",
  "CARatioH100","CARatioH100c",
  "MalePT","MalePTc",
  "MalePW","MalePWc",
  "MalePB","MalePBc",
  "MalePH","MalePHc",
  "MFRatioT100","MFRatioT100c",
  "MFRatioW100","MFRatioW100c",
  "MFRatioB100","MFRatioB100c",
  "MFRatioH100","MFRatioH100c",
  "ElderT","ElderTc",
  "ElderW","ElderWc",
  "ElderB","ElderBc",
  "ElderH","ElderHc",
  "SingleT","SingleTc",
  "SingleW","SingleWc",
  "SingleB","SingleBc",
  "SingleH","SingleHc",
  "FHeadT","FHeadTc",
  "FHeadW","FHeadWc",
  "FHeadB","FHeadBc",
  "FHeadH","FHeadHc",
  "NoHighT","NoHighTc",
  "NoHighW","NoHighWc",
  "NoHighB","NoHighBc",
  "NoHighH","NoHighHc",
  "UnempT","UnempTc",
  "UnempW","UnempWc",
  "UnempB","UnempBc",
  "UnempH","UnempHc",
  "CPovT","CPovTc",
  "CPovW","CPovWc",
  "CPovB","CPovBc",
  "CPovH","CPovHc",
  "CPov1","CPov1c",
  "CPov2","CPov2c",
  "CPov3","CPov3c",
  "PubAsT","PubAsTc",
  "WelfarT","WelfarTc",
  "SnapT","SnapTc",
  "SnapW","SnapWc",
  "SnapB","SnapBc",
  "SnapH","SnapHc",
  "IncomeT1k","IncomeT1kc",
  "IncomeW1k","IncomeW1kc",
  "IncomeB1k","IncomeB1kc",
  "IncomeH1k","IncomeH1kc",
  "GiniT100","GiniT100c",
  "HValueT10k","HValueT10kc",
  "MCostT100","MCostT100c",
  "OCostDT100","OCostDT100c",
  "MRentDT100","MRentDT100c",
  "OCostPT","OCostPTc",
  "MRentPT","MRentPTc",
  "MortgT","MortgTc",
  "LangAPT","LangAPTc",
  "LangAPW","LangAPWc",
  "LangAPB","LangAPBc",
  "LangAPH","LangAPHc",
  "LangBPT","LangBPTc",
  "LangBPW","LangBPWc",
  "LangBPB","LangBPBc",
  "LangBPH","LangBPHc",
  "LangCPT","LangCPTc",
  "OutUsT","OutUsTc",
  "OutUsW","OutUsWc",
  "OutUsB","OutUsBc",
  "OutUsH","OutUsHc",
  "FBornT","FBornTc",
  "FBornW","FBornWc",
  "FBornB","FBornBc",
  "FBornH","FBornHc",
  "NotCtzT","NotCtzTc",
  "NotCtzW","NotCtzWc",
  "NotCtzB","NotCtzBc",
  "NotCtzH","NotCtzHc",
  "MoveT","MoveTc",
  "MoveW","MoveWc",
  "MoveB","MoveBc",
  "MoveH","MoveHc",
  "VacantT","VacantTc",
  "OwnerT","OwnerTc",
  "OwnerW","OwnerWc",
  "OwnerB","OwnerBc",
  "OwnerH","OwnerHc",
  "CrowdT","CrowdTc",
  "CrowdW","CrowdWc",
  "CrowdB","CrowdBc",
  "CrowdH","CrowdHc",
  "MobileT","MobileTc",
  "MobileW","MobileWc",
  "MobileB","MobileBc",
  "MobileH","MobileHc",
  "DisablT","DisablTc",
  "DisablW","DisablWc",
  "DisablB","DisablBc",
  "DisablH","DisablHc",
  "DisablTC","DisablTCc",
  "DisablWC","DisablWCc",
  "DisablBC","DisablBCc",
  "DisablHC","DisablHCc",
  "DisablTM","DisablTMc",
  "DisablTF","DisablTFc",
  "Urban1","Urban1c",
  "Urban2","Urban2c",
  "ISBE_PFA","ISBE_PFAc",
  "ISBE_PFAE","ISBE_PFAEc",
  "ISBE_PI","ISBE_PIc",
  "HeadStart","HeadStartc",
  "ElyHeadS","ElyHeadSc",
  "HeadSAll","HeadSAllc",
  "PFA_HS1","PFA_HS1c",
  "PFA_HS2","PFA_HS2c",
  "LCCC","LCCCc",
  "LECCC","LECCCc",
  "LFCC","LFCCc",
  "LLECCC","LLECCCc",
  "LCLFCC","LCLFCCc",
  "LCCCB1","LCCCB1c",
  "LCCCB2","LCCCB2c",
  "LCCB1","LCCB1c",
  "LCCB2","LCCB2c",
  "LCCCS1","LCCCS1c",
  "LCCCS2","LCCCS2c",
  "LCCS1","LCCS1c",
  "LCCS2","LCCS2c",
  "LCCCG1","LCCCG1c",
  "LCCCG2","LCCCG2c",
  "LCCG1","LCCG1c",
  "LCCG2","LCCG2c",
  "ChildCare1","ChildCare1c",
  "ChildCare2","ChildCare2c",
  "ChildCare3","ChildCare3c",
  "CCAP","CCAPc",
  "Homeless","Homelessc",
  "Homeless2","Homeless2c",
  "DHS_HFIr","DHS_HFIrc",
  "DHS_PTSr","DHS_PTSrc",
  "DHS_HVPr","DHS_HVPrc",
  "IDHS_EIr","IDHS_EIrc",
  "MHV_C4","MHV_C4c",
  "MHV_P4","MHV_P4c",
  "MHV_C5","MHV_C5c",
  "MHV_P5","MHV_P5c",
  "FoodInsP","FoodInsPc",
  "FoodIS","FoodISc"
),group="CountyFIPS"))






save.image("Z:/CDCK01/Analysis/ZipCode/Food/Food01_data_census2.RData")
